# List countries we are interested
countries <- c("Albania", "Costa Rica", "Colombia", "Dominican Republic",
               "Ecuador", "Ethiopia", "Greece", "Guatemala", "Honduras",
               "Jamaica", "Mexico", "Rwanda", "Senegal", "Eswatini", "Uganda",
               "South Africa")

iso_list <- c("ALB", "CRI", "COL", "DOM", "ECU", "ETH", "GRC", "GTM", "HND", "JAM",
              "MEX", "RWA", "SEN", "SWZ", "UGA", "ZAF")

iso2_list <- c("AL", "CR", "CO", "DO", "EC", "ET", "GR", "GT", "HN", "JM",
               "MX", "RW", "SN", "SZ", "UG", "ZA")

country_data <- data.frame(
  Country = countries,
  ISO_3 = iso_list,
  iso = iso2_list,
  stringsAsFactors = FALSE
)

# Step 1 - First get the agg counts ---- 
# This produces Columns 1, 2, 4
data <- fread(paste0(output_path, "TA12_Count_Turnover_Present.csv"))

# Select columns
data <- data %>% 
  select(Country, `Number os Subsidiaries`, `Number of Firms`)

# Get number of MNEs
count_mne <- 
  read_excel(paste0(raw_data_path, "General Extractions/MNE_Count.xlsx"), skip = 4) %>%
  slice(seq(2, n()))

# Rename columns
colnames(count_mne) <- c("Country", "Non_Zero", "Zero", "na", "Total")

# Clening
count_mne <- count_mne %>%
  mutate(Non_Zero = as.numeric(Non_Zero),
         total_use = Non_Zero + Zero) %>%
  select(Country, "Total MNE" = Total)

# Clean country name
count_mne <- count_mne %>%
  mutate(Country = 
           stringr::str_remove(Country, " \\(.*\\)"))

# Join Counts
tab_totals <- data %>% 
  left_join(count_mne, by = "Country")


# Step 2 - Second we count the subsidiaries according to our methodology ---- 
files <- list.files(path = final_path ,
                    pattern = "Subs_Scope_GUO.csv", full.names = TRUE)

# Create empty object to save the counts
table <- data.frame()
# Loop in the files
for (i in 1:length(files)) {
  
  aux_data <- fread(files[i])
  
  table_aux <- aux_data %>% summarise(iso = substr(basename(files[i]), 1, 3),
                                      count_750 = n(),
                                      count_scope = sum(n_total > 1)
  )
  
  table_aux$count_groups <- aux_data %>%
    distinct(GUO_BVD_ID_NUMBER) %>%
    nrow()
  
  table <- table %>% bind_rows(table_aux)
}

table <- table %>%
  mutate("iso" = countrycode(sourcevar = unique(table$iso),
                             origin = "iso3c",
                             destination = "iso2c"))

# Save table to merge afterwards
table_subs <- table


# Step 3 - Now we do the same with firms above 500 ---- 

files <- list.files(path = final_path,
                    pattern = "Subs_t500_Scope_GUO.csv",
                    full.names = TRUE)

table <- data.frame()
for (i in 1:length(files)) {
  
  aux_data <- fread(files[i])
  
  table_aux <- aux_data %>% summarise(iso = substr(basename(files[i]), 1, 3),
                                      count_500 = n())
  
  table <- table %>% bind_rows(table_aux)
}


# Recover ISO 2
table <- table %>%
  mutate("iso" = countrycode(sourcevar = unique(table$iso),
                             origin = "iso3c",
                             destination = "iso2c"))

# Save table to merge afterwards
table_subs_500 <- table

# Step 4 - Now we look at the number of MNEs per country ----

# Counting the amount of MNEs in scope per country.
mne_scope <- fread(paste0(int_path, "MNEs_2015_2018.csv"))

# Get iso from bvd_id_code
mne_scope$iso <- mne_scope$GUO_BVD_ID_NUMBER %>% substr(1,2)

# Number of MNE per country
table_MNEs <- mne_scope %>% group_by(iso) %>% summarise("MNEs_per_country" = n())

# Clean a bit
rm(aux_data, data, mne_scope, table, table_aux)

# Step 5 - Numbers from CbCr ----

cbcr_oecd <- read.csv(paste0(raw_data_path, "EUTO_CbCR_data_2023-11-09.csv"))

# Summarize numbers in 2018
cbcr_oecd <- cbcr_oecd %>% 
  filter(partner_code %in% iso_list) %>% 
  ungroup() %>%
  filter(year == 2018 & panel_code == "PANELA")

#Choose the right variable 
cbcr_oecd <- cbcr_oecd %>%
  mutate(ENTITIES_COUNT = if_else(is.na(ENTITIES_COUNT), CBCR_COUNT, ENTITIES_COUNT))

# If na gets zero
cbcr_oecd[is.na(cbcr_oecd) == 1] <- 0

# Summarise counts
table <- cbcr_oecd %>%
  group_by(partner_code) %>%
  summarise(tot_sub = sum(SUBGROUPS_COUNT),
            tot_ent = sum(ENTITIES_COUNT),
            tot_cbcr = sum(CBCR_COUNT))

table_cbcr <- table

# Step 6 -  Join All together ----

#Lets organize the datasets to join them
table <- country_data %>%
  left_join(table_subs, by = "iso") %>%
  left_join(table_subs_500, by = "iso") %>%
  left_join(tab_totals, by = "Country") %>%
  left_join(table_MNEs, by = "iso") %>%
  left_join(table_cbcr, by = c("ISO_3" = "partner_code"))
  
# Not finded then zero
table[is.na(table)] <- 0

# Select vatiable we will use
table <- table %>%
  select(Country, `Number of Firms`, 
         `Total MNE`,
         MNEs_per_country,
         `Number os Subsidiaries`,
         count_500, count_750, count_scope,
         count_groups, tot_ent, tot_cbcr)

# Re order
table <- table %>%
  arrange(Country)

# Save the LaTeX table to a file
latex_table <- xtable(table, digits = 0)

print(latex_table, file = paste0(output_path, "TA11_Count_Table.tex"),
      include.rownames = FALSE)