*===============================================================================
* File name: 		CIT_ALB.do
* 
* Description:		This do-file creates the dataset ALB_withvars.csv. 
*
* Input:  					
*					$data/input/Albania/15.05.2020 TF 2015-A--2019-A.xlsx 
*					$data/input/Albania/NACE_REV2_US_NAICS_2017.xlsx  
*					$data/input/Albania/NAICS_2-6 digit_2017_Codes.xlsx 
*					$data/input/Albania/“Shutdown” sectors as defined by Vavra (2020).xlsx
*
* Output:
*					$data/output/Albania/ALB_withvars.csv
*===============================================================================
 
cls
capture restore
set more off
cap log close
clear all

*****************************************************************************
**************************** LEGAL ENTITIES *********************************
*****************************************************************************

* Load data and append together
import excel "$data/input/Albania/15.05.2020 TF 2015-A--2019-A.xlsx", sheet("Sheet1") firstrow clear

foreach var of varlist Income-Profittaxduetobepaid{
 replace `var' = "" if `var' =="NULL"   
 destring `var', replace
}

******** SELECT AND CREATE VARIABLES ********

* GROUP 0
	* Indentification variables
rename Year year
rename Id_Taxpayer tax_ID
generate country = "ALB"
generate entity = "Legal"	

* Check for duplicates and drop
duplicates report year tax_ID

* GROUP 1: INCOMES
	* Turnover and other income 
gen turnover = abs(Fiscalincome)
gen other_income = .
	* Exempt income
gen exempt_income = .
gen dividend_income = .
gen dividend_exempt = .

	* Total income (all income)
egen total_income = rowtotal(turnover other_income), missing	
	* Taxable income (-exempt income)
gen taxable_income = total_income - cond(missing(exempt_income), 0, exempt_income)

* GROUP 2: COST ITEMS
	* Cost of good solds
gen cogs = .	
	* Labor Inputs
gen labor_inp = .
	* Material Inputs
gen material_inp = .
	* Selling, admin and other operating costs
gen operating_inp = .
	* Capital Inputs
gen capital_inp = .
	* Financial Inputs
gen financial_inp = .
	* Depreciation 
gen depreciation = .	
	* Other Inputs
gen other_inp = .
 	* Non deductible Inputs
gen non_deduc_inp = abs(Nondeductableexpenses)

 	* Total costs: add up all costs & expenditure
egen tot_cost_built = rowtotal(capital_inp material_inp operating_inp labor_inp financial_inp depreciation other_inp), missing
gen tot_cost = abs(Fiscalexpenses)

	* Deductible Costs: total costs - non-deductible inputs 
gen deductible_cost = tot_cost - cond(missing(non_deduc_inp), 0, non_deduc_inp)   

* GROUP 3: PROFITS
gen gross_profit = .
	* Net profit
gen net_profit = total_income - cond(missing(tot_cost), 0, tot_cost)
	* Taxable profit
gen taxable_profit_built = taxable_income - cond(missing(deductible_cost), 0, deductible_cost)
gen taxable_profit_dataset = Fiscalprofit - cond(missing(Fiscalloss), 0, Fiscalloss)

gen taxable_profit = taxable_profit_dataset

* GROUP 4: GROSS & NET TAX BASE

	* Investment Incentives  (From tax base)
gen investment_taxbase = .
	* Capital allowances  (From tax base)
gen capital_allowance = .
	* Losses (always from tax base)
gen loss_carryforward = Carriedloss
	* Other Deductions (always from tax base)
gen other_ded_taxbase = . 
	* Add up credits & deductions from tax base: 
egen tot_deduc_taxbase = rowtotal(investment_taxbase capital_allowance other_ded_taxbase), missing 

	* Gross tax base (taxable_profit - tot_deduc_taxbase)
gen gross_tax_base = taxable_profit
	* Net tax base (gross_tax_base - loss_carryforward)
gen net_tax_base = Nettaxableprofit1617

* GROUP 5: GROSS & NET TAX LIABILITY

	* Gross tax liability (net tax base*CIT rate)
gen gross_tax_liability = Profittax1920

	* Credits for foreign taxes paid
gen cred_foreign_tax = .	
	* Investment credits from tax liability
gen investment_taxliab = .
	* Special firms credits from tax liability
gen special_taxliab = .
	* International Trade credits 
gen trade_taxliab = .
	* Other credit and allowances from tax liability
gen other_cred_taxliab = .
	* Add up credits & deductions from tax liability 
egen tot_deduc_taxliab = rowtotal(cred_foreign_tax special_taxliab trade_taxliab investment_taxliab other_cred_taxliab), missing
	* Add up credits & deductions that are not necessarily real credits from tax liability 
egen tot_noelse_taxliab = rowtotal(cred_foreign_tax  other_cred_taxliab), missing

	* Net tax liability (gross_tax_liability - tot_deduc_taxliab)
gen net_tax_liability = Profittax1920 - cond(missing(tot_deduc_taxliab), 0, tot_deduc_taxliab)

	* Net tax liability without foreign and other credits  
gen ntl_noelse = net_tax_liability + cond(missing(tot_noelse_taxliab), 0, tot_noelse_taxliab)

* GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS

	* Add up partial/advance payments
gen partial_advanced_pay = .
	* Add withholding 
gen withholding = .
	* Other creditable tax payments
gen other_cred_tax_pay = Deferredprofittax

	* Tax to remit
gen tax_to_remit = Profittaxduetobepaid


**** Treatment of missings and 0
foreach var of varlist gross_tax_base net_tax_base gross_tax_liability net_tax_liability tax_to_remit {
    replace `var' = 0 if missing(`var') & !missing(total_income)
}

********* Add labels and drop some variables ********
label variable tax_ID "Tax ID"
label variable year "Fiscal Year"
label variable turnover "Turnover"
label variable total_income "Total income"
label variable taxable_income "Taxable income"
label variable tot_cost "Total Costs"
label variable deductible_cost "Deductible Costs"
label variable net_profit "Net profit"
label variable taxable_income "Taxable profit"
label variable gross_tax_base "Gross Tax Base"
label variable tot_deduc_taxbase "Total Credits & Deductions - Tax Base"
label variable net_tax_base "Net Tax Base"
label variable gross_tax_liability "Gross Tax Liability"
label variable net_tax_liability "Net Tax Liability"
label variable tot_deduc_taxliab "Total Credits & Deductions - Tax Liability"
label variable tax_to_remit "Tax to Remit"
label variable country "Country"
**********************************************************************

* GROUP 7: FIRM CHARACTERISTICS

gen capital_city = .

*** ADD SECTORS
replace ServiceCodes = "" if ServiceCodes == "NULL"
gen section = substr(ServiceCodes, 1, 1)
gen class = substr(ServiceCodes, 2, .)
gen class_str = string(real(class), "%04.0f")
gen NACERev2 = substr(class_str,1,2)+"."+substr(class_str, 3,4)
gen division = substr(class_str,1,2)
destring division, replace

* Extract sector at the division level of NACE Rev. 2
gen descr_section_NACErev2 = ""
replace descr_section_NACErev2 = "AGRICULTURE, FORESTRY AND FISHING" if section == "A"
replace descr_section_NACErev2 = "MINING AND QUARRYING" if section == "B"
replace descr_section_NACErev2 = "MANUFACTURING" if section == "C"
replace descr_section_NACErev2 = "ELECTRICITY, GAS, STEAM AND AIR CONDITIONING SUPPLY" if section == "D"
replace descr_section_NACErev2 = "WATER SUPPLY; SEWERAGE, WASTE MANAGEMENT AND REMEDIATION ACTIVITIES" if section == "E"
replace descr_section_NACErev2 = "CONSTRUCTION" if section == "F"
replace descr_section_NACErev2 = "WHOLESALE AND RETAIL TRADE; REPAIR OF MOTOR VEHICLES AND MOTORCYCLES" if section == "G"
replace descr_section_NACErev2 = "TRANSPORTATION AND STORAGE" if section == "H"
replace descr_section_NACErev2 = "ACCOMODATION AND FOOD SERVICE ACTIVITIES" if section == "I"
replace descr_section_NACErev2 = "INFORMATION AND COMMUNICATION" if section == "J"
replace descr_section_NACErev2 = "FINANCIAL AND INSURANCE ACTIVITIES" if section == "K"
replace descr_section_NACErev2 = "REAL ESTATE ACTIVITIES" if section == "L"
replace descr_section_NACErev2 = "PROFESSIONAL, SCIENTIFIC AND TECHNICAL ACTIVITIES" if section == "M"
replace descr_section_NACErev2 = "ADMNINISTRATIVE AND SUPPORT SERVICE ACTIVITIES" if section == "N"
replace descr_section_NACErev2 = "PUBLIC ADMINISTRATION AND DEFENCE; COMPULSORY SOCIAL SECURITY" if section == "O"
replace descr_section_NACErev2 = "EDUCATION" if section == "P"
replace descr_section_NACErev2 = "HUMAN HEALTH AND SOCIAL WORK ACTIVITIES" if section == "Q"
replace descr_section_NACErev2 = "ARTS, ENTERTAINMENT AND RECREATION" if section == "R"
replace descr_section_NACErev2 = "OTHER SERVICE ACTIVITIES" if section == "S"
replace descr_section_NACErev2 = "ACTIVITY OF HOUSEHOLDS AS EMPLOYERS; ACTIVITIES OF HOUSEHOLDS FOR OWN USE" if section == "T"
replace descr_section_NACErev2 = "ACTIVITY OF EXTRATERRITORIAL ORGANISATIONS AND BODIES" if section == "U"

gen descr_section = descr_section_NACErev2

** SECTOR MORE GRANULAR LEVELS
tempfile main_data
save `main_data'

import excel using "$data/input/Albania/NACE_REV2_US_NAICS_2017.xlsx", firstrow clear

* Extract NAICS 4D 
gen NAICS4D = substr(USNAICS2017, 1, 4) 
drop Notes D USNAICS2017
rename B NACE_titles
duplicates drop NAICS4D, force
tempfile temp
save `temp'

import excel using "$data/input/Albania/NAICS_2-6 digit_2017_Codes", firstrow clear
keep if length(NAICSUSCode) == 4
keep NAICSUSCode NAICSUSTitle
rename NAICSUSCode NAICS4D
merge 1:1 NAICS4D using `temp'
drop _merge 
tempfile temp
save `temp'

import excel using "$data/input/Albania/“Shutdown” sectors as defined by Vavra (2020).xlsx" , firstrow clear
gen NAICS4D = substr(NACE4D, 1, 4)
gen subcategorie = substr(NACE4D, 5, .)
drop NACE4D
merge 1:1 NAICS4D using `temp'
keep if _merge == 3
keep NAICS4D categorie NACERev2
duplicates drop NACERev2, force

merge 1:m NACERev2 using `main_data'
drop if _merge == 1
gen shutdown_subsectors = 1 if _merge == 3
drop _merge


************* KEEP VARIABLES WE NEED *************
	* Create locals to keep variables
local group0 year country tax_ID entity class section division descr_section
local group1 turnover exempt_income dividend_exempt dividend_income other_income total_income taxable_income 
local group2 tot_cost *_inp deductible_cost depreciation cogs
local group3 taxable_profit net_profit gross_profit
local group4 investment_taxbase capital_allowance loss_carryforward other_ded_taxbase net_tax_base gross_tax_base tot_deduc_taxbase
local group5 gross_tax_liability net_tax_liability tot_deduc_taxliab cred_foreign_tax investment_taxliab other_cred_taxliab 
local group6 withholding partial_advanced_pay other_cred_tax_pay tax_to_remit
local group7 ntl_noelse tot_noelse_taxliab special_taxliab trade_taxliab capital_city

	* Keep selected variables
keep  `group0' `group1' `group2' `group3' `group4' `group5' `group6' `group7' // `group8'


* GROUP 8: Statutory Tax Rate

gen STR = . 
replace STR = 0.15 if year >= 2014 
replace STR = 0.10 if year < 2014 & year >= 2008
* 2019
replace STR = 0. if year == 2019 & turnover <= 5e+06 						// Turnover below 5 million ALL are exempt
replace STR = 0.05 if year == 2019 & turnover > 5e+06 & turnover <= 14e+06 	// Turnover below 14 million ALL have a lower rate

* 2018-16
replace STR = 0. if year <= 2018 & year >= 2016 & turnover <= 5e+06 		// Turnover below 5 million ALL are exempt
replace STR = 0.05 if year <= 2018 & year >= 2016 & turnover <= 8e+06 		// Turnover below 14 million ALL 

* 2015
replace STR = 0. if year == 2015 & turnover <= 2e+06  						// Turnover below 5 million ALL are exempt
replace STR = 0.05 if year == 2015 & turnover > 2e+06 & turnover <= 8e+06 	// Turnover below 14 million ALL 

* Final adjustments
sort tax_ID year, stable
export delimited using "$data/output/Albania/ALB_withvars.csv", replace 