*===============================================================================
* File name: 		CIT_COL.do
* 
* Description:		This do-file creates the dataset COL_withvars.csv. 
*
* Input:  					
*					$data/input/Colombia/df_panel_110_otras.csv
*
* Output:
*					$data/output/Colombia/COL_withvars.csv
*===============================================================================
 
cls
capture restore
set more off
cap log close
clear all

* First and last period (Fiscal Year)
local first_period = 2020								
local last_period = 2022

********************************************************************************
****************************** LEGAL ENTITIES **********************************
********************************************************************************
	import delimited "$data/input/Colombia/df_panel_110_otras.csv", clear

	******** SELECT AND CREATE VARIABLES ********
	* GROUP 0
		* Indentification variables
    	
	destring cat_anio, replace force
	keep if cat_anio > 2019 
    
	rename id_nit tax_ID		
	rename cat_anio year		
	generate country = "COL"
	generate entity = "Legal"	

	* Keep total assets 
	gen total_assets = num_total_patrimonio_bruto 
	
		* Check for duplicates and drop
	duplicates report year tax_ID // No duplicates
	
	* GROUP 1: INCOMES
		* Turnover and other income 
	gen turnover =  num_ingresos_brutos_ordinarios
	egen other_income = rowtotal(num_ingresos_financieros num_otros_ingresos num_rentas_gravables), missing
		* Exempt income
	egen exempt_income = rowtotal(num_ingreso_ncrngo num_devoluciones_rebajas_descu num_rentas_exentas) , missing
	
		* Dividend income 
	egen dividend_income = rowtotal(num_div_part_extranj_nacion) , missing							
	egen dividend_exempt = rowtotal(num_div_part_ncrngo num_div_part_chc) , missing 
	
		* Total income (turnover + other_income)	
	egen total_income_built = rowtotal(turnover other_income), missing			
	gen total_income = total_income_built
	
	* Taxable income (-exempt income)
	gen taxable_income = . 
	gen taxable_income_built = total_income_built - cond(missing(exempt_income), 0, exempt_income)	
	
	* GROUP 2: COST ITEMS
		* Cost of good solds
	gen cogs = . 
		* Labor Inputs
	gen labor_inp = . 
		* Material Inputs
	gen material_inp = . 
		* Selling, admin and other operating costs
	gen operating_inp = .
		* Capital Inputs
	gen capital_inp = .
		* Financial Inputs
	gen financial_inp = .
		* Depreciation 
	gen depreciation = .	
	gen acc_depreciation = .
		* Other Inputs
	gen other_inp = . 	
		* Non deductible Inputs
	gen non_deduc_inp = .  
	
		* Total costs: add up all costs & expenditure
	egen tot_cost_built = rowtotal(capital_inp operating_inp material_inp labor_inp financial_inp depreciation other_inp), missing
	gen tot_cost = num_total_costos_gastos_deducibl
	
		* Deductible Costs: total costs - non-deductible inputs 
	gen deductible_cost = tot_cost - cond(missing(non_deduc_inp), 0, non_deduc_inp)   
	
	* GROUP 3: PROFITS
		* gross profit
	gen gross_profit = .
	gen gross_profit_built = total_income - cond(missing(tot_cost), 0, tot_cost)
	
		* Net profit
	gen net_profit = .  
	gen net_profit_built = total_income - cond(missing(tot_cost), 0, tot_cost)
	
	* Taxable profit

	gen taxable_profit = . 		
	gen taxable_profit_built = taxable_income - cond(missing(deductible_cost), 0, deductible_cost)
	
	* GROUP 4: GROSS & NET TAX BASE
		* Investment Incentives  (From tax base)
	gen investment_taxbase = .
		* Capital allowances  (From tax base)
	gen capital_allowance = .
		* Losses (always from tax base)
	gen loss_carryforward = num_compensaciones  
		* Other Deductions (always from tax base)
	gen other_ded_taxbase = . 	 
		* Add up credits & deductions from tax base: 
	egen tot_deduc_taxbase = rowtotal(investment_taxbase capital_allowance other_ded_taxbase), missing 
	
	* Gross tax base (taxable_profit - tot_deduc_taxbase)
	gen gross_tax_base = taxable_profit - cond(missing(tot_deduc_taxbase), 0, tot_deduc_taxbase)
	gen gross_tax_base_built = taxable_profit_built - cond(missing(tot_deduc_taxbase), 0, tot_deduc_taxbase)
	
		* Net tax base (gross_tax_base - loss_carryforward)
	gen net_tax_base =  num_renta_liq_gravable			
	gen net_tax_base_built = gross_tax_base_built - cond(missing(loss_carryforward), 0, loss_carryforward)
	
	* GROUP 5: GROSS & NET TAX LIABILITY (and STR!) 
	
	* Gross tax liability (net tax base*CIT rate)	
	gen STR = num_impuesto_renta_liq_gravable / num_renta_liq_gravable 
	replace STR = 0.35 if STR >= 0.35
	replace STR = 0.35 if STR == . 		
		
	gen gross_tax_liability = num_impuesto_renta_liq_gravable
	gen gross_tax_liability_built = STR*net_tax_base_built
	
		* Credits for foreign taxes paid
	gen cred_foreign_tax = num_descuento_impuesto_exterior	
		* Investment credits from tax liability
	egen investment_taxliab = rowtotal(num_descuentos_tributarios num_valor_obra_impuesto1 num_valor_obra_impuesto2), missing
		* Special firms credits from tax liability
	gen special_taxliab = . 
		* International Trade credits 
	gen trade_taxliab = .
		* Other credit and allowances from tax liability
	gen other_cred_taxliab = .
		* Add up credits & deductions from tax liability 
	egen tot_deduc_taxliab = rowtotal(cred_foreign_tax special_taxliab trade_taxliab investment_taxliab other_cred_taxliab), missing
		* Add up credits & deductions that are not necessarily real credits from tax liability 
	egen tot_noelse_taxliab = rowtotal(cred_foreign_tax  other_cred_taxliab), missing
	
		* Net tax liability (gross_tax_liability - tot_deduc_taxliab)
	gen net_tax_liability = gross_tax_liability - cond(missing(tot_deduc_taxliab), 0, tot_deduc_taxliab)
	gen net_tax_liability_built = gross_tax_liability_built - cond(missing(tot_deduc_taxliab), 0, tot_deduc_taxliab)

		* Net tax liability without foreign and other credits  
	gen ntl_noelse = net_tax_liability + cond(missing(tot_noelse_taxliab), 0, tot_noelse_taxliab)
	gen ntl_noelse_built = net_tax_liability_built + cond(missing(tot_noelse_taxliab), 0, tot_noelse_taxliab)	
	
	* GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS
		* Add up partial/advance payments
	gen partial_advanced_pay = .
		* Add withholding 
	gen withholding = . 
		* Other creditable tax payments
	gen other_cred_tax_pay = . 
	
		* Tax to remit
	gen tax_to_remit = . 
	    
	**** Treatment of missings and 0
	foreach var of varlist taxable_profit net_profit gross_profit gross_tax_base net_tax_base  gross_tax_liability net_tax_liability ntl_noelse {
    sum `var'  `var'_`built' 
    replace `var' = `var'_`built' if missing(`var') & !missing(total_income)
    replace `var' = 0 if missing(`var') & !missing(total_income)
		drop `var'_`built'
		}	

		* Adjustmenet	
	foreach var of varlist gross_tax_base net_tax_base gross_tax_liability net_tax_liability tax_to_remit {
		replace `var' = . if net_profit>turnover
	}
	

	** ADD SECTOR, REGION	
	rename tex_subsector_economico sector
	gen section = ""
	* Standardize sectors. we are using CIIU 4
	replace section = "A" if sector == "agricultura ganaderia caza silvicultura y pesca"
	replace section = "B" if sector == "explotacion de minas y canteras"
	replace section = "C" if sector == "industrias manufactureras"
	replace section = "D" if sector == "suministro de electricidad gas vapor y aire acondicionado"
	replace section =  "E" if sector == "distribucion de agua evacuacion y tratamiento de aguas residuales y actividades de saneamiento ambiental"
	replace section = "F" if sector == "construccion"
	replace section = "G" if sector == "comercio al por mayor y al por menor reparacion de vehiculos automotores y motocicletas"
	replace section = "H" if sector == "transporte y almacenamiento"
	replace section = "I" if sector == "alojamiento y servicios de comida"
	replace section =  "J" if sector == "informacion y comunicaciones"
	replace section = "K" if sector == "actividades financieras y de seguros"
	replace section = "L" if sector == "actividades inmobiliarias"
	replace section =  "M" if sector == "actividades profesionales cientificas y tecnicas" 
	replace section =  "M" if sector =="actividades de servicios administrativos y de apoyo"
	replace section = "P" if sector == "educacion"
	replace section = "Q" if sector == "actividades de atencion de la salud humana y de asistencia social"
	replace section =  "R" if sector == "actividades artisticas de entretenimiento y recreacion"
	replace section = "S" if sector == "otras actividades de servicios"
	replace section = "U" if sector == "actividades de los hogares individuales en calidad de empleadores o de actividades no diferenciadas"
	replace section = "U" if sector == "actividades de organizaciones y entidades extraterritoriales"
	
	gen descr_section = ""	

	*Fecha y region
	rename tex_departamento region
	rename tex_municipio capital_city
		
	gen date_constitution_date = date(date_constitucion, "YMD")		
	rename date_constitution_date incorporation
	gen firm_age = year(today()) - year(incorporation)

    
	********* Add labels and drop some variables ********
	label variable tax_ID "Tax ID"
	label variable year "Fiscal Year"
	label variable turnover "Turnover"
	label variable total_income "Total income"
	label variable taxable_income "Taxable income"
	label variable tot_cost "Total Costs"
	label variable deductible_cost "Deductible Costs"
	label variable net_profit "Net profit"
	label variable taxable_income "Taxable profit"
	label variable gross_tax_base "Gross Tax Base"
	label variable tot_deduc_taxbase "Total Credits & Deductions - Tax Base"
	label variable net_tax_base "Net Tax Base"
	label variable gross_tax_liability "Gross Tax Liability"
	label variable net_tax_liability "Net Tax Liability"
	label variable tot_deduc_taxliab "Total Credits & Deductions - Tax Liability"
	label variable tax_to_remit "Tax to Remit"
	label variable country "Country"


	************* KEEP VARIABLES WE NEED *************
		* Create locals to keep variables
	local group0 year country tax_ID entity section descr_section 
	local group1 turnover exempt_income other_income total_income taxable_income dividend_income dividend_exempt
	local group2 tot_cost *_inp deductible_cost depreciation acc_depreciation cogs
	local group3 taxable_profit net_profit gross_profit
	local group4 investment_taxbase capital_allowance loss_carryforward net_tax_base gross_tax_base tot_deduc_taxbase
	local group5 gross_tax_liability net_tax_liability tot_deduc_taxliab cred_foreign_tax investment_taxliab other_cred_taxliab 
	local group6 withholding partial_advanced_pay other_cred_tax_pay tax_to_remit
	local group7 ntl_noelse tot_noelse_taxliab special_taxliab trade_taxliab
	local group8 capital_city region incorporation firm_age STR total_assets
	
		* Keep selected variables
	keep  `group0' `group1' `group2' `group3' `group4' `group5' `group6' `group7' `group8'

	export delimited using "$data/output/Colombia/COL_withvars.csv", replace