*===============================================================================
* File name: 		CIT_DOM.do
* 
* Description:		This do-file creates the dataset DOM_withvars.csv. 
*
* Input:  					
*					$data/input/Dominican Republic/DR_TaxData_Excel.xlsx 
*					$data/input/Dominican Republic/CIIU4_firmsectors.dta
*
* Output:
*					$data/output/Dominican Republic/DOM_withvars.csv
*===============================================================================

set excelxlsxlargefile on

cls
capture restore
set more off
cap log close
clear all

*****************************************************************************
**************************** LEGAL ENTITIES *********************************
*****************************************************************************

* Load data and append together
import excel using "$data/input/Dominican Republic/DR_TaxData_Excel.xlsx", firstrow clear

******** SELECT AND CREATE VARIABLES ********
* GROUP 0
	* Indentification variables
rename AÑO year
rename ID_EMPRESA tax_ID
generate country = "DOM"
generate entity = "Legal"	

	* Check for duplicates and drop
duplicates report year tax_ID // No duplicates

* GROUP 1: INCOMES
	* Turnover and other income 
gen turnover = IR2_INGRESOS
replace turnover = 0 if turnover == .01 | turnover ==1
gen other_income = .
	* Exempt income
gen exempt_income = .

gen dividend_income = .
gen dividend_exempt = .

	* Total income (all income)
gen total_income = IR2_INGRESOS	
	* Taxable income (-exempt income)
gen taxable_income = total_income - cond(missing(exempt_income), 0, exempt_income)

	* Net profit // gen here to build variables below
gen net_profit = IR2_BENEF_CONTABLE

* GROUP 2: COST ITEMS
	* Cost of good sold
gen cogs = B_Costos
	* Labor Inputs
egen labor_inp = rowtotal (B_Gastos_de_Personal B_Gastos_Trabajos_Suminist_ss), missing 
	* Material Inputs
gen material_inp = B_Costos // cost of good sold here
	* Selling, admin and other operating costs
gen operating_inp = B_Gastos_Representacion
	* Capital Inputs
gen capital_inp = B_Arrendamientos
	* Financial Inputs
gen financial_inp = B_Gastos_Financieros
	* Depreciation 
gen depreciation = B_Deprec_Reparac_Mant_activos
gen acc_depreciation = .
	* Other Inputs
egen other_inp = rowtotal(B_Gastos_Extraordinarios B_Otros_Gastos), missing 	
	* Non deductible Inputs
gen non_deduc_inp = .  

 	* Total costs: add up all costs & expenditure
egen tot_cost= rowtotal(capital_inp material_inp operating_inp labor_inp financial_inp depreciation other_inp), missing

	* Deductible Costs: total costs - non-deductible inputs 
gen deductible_cost = tot_cost - cond(missing(non_deduc_inp), 0, non_deduc_inp)   

* GROUP 3: PROFITS

	* Gross profit
gen gross_profit = total_income - cond(missing(cogs), 0, cogs)   

	* Taxable profit
gen taxable_profit = IR2_RNI_DESPUES_AJUSTES // after all adjustment

* GROUP 4: GROSS & NET TAX BASE

	* Investment Incentives  (From tax base)
gen investment_taxbase = IR2_DEDUCCION_INVER_LEY392_07
	* Capital allowances  (From tax base)
gen capital_allowance = .
	* Losses (always from tax base)
gen loss_carryforward = cond(missing(IR2_RNI_DESPUES_AJUSTES), 0, IR2_RNI_DESPUES_AJUSTES) - cond(missing(IR2_RNI_DESPUES_PERDIDAS), 0, IR2_RNI_DESPUES_PERDIDAS) 
	* Other Deductions (always from tax base)
gen other_ded_taxbase = . 
	* Add up credits & deductions from tax base: 
egen tot_deduc_taxbase = rowtotal(investment_taxbase capital_allowance other_ded_taxbase), missing 

	* Gross tax base (taxable_profit - tot_deduc_taxbase)
gen gross_tax_base = taxable_profit - cond(missing(tot_deduc_taxbase), 0, tot_deduc_taxbase)
	* Net tax base (gross_tax_base - loss_carryforward)
gen net_tax_base_built = gross_tax_base - cond(missing(loss_carryforward), 0, loss_carryforward)
gen net_tax_base = IR2_RNI_NETO


* GROUP 5: GROSS & NET TAX LIABILITY

	* Gross tax liability (net tax base*CIT rate)
gen gross_tax_liability = IR2_IMPUESTO_LIQ
	* Credits for foreign taxes paid
gen cred_foreign_tax = .	
	* Investment credits from tax liability
egen investment_taxliab = rowtotal(IR2_CRED_CINE_LEY108_10 IR2_CRED_ENER_RENOVABLE IR2_CRED_FISCAL_CINE_LEY108_10), missing
	* Special firms credits from tax liability
gen special_taxliab = .
	* International Trade credits 
gen trade_taxliab = .
	* Other credit and allowances from tax liability
gen other_cred_taxliab = .
	* Add up credits & deductions from tax liability 
egen tot_deduc_taxliab = rowtotal(cred_foreign_tax special_taxliab trade_taxliab investment_taxliab other_cred_taxliab), missing
	* Add up credits & deductions that are not necessarily real credits from tax liability 
egen tot_noelse_taxliab = rowtotal(cred_foreign_tax other_cred_taxliab), missing

	* Net tax liability (gross_tax_liability - tot_deduc_taxliab)
gen net_tax_liability = gross_tax_liability - cond(missing(tot_deduc_taxliab), 0, tot_deduc_taxliab)

	* Net tax liability without foreign and other credits  
gen ntl_noelse = net_tax_liability + cond(missing(tot_noelse_taxliab), 0, tot_noelse_taxliab)

* GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS

	* Add up partial/advance payments
gen partial_advanced_pay = .
	* Add withholding 
gen withholding = .
	* Other creditable tax payments
gen other_cred_tax_pay = .

	* Tax to remit
gen tax_to_remit = .

**** Treatment of missings and 0
foreach var of varlist gross_tax_base net_tax_base gross_tax_liability net_tax_liability  {
    replace `var' = 0 if missing(`var') & !missing(total_income)
}

********* Add labels and drop some variables ********
label variable tax_ID "Tax ID"
label variable year "Fiscal Year"
label variable turnover "Turnover"
label variable total_income "Total income"
label variable taxable_income "Taxable income"
label variable tot_cost "Total Costs"
label variable deductible_cost "Deductible Costs"
label variable net_profit "Net profit"
label variable taxable_income "Taxable profit"
label variable gross_tax_base "Gross Tax Base"
label variable tot_deduc_taxbase "Total Credits & Deductions - Tax Base"
label variable net_tax_base "Net Tax Base"
label variable gross_tax_liability "Gross Tax Liability"
label variable net_tax_liability "Net Tax Liability"
label variable tot_deduc_taxliab "Total Credits & Deductions - Tax Liability"
label variable tax_to_remit "Tax to Remit"
label variable country "Country"

**********************************************************************

* Add sectors 
* Standardize sectors. we are using CIIU 4
gen section = ""
replace section = "A" if ACT_ECONOMICA == "Cultivo de Cereales"
replace section = "A" if ACT_ECONOMICA == "Cultivos Tradicionales"
replace section = "A" if ACT_ECONOMICA == "Ganadería, Silvicultura y Pesca"
replace section = "B" if ACT_ECONOMICA == "Explotación de Minas y Canteras"
replace section = "C" if ACT_ECONOMICA == "Manufactura"
replace section = "D" if ACT_ECONOMICA == "Electricidad, Gas y Agua"
replace section = "F" if ACT_ECONOMICA == "Construcción"
replace section = "G" if ACT_ECONOMICA == "Comercio"
replace section = "H" if ACT_ECONOMICA == "Transporte y Almacenamiento"

replace section = "I" if ACT_ECONOMICA == "Hoteles, Bares y Restaurantes"
replace section = "J" if ACT_ECONOMICA == "Comunicaciones"   
replace section = "K" if ACT_ECONOMICA == "Intermediación Financiera, Seguros y Otras"

replace section = "L" if ACT_ECONOMICA == "Alquiler de Viviendas"
replace section = "O" if ACT_ECONOMICA == "Administración Pública"
replace section = "P" if ACT_ECONOMICA == "Servicios de Enseñanza"
replace section = "Q" if ACT_ECONOMICA == "Servicios de Salud"
replace section = "S" if ACT_ECONOMICA == "Otros Servicios"
replace section = "S" if ACT_ECONOMICA == "Servicios Agropecuarios"

preserve
use "$data/input/Dominican Republic/CIIU4_firmsectors.dta", clear
keep section descr_section 
duplicates drop section, force
tempfile sector
save `sector'
restore

merge m:1 section using `sector'
drop if _merge == 2
drop _merge 

* GROUP 7: FIRM CHARACTERISTICS
gen total_assets = A_TOTAL_ACTIVOS 

** STR:
gen STR = .
replace STR = 0.27 if year == 2015
replace STR = 0.28 if year == 2014
replace STR = 0.25 if year < 2014 & year > 2006
replace STR = 0.3 if year <= 2006

/* Special Economic Zones */
gen sez=0
replace sez=1 if REGIMEN_TRIBUTARIO=="ZONA F. INDUSTRIAL"
replace sez=1 if REGIMEN_TRIBUTARIO=="ZONA F.COM AEROP"
replace sez=1 if REGIMEN_TRIBUTARIO=="ZONA F.COM HOTEL"
replace sez=1 if REGIMEN_TRIBUTARIO=="ZONA F.COM MERCANCIAS"
replace sez=1 if REGIMEN_TRIBUTARIO=="ZONA F.COM SERVICIOS"

		  
************* KEEP VARIABLES WE NEED *************
	* Create locals to keep variables
local group0 year country tax_ID entity section  descr_section
local group1 turnover exempt_income other_income total_income taxable_income dividend_income dividend_exempt
local group2 tot_cost *_inp deductible_cost depreciation acc_depreciation cogs
local group3 taxable_profit net_profit gross_profit
local group4 investment_taxbase capital_allowance loss_carryforward other_ded_taxbase net_tax_base gross_tax_base tot_deduc_taxbase
local group5 gross_tax_liability net_tax_liability tot_deduc_taxliab cred_foreign_tax investment_taxliab other_cred_taxliab 
local group6 withholding partial_advanced_pay other_cred_tax_pay tax_to_remit TASA_ISR  ntl_noelse tot_noelse_taxliab special_taxliab trade_taxliab total_assets STR sez

	* Keep selected variables
keep  `group0' `group1' `group2' `group3' `group4' `group5' `group6'

rename TASA_ISR statutory_rate
gen capital = .

* Final adjustments
sort tax_ID year, stable

export delimited using "$data/output/Dominican Republic/DOM_withvars.csv", replace 