*===============================================================================
* File name: 		CIT_ETH.do
* 
* Description:		This do-file creates the dataset DOM_withvars.csv. 
*
* Input:  					
*					$data/input/Ethiopia/combined data.dta
*					$data/input/Ethiopia/LOC_ETH_opencagegeo.csv
*
* Output:
*					$data/output/Ethiopia/ETH_withvars.csv
*===============================================================================

set excelxlsxlargefile on

cls
capture restore
set more off
cap log close
clear all

*****************************************************************************
**************************** LEGAL ENTITIES *********************************
*****************************************************************************

 *** First and last period (Fiscal Year)
local first_period = 2010								
local last_period = 2018

*LOAD
use "$data/input/Ethiopia/combined data.dta", clear

******** SELECT AND CREATE VARIABLES ********
* GROUP 0
	* Indentification variables
rename TPYEAR  year
rename TAX_PAYER_NO tax_ID
generate country = "ETH"
generate entity = "Legal"

drop if LegalStatus_Type == "COOPERATIVE SOCIETY"
drop if LegalStatus_Type == "ENTERPRISE"
drop if LegalStatus_Type == " GOVERNMENT INSTITUTION"
drop if LegalStatus_Type == "INDIVIDUAL"
drop if LegalStatus_Type == "JOINT VENTURE"
drop if LegalStatus_Type == "MICRO ENTERPRISE"
drop if LegalStatus_Type == "NO ENTERPRISE"
drop if LegalStatus_Type == "NGO"
drop if LegalStatus_Type == "OTHERS"
drop if LegalStatus_Type == "PARTNERSHIP"
drop if LegalStatus_Type == "SMALL"
drop if LegalStatus_Type == "SMALL ENTERPRISE"
drop if LegalStatus_Type == "SOLE PROPRIETOR"

	* Check for duplicates and drop
duplicates drop  
duplicates report year tax_ID 
duplicates tag year tax_ID, gen(flag)
sort year tax_ID  

	* We sort the data to only keep the revised return and sectors that are specified
gen tag1= .
replace tag1 = 0 if ASSESS_TYPE ==  "REVISED BY TAX DEPARTMENT"
replace tag1 = 1 if ASSESS_TYPE == "DONE BY TAXPAYER"

gen tag2 = 0
replace tag2 = 1 if Business_Activity_ESIC == "UNSPECIFIED"

sort year tax_ID tag1 tag2
duplicates drop year tax_ID, force  
duplicates report year tax_ID 


* GROUP 1: INCOMES

	* Turnover and other income 
gen turnover = abs(Sales_Income)
gen other_income = abs(OtherInc)
	* Exempt income
gen exempt_income = .
gen dividend_income = .
gen dividend_exempt = .

	* Total income (all income)
egen total_income_built = rowtotal(turnover other_income), missing	
gen total_income = abs(GrossIncome) 
replace total_income = total_income_built if total_income < total_income_built  
sum total_income total_income_built

replace total_income = total_income_built if missing(GrossIncome)
sum total_income total_income_built
list total_income total_income_built in 1/20

	* Taxable income (-exempt income)
gen taxable_income = total_income - cond(missing(exempt_income), 0, exempt_income)

	* Gross profit (Gross income - CoGS)
gen gross_profit = GrossP_L
gen gross_profit_built = abs(GrossIncome) - abs(CoGS)
sum gross_profit gross_profit_built
list gross_profit gross_profit_built in 1/20

* GROUP 2: COST ITEMS

	* cost of good sold 
gen cogs = CoGS
	* Labor Inputs
gen labor_inp = .
	* Material Inputs
gen material_inp = abs(CoGS)
	* Selling, admin and other operating costs
gen operating_inp = .
	* Capital Inputs
gen capital_inp = .
	* Financial Inputs
gen financial_inp = .
	* Depreciation 
gen depreciation = .	
	* Other Inputs
gen other_inp = .
 	* Non deductible Inputs
gen non_deduc_inp = .

 	* Total costs: add up all costs & expenditure
egen tot_cost_built = rowtotal(capital_inp material_inp operating_inp labor_inp financial_inp depreciation other_inp), missing
gen tot_cost_dataset = abs(TotalExp) + cond(missing(material_inp), 0, material_inp)
gen tot_cost = tot_cost_dataset

	* Deductible Costs: total costs - non-deductible inputs 
gen deductible_cost = tot_cost - cond(missing(non_deduc_inp), 0, non_deduc_inp)   

* GROUP 3: PROFITS
	* Net profit
gen net_profit = NetIncomeLoss  
gen net_profit_built = total_income - cond(missing(tot_cost), 0, tot_cost)
sum net_profit net_profit_built
list net_profit net_profit_built in 1/20

	* Taxable profit
gen taxable_profit = taxable_income - cond(missing(deductible_cost), 0, deductible_cost)


* GROUP 4: GROSS & NET TAX BASE

	* Investment Incentives  (From tax base)
gen investment_taxbase = .
	* Capital allowances  (From tax base)
gen capital_allowance = .
	* Losses (always from tax base)
replace LOSSCBADJ = abs(LOSSCBADJ)
gen loss_carryforward = abs(LossCFPrev) + cond(missing(LOSSCBADJ), 0, LOSSCBADJ)
	* Other Deductions (always from tax base)
gen other_ded_taxbase = .
	* Add up credits & deductions from tax base: 
egen tot_deduc_taxbase = rowtotal(investment_taxbase capital_allowance other_ded_taxbase), missing 
	* Gross tax base (taxable_profit - tot_deduc_taxbase)
gen gross_tax_base = taxable_profit- cond(missing(tot_deduc_taxbase), 0, tot_deduc_taxbase)
	* Net tax base (gross_tax_base - loss_carryforward)
gen net_tax_base = TaxableIncome 
gen net_tax_base_built = taxable_profit - cond(missing(loss_carryforward), 0, loss_carryforward)
sum net_tax_base net_tax_base_built 
list net_tax_base net_tax_base_built in 1/20

* GROUP 5: GROSS & NET TAX LIABILITY
	* Gross tax liability (net tax base*CIT rate)
gen gross_tax_liability = TaxPaybl 
gen gross_tax_liability_built = net_tax_base_built*0.3
replace gross_tax_liability_built = net_tax_base_built*0.25 if SectorActivity == "MINING AND QUARRYING" 

sum gross_tax_liability gross_tax_liability_built
list gross_tax_liability gross_tax_liability_built in 1/20

	* Credits for foreign taxes paid
gen cred_foreign_tax = .	
	* Investment credits from tax liability
gen investment_taxliab = .
	* Special firms credits from tax liability
gen special_taxliab = .
	* International Trade credits 
gen trade_taxliab = .
	* Other credit and allowances from tax liability
gen other_cred_taxliab = .

	* Add up credits & deductions from tax liability 
egen tot_deduc_taxliab = rowtotal(cred_foreign_tax special_taxliab trade_taxliab investment_taxliab other_cred_taxliab), missing
	* Add up credits & deductions that are not necessarily real credits from tax liability 
egen tot_noelse_taxliab = rowtotal(cred_foreign_tax  other_cred_taxliab), missing

	* Net tax liability (gross_tax_liability - tot_deduc_taxliab)
gen net_tax_liability = gross_tax_liability - cond(missing(tot_deduc_taxliab), 0, tot_deduc_taxliab)
gen net_tax_liability_built = gross_tax_liability_built
gen ntl_test = LeftUnPaid + cond(missing(FCredi_WithHldg_Total), 0, FCredi_WithHldg_Total)
sum net_tax_liability net_tax_liability_built ntl_test
list net_tax_liability net_tax_liability_built ntl_test in 1/20

	* Net tax liability without foreign and other credits  
gen ntl_noelse = net_tax_liability + cond(missing(tot_noelse_taxliab), 0, tot_noelse_taxliab)

* GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS
	* Add up partial/advance payments
gen partial_advanced_pay = .
	* Add withholding 
gen withholding = FCredi_WithHldg_Total
	* Other creditable tax payments
gen other_cred_tax_pay = .

	* Tax to remit
gen tax_to_remit = LeftUnPaid 

**** Treatment of missings and 0
foreach var of varlist gross_tax_base net_tax_base gross_tax_liability net_tax_liability tax_to_remit {
    replace `var' = 0 if missing(`var') & !missing(total_income)
}

********* Add labels and drop some variables ********
label variable tax_ID "Tax ID"
label variable year "Fiscal Year"
label variable turnover "Turnover"
label variable total_income "Total income"
label variable taxable_income "Taxable income"
label variable tot_cost "Total Costs"
label variable deductible_cost "Deductible Costs"
label variable net_profit "Net profit"
label variable taxable_income "Taxable profit"
label variable gross_tax_base "Gross Tax Base"
label variable tot_deduc_taxbase "Total Credits & Deductions - Tax Base"
label variable net_tax_base "Net Tax Base"
label variable gross_tax_liability "Gross Tax Liability"
label variable net_tax_liability "Net Tax Liability"
label variable tot_deduc_taxliab "Total Credits & Deductions - Tax Liability"
label variable tax_to_remit "Tax to Remit"
label variable country "Country"

**********************************************************************
**** ADD sectors 
gen section = ""
gen descr_section = ""

replace section = "A" if SectorActivity == "AGRICULTURAL, HUNTING, FORESTY AND FISHING" | SectorActivity == "AGRICULTURE" 
replace section = "B" if SectorActivity == "MINING AND QUARRYING" 
replace section = "C" if SectorActivity == "MANUFACTURING" | SectorActivity == "HAND-CRAFTS AND COTTAGE INDUSTRIES"
replace section = "D" if SectorActivity == "UTILIES"  
//replace section = "E" if SectorActivity == ""  
replace section = "F" if SectorActivity == "CONSTRUCTION"
replace section = "G" if SectorActivity == "RETAIL TRADE" | SectorActivity == "RETAILING"  | SectorActivity =="WHOLESALING" | SectorActivity == "WHOLESALE TRADE"
replace section = "H" if SectorActivity == "TRANSPORT AND STORAGE" | SectorActivity == "TRANSPORTATION" 
replace section = "I" if SectorActivity == "ACCOMODATION AND FOOD SERVICES" | SectorActivity == "HOTEL" | SectorActivity == "RESTAURANT/BAR"
replace section = "J" if SectorActivity == "INFORMATION" 
replace section = "K" if SectorActivity == "FINANCE AND INSURANCE" | SectorActivity == "CONSULTING"
replace section = "L" if SectorActivity == "REAL ESTATE, RENTAL AND LEASING" | SectorActivity == "RENTAL/HIRE"
replace section = "M" if SectorActivity == "PROFESSIONAL, SCIENTIFIC AND TECHNICAL SERVICES"
replace section = "N" if SectorActivity == "SERVICE"
replace section = "O" if SectorActivity == "PUBLIC ADMINISTRATION(EXCLUDING EDUCATIONAL AND HEALTH SERVICES)"
replace section = "P" if SectorActivity == "EDUCATIONAL SERVICES (INCLUDING GOVERNMENT INSTITUTIONS)"
replace section = "Q" if SectorActivity == "HEALTH CARE AND SOCIAL ASSISTANCE"
replace section = "R" if SectorActivity == "ARTS, ENTERTAINMENTS AND RECREATION"
replace section = "S" if SectorActivity == "OTHER SERVICES (EXCEPT PUBLIC ADMINISTRATION)"
//replace section = "T" if SectorActivity == ""
replace section = "U" if SectorActivity == "OTHER NON-RESIDENTIAL ORGANIZATIONS AND BODIES"

gen descr_section_NACErev2 = section
replace descr_section_NACErev2 = "AGRICULTURE, FORESTRY AND FISHING" if section == "A"
replace descr_section_NACErev2 = "MINING AND QUARRYING" if section == "B"
replace descr_section_NACErev2 = "MANUFACTURING" if section == "C"
replace descr_section_NACErev2 = "ELECTRICITY, GAS, STEAM AND AIR CONDITIONING SUPPLY" if section == "D"
replace descr_section_NACErev2 = "WATER SUPPLY; SEWERAGE, WASTE MANAGEMENT AND REMEDIATION ACTIVITIES" if section == "E"
replace descr_section_NACErev2 = "CONSTRUCTION" if section == "F"
replace descr_section_NACErev2 = "WHOLESALE AND RETAIL TRADE; REPAIR OF MOTOR VEHICLES AND MOTORCYCLES" if section == "G"
replace descr_section_NACErev2 = "TRANSPORTATION AND STORAGE" if section == "H"
replace descr_section_NACErev2 = "ACCOMODATION AND FOOD SERVICE ACTIVITIES" if section == "I"
replace descr_section_NACErev2 = "INFORMATION AND COMMUNICATION" if section == "J"
replace descr_section_NACErev2 = "FINANCIAL AND INSURANCE ACTIVITIES" if section == "K"
replace descr_section_NACErev2 = "REAL ESTATE ACTIVITIES" if section == "L"
replace descr_section_NACErev2 = "PROFESSIONAL, SCIENTIFIC AND TECHNICAL ACTIVITIES" if section == "M"
replace descr_section_NACErev2 = "ADMNINISTRATIVE AND SUPPORT SERVICE ACTIVITIES" if section == "N"
replace descr_section_NACErev2 = "PUBLIC ADMINISTRATION AND DEFENCE; COMPULSORY SOCIAL SECURITY" if section == "O"
replace descr_section_NACErev2 = "EDUCATION" if section == "P"
replace descr_section_NACErev2 = "HUMAN HEALTH AND SOCIAL WORK ACTIVITIES" if section == "Q"
replace descr_section_NACErev2 = "ARTS, ENTERTAINMENT AND RECREATION" if section == "R"
replace descr_section_NACErev2 = "OTHER SERVICE ACTIVITIES" if section == "S"
replace descr_section_NACErev2 = "ACTIVITY OF HOUSEHOLDS AS EMPLOYERS; ACTIVITIES OF HOUSEHOLDS FOR OWN USE" if section == "T"
replace descr_section_NACErev2 = "ACTIVITY OF EXTRATERRITORIAL ORGANISATIONS AND BODIES" if section == "U"
replace descr_section = descr_section_NACErev2

drop descr_section_NACErev2 

tempfile CIT
save `CIT'


* GROUP 7: FIRM CHARACTERISTICS

*** Capital city
import delimited "$github/distributional-statistics/dofiles/Cleaning/Ethiopia/LOC_ETH_opencagegeo.csv", varnames(1) case(preserve) clear 

merge 1:m TPTAX_CENTER using `CIT'
drop if _merge == 1
drop _merge
gen capital_city = 0
replace capital_city = 1 if g_state == "Addis Ababa"
replace capital_city = . if g_state == ""

gen tax_center = TPTAX_CENTER

* GROUP 8: Statutory Tax Rate

gen STR = . 
replace STR = 0.3 
replace STR = 0.25 if section == "B"
 
************* KEEP VARIABLES WE NEED *************
	* Create locals to keep variables
local group0 year country tax_ID entity section descr_section capital_city g_state tax_center
local group1 turnover exempt_income other_income total_income taxable_income 
local group2 tot_cost *_inp deductible_cost depreciation
local group3 taxable_profit net_profit
local group4 investment_taxbase capital_allowance loss_carryforward other_ded_taxbase net_tax_base gross_tax_base tot_deduc_taxbase
local group5 gross_tax_liability net_tax_liability tot_deduc_taxliab cred_foreign_tax investment_taxliab other_cred_taxliab 
local group6 withholding partial_advanced_pay other_cred_tax_pay tax_to_remit ntl_noelse tot_noelse_taxliab special_taxliab trade_taxliab
local group7 GrossP_L Sales_Income OtherInc GrossIncome CoGS TaxPaybl cogs STR dividend_income dividend_exempt

	* Keep selected variables
keep  `group0' `group1' `group2' `group3' `group4' `group5' `group6' `group7'

tab year 

	* Fiscal years
drop if year == 2018
drop if year == 2017 

* Final adjustments
sort tax_ID year, stable

export delimited using "$data/output/Ethipia/ETH_withvars.csv", replace 