*===============================================================================
* File name: 		CIT_GTM.do
* 
* Description:		This do-file creates the dataset GTM_withvars.csv. 
*
* Input:  					
*					$data/input/Guatemala/ISR_SOBRE_UTILIDADES_DC_26-92_PF2006-2012.txt 
*					$data/input/Guatemala/GPD_ISR_DC10-2012_P2013-2014.txt 
*					$data/input/Guatemala/ISR_ANUAL_2016_2018.txt 
*					$data/input/Guatemala/GPD_ISR_DC10-2012_P2013-2014.txt.txt 
*					$data/input/Guatemala/PADRON_CONTRIBUYENTES.txt 
*					$data/input/Guatemala/CIIU4_firmsectors.dta 
*					$data/input/Guatemala/ISR_ANUAL_2019_2020.txt
*
* Output:
*					$data/output/Guatemala/GTM_withvars.csv
*===============================================================================

cls
capture restore
set more off
cap log close
clear all

*****************************************************************************
**************************** LEGAL ENTITIES *********************************
*****************************************************************************

local first_period = 2006								
local last_period = 2020

*************************** Dataset 1: 2006-2012 ******************************
import delimited using "$data/input/Guatemala/ISR_SOBRE_UTILIDADES_DC_26-92_PF2006-2012.txt", clear  delim (tab)

******** SELECT AND CREATE VARIABLES ********

* GROUP 0

	* Remove special character
replace tipo_persona = subinstr(tipo_persona, "|", "",.)
replace municipio = subinstr(municipio, "|", "",.)

	* Generate new variables: country name and entity type
generate country = "GTM"
generate entity = ""
replace entity = "Legal" if tipo_persona == "J"
replace entity = "Natural" if tipo_persona == "I"
replace entity = "Unclassified" if tipo_persona == ""	

	* Check for duplicates and drop
duplicates report codigo periodo // No duplicates

* GROUP 1: INCOMES
	* Turnover and other income 
egen turnover = rowtotal(venta_debienes_mercado_local prestacion_servicios_mercado_loc exportaciones servicios_profesionales_prestado), missing

egen other_income = rowtotal(rentas_no_afectas donaciones_ing rentas_derivadas_de_inversion_fi intereses_y_rendimientos_financi arrendamientos_ing dietas resarcimiento_de_perdidas_patrim otrosingresos), missing
	* Exempt income
gen exempt_income = rentas_exentas

gen dividend_income = .
gen dividend_exempt = .

	* Total income (all income)
gen total_income = total_renta_bruta	
egen total_income_built = rowtotal(turnover other_income), missing
replace total_income = total_income_built if missing(total_income)
replace total_income = total_income_built if total_income == 0

	* Taxable income (-exempt income)
gen taxable_income = total_income - cond(missing(exempt_income), 0, exempt_income)

* GROUP 2: COST ITEMS
	* Cost of good solds
gen cogs = costo_de_ventas
	* Labor Inputs
#delimit ;
egen labor_inp = rowtotal(sueldos_socios_consejeros_s_a
     sueldos_salarios_bonificaciones honorarios_servicios_desde_el_ex 
	 honorarios_servicios_en_el_pais_ indemnizaciones cuotas_patronales), missing;	
 #delim cr 
	* Material Inputs
gen material_inp = costo_de_ventas
	* Selling, admin and other operating costs
gen operating_inp = viaticos_y_gastos_de_transporte
	* Capital Inputs
gen capital_inp = arrendamientos_gt
	* Financial Inputs
egen financial_inp = rowtotal(intereses_gastos_sujetos_retenci ///
     gtos_financieros_origen_inversio reaseguros_y_reafinazamaientos), missing
	* Depreciation 
egen depreciation = rowtotal(depreciaciones amortizaciones), missing
gen acc_depreciation = .
	* Other Inputs
#delimit ;
egen other_inp = rowtotal( ctas_incobrables_giro_habitual regalias otros_gastos impuestos_y_contribuciones donaciones_gt), missing;
#delim cr 	
	* Non deductible Inputs
egen non_deduc_inp = rowtotal( _costo_gasto_no_deducible _exceso_costos_gastos_97_ingreso _costo_gtos_rentas_exentas), missing
 	* Total costs: add up all costs & expenditure
egen tot_cost_built = rowtotal(capital_inp material_inp operating_inp labor_inp financial_inp depreciation other_inp), missing
gen tot_cost_dataset = total_costo_y_gasto
egen tot_cost = rowmax(tot_cost_built tot_cost_dataset)

	* Deductible Costs: total costs - non-deductible inputs 
gen deductible_cost = tot_cost - cond(missing(non_deduc_inp), 0, non_deduc_inp)   

* GROUP 3: PROFITS
	* Gross profit
gen gross_profit = total_income - cond(missing(cogs), 0, cogs)
	* Net profit
gen net_profit = total_renta_neta
replace net_profit = -1*perdida_neta if net_profit == 0
gen net_profit_built = total_income- cond(missing(tot_cost), 0, tot_cost)
	* Taxable profit
gen taxable_profit = taxable_income - cond(missing(deductible_cost), 0, deductible_cost)

* GROUP 4: GROSS & NET TAX BASE
	* Investment Incentives  (From tax base)
egen investment_taxbase = rowtotal(_deducciones_costos_gastos_exced _deduccion_unicapersonas_no_merc), missing
	* Capital allowances  (From tax base)
gen capital_allowance = .
	* Losses (always from tax base)
gen loss_carryforward =_perdida_de_operacion_empresas_n
	* Other Deductions (always from tax base)
gen other_ded_taxbase = .
	* Add up credits & deductions from tax base: 
egen tot_deduc_taxbase = rowtotal(investment_taxbase capital_allowance other_ded_taxbase), missing 

	* Gross tax base (taxable_profit - tot_deduc_taxbase)
gen gross_tax_base = taxable_profit - cond(missing(tot_deduc_taxbase), 0, tot_deduc_taxbase)
	* Net tax base (gross_tax_base - loss_carryforward)
gen net_tax_base_built = gross_tax_base - cond(missing(loss_carryforward), 0, loss_carryforward)
gen net_tax_base = renta_imponible + cond(missing(ganancia_k_imponible), 0, ganancia_k_imponible)
replace net_tax_base = perdida_fiscal*-1 if net_tax_base == 0

* GROUP 5: GROSS & NET TAX LIABILITY
	* Gross tax liability (net tax base*CIT rate)
gen gross_tax_liability = impuesto_sobre_la_renta
	* Credits for foreign taxes paid
gen cred_foreign_tax = .	
	* Investment credits from tax liability
egen investment_taxliab = rowtotal(incentivos_por_inversion_acredit incentivos_inversionesforestales), missing
	* Special firms credits from tax liability
gen special_taxliab = .
	* International Trade credits 
gen trade_taxliab = .
	* Other credit and allowances from tax liability
egen other_cred_taxliab = rowtotal(otros_acreditar_esteperiodo), missing
	* Add up credits & deductions from tax liability 
egen tot_deduc_taxliab = rowtotal(cred_foreign_tax special_taxliab trade_taxliab investment_taxliab other_cred_taxliab), missing
	* Add up credits & deductions that are not necessarily real credits from tax liability 
egen tot_noelse_taxliab = rowtotal(cred_foreign_tax  other_cred_taxliab), missing
	* Net tax liability (gross_tax_liability - tot_deduc_taxliab)
gen net_tax_liability = gross_tax_liability - cond(missing(tot_deduc_taxliab), 0, tot_deduc_taxliab)
	* Net tax liability without foreign and other credits  
gen ntl_noelse = net_tax_liability + cond(missing(tot_noelse_taxliab), 0, tot_noelse_taxliab)

* GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS
	* Add up partial/advance payments
egen partial_advanced_pay = rowtotal(_ietaap_pagado_año_anterior_sald _ietaap_acreditar_esteperiodo _iema_pagado_años_2004_no_acredi iema_pagado_años_2004_acreditar_ is_pagado_año_anterior_saldo_no_ is_pagado_anterior_acreditar_est iset_saldo_noacreditado iset_acreditar_este_periodo), missing
	* Add withholding 
gen withholding = .
	* Other creditable tax payments
gen other_cred_tax_pay = .
	* Tax to remit
gen tax_to_remit = saldodelimpuesto

**** Treatment of missings and 0
foreach var of varlist gross_tax_base net_tax_base gross_tax_liability net_tax_liability tax_to_remit {
    replace `var' = 0 if missing(`var') & !missing(total_income)
}

gen firm_age = edad

	* Create temp file
tempfile annual_06_12
save `annual_06_12'

******************************* Dataset 2: 2015 ******************************
import delimited using "$data/input/Guatemala/GPD_ISR_Anual_2015.txt", clear delim(tab)
duplicates report codigo // No duplicates
	
tempfile annual_15
save `annual_15'

**************************** Dataset 3: 2013-2014 *****************************

import delimited using "$data/input/Guatemala/GPD_ISR_DC10-2012_P2013-2014.txt", clear delim(tab)
duplicates report codigo periodo // No duplicates 
	 
	* Rename variable to make appending easier
rename s_utilidades_total_renta_bruta utilidades_total_renta_bruta 

tempfile annual_13_14
save	`annual_13_14'

******************************* Dataset 4: 2016-2018 ***************************
import delimited "$data/input/Guatemala/ISR_ANUAL_2016_2018.txt", clear
duplicates report clave periodo // No duplicates

tempfile annual_16_18
save	`annual_16_18'

******************************* Dataset 5: 2019-2020 ***************************
import delimited "$data/input/Guatemala/ISR_ANUAL_2019_2020.txt", clear
duplicates report clave periodo // No duplicates

**************************** Append Datasets 2, 3, 4 & 5 ***********************
append using `annual_16_18'
rename (v116 v118 _1_totalcostosygastos) (_cuentas_incobrables_116 _donaciones_118 totalcostosygastos)
rename _* *

tempfile annual_16_20
save	`annual_16_20'

*Need to add data for 2016-2020 years
import delimited "$data/input/Guatemala/PADRON_CONTRIBUYENTES.txt", clear
keep clave edad* nombre18a nombre_tipo municipio

merge 1:m clave using `annual_16_20'
drop if _merge==1
drop _merge

gen tipo_persona="J"
replace tipo_persona="I" if nombre_tipo=="INDIVIDUAL" | nombre_tipo=="EXTRANJERO DIPLOMÁTICO O AGENTE DE ORGANISMO INTERNAC."
replace tipo_persona="" if nombre_tipo==""

gen sector_economico=nombre18a

rename clave codigo

gen afiliacion_isr=""
replace afiliacion_isr="|SOBRE UTILIDADES|" if afiliacion==0 | afiliacion==1
replace afiliacion_isr="|EXENTO|" if afiliacion==2
replace afiliacion_isr="|SOBRE INGRESOS|" if afiliacion==3

gen firm_age=.
replace firm_age=round(edad_2016) if periodo==2016
replace firm_age=round(edad_2017) if periodo==2017
replace firm_age=round(edad_2018) if periodo==2018
replace firm_age=round(edad_2019) if periodo==2019
replace firm_age=round(edad_2020) if periodo==2020

append using `annual_15'
append using `annual_13_14'

******** SELECT AND CREATE VARIABLES ********
* GROUP 0
	* Indentification variables

	* Remove special character
replace tipo_persona = subinstr(tipo_persona, "|", "",.)
replace municipio = subinstr(municipio, "|", "",.)

	* Generate new variables: country name and entity type
generate country = "GTM"
generate entity = ""
replace entity = "Legal" if tipo_persona == "J"
replace entity = "Natural" if tipo_persona == "I"
replace entity = "Unclassified" if tipo_persona == ""	

	* Check for duplicates and drop
duplicates report codigo periodo

* GROUP 1: INCOMES
	* Turnover and other income 
egen turnover = rowtotal(produccion_venta_comercializaci exportacion_bienes exportacion_servicios  prestacion_servicios ventas_exportadores_factura_esp honorarios_profesionales), missing 

gen other_income = utilidades_total_renta_bruta - cond(missing(turnover), 0, turnover) - cond(missing(_rentas_exentas), 0, _rentas_exentas)
	* Exempt income
gen exempt_income = _rentas_exentas

gen dividend_income = .
gen dividend_exempt = .

	* Total income (all income)
gen total_income = utilidades_total_renta_bruta	
egen total_income_built = rowtotal(turnover other_income), missing
replace total_income = total_income_built if missing(total_income)
replace total_income=total_income+exempt_income if total_income==0 & exempt_income>0

	* Taxable income (-exempt income)
gen taxable_income = total_income - cond(missing(exempt_income), 0, exempt_income)

* GROUP 2: COST ITEMS
	* Cost of good solds
gen cogs = costo_de_ventas
	* Labor Inputs
#delimit ;
egen labor_inp = rowtotal( sueldos_salarios_otros 
	 sueldos_socios_consejeros aguinaldos bonificaciones cuotas_patronales_igss 
	 cuotas_irta_intecap asignacion_planes_prevision_soc indemnizaciones 
	 inversion_beneficio_trabajadore tierras_laborables_a_trabajador 
	 prima_seguro_vida_empleados dietas honorarios_comisiones_pais 
	 honorarios_comisiones_extranjer ), missing; 
 #delim cr 
	* Material Inputs
*Inventory : 
gen material_inp = costo_de_ventas
	* Selling, admin and other operating costs
egen operating_inp = rowtotal(gastos_prestacion_servicios viaticos gastos_de_transporte gastos_promocion_publicidad gastos_de_ventas gastos_generales), missing
	* Capital Inputs
egen capital_inp = rowtotal(arrendamiento_bienes_muebles mejoras_arrendatarios gastos_mantenimiento), missing
	* Financial Inputs
egen financial_inp = rowtotal(reaseguros_reafianzamientos impuestos_tasas_contribuciones ///
	 intereses_otros_cargos regalias), missing
	* Depreciation 
egen depreciation = rowtotal(depreciaciones amortizaciones), missing
	* Other Inputs
#delimit ;
egen other_inp = rowtotal(combustibles_lubricantes prima_seguro_incendios_etc
	     perdidas_por_daños perdidas_por_daños cuentas_incobrables_116
	 reservas_tecnicas_matematicas donaciones_118
	 donaciones_estado_universidades excedentes_costos_97 perdidas_cambiarias 
	  ), missing;
#delim cr 
	* Non deductible Inputs
egen non_deduc_inp = rowtotal(costos_gastos_rentas_exentas costos_gastos_rentas_no_afectas costos_gastos_sujeto_retencion costos_gastos_rentas_capital otros_gastos_no_deducibles), missing
 	* Total costs: add up all costs & expenditure
egen tot_cost_built = rowtotal(capital_inp operating_inp material_inp labor_inp financial_inp depreciation other_inp), missing
gen tot_cost_dataset = totalcostosygastos
egen tot_cost = rowmax(tot_cost_built tot_cost_dataset)

	* Deductible Costs: total costs - non-deductible inputs 
gen deductible_cost = tot_cost - cond(missing(non_deduc_inp), 0, non_deduc_inp)   

* GROUP 3: PROFITS
	* Gross profit
gen gross_profit = total_income - cond(missing(cogs), 0, cogs)
	* Net profit
gen net_profit = renta_neta
replace net_profit = -1*perdida_neta if net_profit == 0
gen net_profit_built = total_income - cond(missing(tot_cost), 0, tot_cost)
	* Taxable profit
gen taxable_profit = renta_imponible 
replace taxable_profit = -1*perdida_fiscal if taxable_profit ==0 

* GROUP 4: GROSS & NET TAX BASE
	* Investment Incentives  (From tax base)
gen investment_taxbase = .
	* Capital allowances  (From tax base)
gen capital_allowance = .
	* Losses (always from tax base)
gen loss_carryforward = .
	* Other Deductions (always from tax base)
gen other_ded_taxbase = .
	* Add up credits & deductions from tax base: 
egen tot_deduc_taxbase = rowtotal(investment_taxbase capital_allowance other_ded_taxbase), missing 

	* Gross tax base (taxable_profit - tot_deduc_taxbase)
gen gross_tax_base = taxable_profit - cond(missing(tot_deduc_taxbase), 0, tot_deduc_taxbase)
	* Net tax base (gross_tax_base - loss_carryforward)
gen net_tax_base_built = gross_tax_base - cond(missing(loss_carryforward), 0, loss_carryforward)
gen net_tax_base = taxable_profit

* GROUP 5: GROSS & NET TAX LIABILITY
	* Gross tax liability (net tax base*CIT rate)
gen gross_tax_liability = determinacion_isr
gen gross_tax_liab_built = net_tax_base*0.25 if periodo >= 2015 & periodo <= 2020
replace gross_tax_liab_built = net_tax_base*0.28 if periodo == 2014
replace gross_tax_liab_built = net_tax_base*0.31 if periodo < 2014
replace gross_tax_liab_built = 0 if net_tax_base<0
	* Credits for foreign taxes paid
gen cred_foreign_tax = .	
	* Investment credits from tax liability
egen investment_taxliab = rowtotal(_incentivo_fuentes_energia_acre _incentivos_forestales_acredita ), missing
	* Special firms credits from tax liability
gen special_taxliab = .
	* International Trade credits 
gen trade_taxliab = .
	* Other credit and allowances from tax liability
egen other_cred_taxliab = rowtotal(_otros_resolucion_acreditar incentivos_fiscales_2989_valor), missing
	* Add up credits & deductions from tax liability 
egen tot_deduc_taxliab = rowtotal(cred_foreign_tax special_taxliab trade_taxliab investment_taxliab other_cred_taxliab), missing
	* Add up credits & deductions that are not necessarily real credits from tax liability 
egen tot_noelse_taxliab = rowtotal(cred_foreign_tax  other_cred_taxliab), missing
	* Net tax liability (gross_tax_liability - tot_deduc_taxliab)
gen net_tax_liability = gross_tax_liability - cond(missing(tot_deduc_taxliab), 0, tot_deduc_taxliab)
gen net_tax_lia_built = saldo_impuesto
	* Net tax liability without foreign and other credits  
gen ntl_noelse = net_tax_liability + cond(missing(tot_noelse_taxliab), 0, tot_noelse_taxliab)

* GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS
	* Add up partial/advance payments
egen partial_advanced_pay = rowtotal(_pagos_trimestrales _pagos_en_exceso), missing
	* Add withholding 
gen withholding = .
	* Other creditable tax payments
egen other_cred_tax_pay = rowtotal(_iso_a_acreditar _ietaap_a_acreditar ///
	 _iema_a_acreditar), missing 
	* Tax to remit
gen tax_to_remit = impuesto_sobre_la_renta

**** Treatment of missings and 0
foreach var of varlist gross_tax_base net_tax_base gross_tax_liability net_tax_liability tax_to_remit {
    replace `var' = 0 if missing(`var') & !missing(total_income)
}

************************** Append Datasets 1, 2, 3, 4 & 5 **********************
append using `annual_06_12'

	* Final adjustments to the data
sort codigo periodo, stable
rename periodo year
rename codigo tax_ID
gen total_assets = total_activos

drop if afiliacion_isr == "|SOBRE INGRESOS|" |  afiliacion_isr == "|EXENTO|" 
drop if entity == "Unclassified"

********* Add labels and drop some variables ********
label variable tax_ID "Tax ID"
label variable year "Fiscal Year"
label variable turnover "Turnover"
label variable total_income "Total income"
label variable taxable_income "Taxable income"
label variable tot_cost "Total Costs"
label variable deductible_cost "Deductible Costs"
label variable net_profit "Net profit"
label variable taxable_income "Taxable profit"
label variable gross_tax_base "Gross Tax Base"
label variable tot_deduc_taxbase "Total Credits & Deductions - Tax Base"
label variable net_tax_base "Net Tax Base"
label variable gross_tax_liability "Gross Tax Liability"
label variable net_tax_liability "Net Tax Liability"
label variable tot_deduc_taxliab "Total Credits & Deductions - Tax Liability"
label variable tax_to_remit "Tax to Remit"
label variable country "Country"

********* Add labels and drop some variables ********

	* Standardize sectors. we are using CIIU 4
replace sector_economico = "L" if sector_economico == "|ACTIVIDADES INMOBILIARIAS, EMPRESARIALES Y DE ALQUILERES|" | sector_economico == "Actividades inmobiliarias, empresariales y de alquiler"
replace sector_economico = "O" if sector_economico == "|ADMINISTRACION PUBLICA Y DEFENSA; PLANES DE SEGURIDAD|" | sector_economico == "Administración pública y defensa; planes de seguridad social"
replace sector_economico = "A" if sector_economico == "|AGRICULTURA, GANADERIA, CAZA Y SILVICULTURA|" | sector_economico == "Agricultura, ganadería, caza y silvicultura"
replace sector_economico = "G" if sector_economico == "|COMERCIO AL POR MAYOR Y MENOR|" | sector_economico == "Comercio al por mayor y menor"
replace sector_economico = "F" if sector_economico == "|CONSTRUCCION|" | sector_economico == "Construcción"
replace sector_economico = "S" if sector_economico == "|EMPLEADOS EN RELACION DE DEPENDENCIA, ESTUDIANTES |" | sector_economico == "Empleados en relación de dependencia, estudiantes"
replace sector_economico = "P" if sector_economico == "|ENSEÑANZA|" | sector_economico == "Enseñanza"
replace sector_economico = "B" if sector_economico == "|EXPLOTACION DE MINAS Y CANTERAS|" | sector_economico == "Explotación de minas y canteras"
replace sector_economico = "T" if sector_economico == "|HOGARES PRIVADOS CON SERVICIO DOMESTICO|" | sector_economico == "Hogares privados con servicio doméstico"
replace sector_economico = "I" if sector_economico == "|HOTELES Y RESTAURANTES|" | sector_economico == "Hoteles y restaurantes"
replace sector_economico = "C" if sector_economico == "|INDUSTRIAS|" | sector_economico == "Industrias"
replace sector_economico = "K" if sector_economico == "|INTERMEDIACION FINANCIERA|" | sector_economico == "Intermediación financiera"
replace sector_economico = "U" if sector_economico == "|ORGANIZACIONES Y ORGANOS EXTRATERRITORIALES|" | sector_economico == "Organizaciones y órganos extraterritoriales"
replace sector_economico = "M" if sector_economico == "|OTRAS ACTIVIDADES DE SERVICIOS COMUNITARIOS, SOCIALES|" | sector_economico == "Otras actividades de servicios comunitarios, sociales y profesionales"
replace sector_economico = "S" if sector_economico == "|OTRAS ACTIVIDADES NO ESPECIFICADAS ANTERIORMENTE|" | sector_economico == "Otras actividades no especificadas anteriormente"
replace sector_economico = "Q" if sector_economico == "|SERVICIOS SOCIALES Y DE SALUD|" | sector_economico == "Servicios sociales y de salud"
replace sector_economico = "D" if sector_economico == "|SUMINISTRO DE ELECTRICIDAD, GAS Y AGUA|" | sector_economico == "Suministro de electricidad, gas y agua"
replace sector_economico = "H" if sector_economico == "|TRANSPORTE, ALMACENAMIENTO Y COMUNICACIONES|" | sector_economico == "Transporte, almacenamiento y comunicaciones"

rename sector_economico section // Will be necessary when merging

keep if entity == "Legal"

tempfile legal_GTM
save `legal_GTM'

	* We will read the CIIU4 file and then merge it with CIT variables. 
use "$data/input/Guatemala/CIIU4_firmsectors.dta", clear
duplicates drop section, force
drop division descr_division

	* Final adjsutments and save
merge 1:m section using `legal_GTM'
drop if _merge == 1 // 5 observations
drop _merge
order section descr_section, after(entity)

* GROUP 7: FIRM CHARACTERISTICS
gen city = municipio
gen capital_city = 0
replace capital_city = 1 if municipio=="Guatemala"	
replace capital_city = . if municipio=="" 

*gen firm_age = .
gen incorporation = .
replace incorporation = year - firm_age
gen first_year = 0
replace first_year = 1 if firm_age <2 & firm_age != .

* STR:
gen STR = .
replace STR = 0.25 if year >= 2015
replace STR = 0.28 if year == 2014
replace STR = 0.31 if year <= 2013

************* KEEP VARIABLES WE NEED *************
	* Create locals to keep variables
local group0 year country tax_ID entity section  descr_section 
local group1 turnover exempt_income other_income total_income taxable_income dividend_income dividend_exempt
local group2 tot_cost *_inp deductible_cost depreciation acc_depreciation cogs
local group3 taxable_profit net_profit gross_profit
local group4 investment_taxbase capital_allowance loss_carryforward other_ded_taxbase net_tax_base gross_tax_base tot_deduc_taxbase
local group5 gross_tax_liability net_tax_liability tot_deduc_taxliab cred_foreign_tax investment_taxliab other_cred_taxliab 
local group6 withholding partial_advanced_pay other_cred_tax_pay tax_to_remit ntl_noelse tot_noelse_taxliab special_taxliab trade_taxliab
local group7 capital_city incorporation firm_age city total_assets first_year STR incentivos_fiscales_2989_valor

	* Keep selected variables
keep  `group0' `group1' `group2' `group3' `group4' `group5' `group6' `group7' 

    * Adjustement
replace total_income = turnover if total_income<turnover	

* Save
sort tax_ID year, stable
export delimited using "$data/output/Guatemala/GTM_withvars.csv", replace 