*===============================================================================
* File name: 		CIT_JAM.do
* 
* Description:		This do-file creates the dataset JAM_withvars.csv. 
*
* Input:  					
*					$data/input/Jamaica/CIT_2018_2022.xlsx
*					$data/input/Jamaica/CIT_Sch_1_2018_2022.xlsx 
*					$data/input/Jamaica/WB_OECD_ORBIS_Match.xlsx 
*					$data/input/Jamaica/JAM_SEZ.dta 
*					$data/input/Jamaica/SO2.dta 
*					$data/input/Jamaica/AT01_AT02_Assets_16_18.dta
*					$data/input/Jamaica/sch1_ally.dta
*
* Output:
*					$data/output/Jamaica/JAM_withvars.csv
*===============================================================================

cls
capture restore
set more off
cap log close
clear all

*****************************************************************************
**************************** LEGAL ENTITIES *********************************
*****************************************************************************

/* ----------------------------------- */
/* Import 2018-2019 Annual Return data */
/* ----------------------------------- */

/* Load data */
import excel using "$data/input/Jamaica/CIT_2018_2022.xlsx", clear sh("IT02v4_2018-2019") first

/* Destring variables */
ds ANON_ID Period IncentiveAct, not

foreach v of var `r(varlist)' { 
	destring `v', replace
}

/* Generate year variable */
gen year=substr(Period,7,4)
order year, a(Period)
destring year, replace

/* Check duplicates */
duplicates report ANON_ID year

bys ANON_ID year: gen N=_N
order N, a(year)
sort N ANON_ID year

duplicates report if N==2
duplicates drop

/* Save full temp file */
tempfile cit_2018_2019
save `cit_2018_2019'
save "$data/input/Jamaica/cit_2018_2019.dta", replace

/* ----------------------------------- */
/* Import 2020-2021 Annual Return data */
/* ----------------------------------- */

/* Load data */
import excel using "$data/input/Jamaica/CIT_2018_2022.xlsx", clear sh("IT02v5_2020-2021") first

/* Generate year variable */
gen year=substr(Period,7,4)
order year, a(Period)
destring year, replace

/* Check duplicates */
duplicates report ANON_ID year
// 28 duplicates

bys ANON_ID year: gen N=_N
order N, a(year)
sort N ANON_ID year

duplicates report if N==2
duplicates drop

/* Save full temp file */
tempfile cit_2020_2021
save `cit_2020_2021'
save "$data/input/Jamaica/cit_2020_2021.dta", replace

/* ------------------------------ */
/* Import 2022 Annual Return data */
/* ------------------------------ */

/* Load data */
import excel using "$data/input/Jamaica/CIT_2018_2022.xlsx", clear sh("IT02v6_2022") first

/* Generate year variable */
gen year=substr(Period,7,4)
order year, a(Period)
destring year, replace

/* Check duplicates */
duplicates report ANON_ID year

bys ANON_ID year: gen N=_N
order N, a(year)
sort N ANON_ID year

duplicates report if N==2

duplicates drop

/* Save full temp file */
tempfile cit_2022
save `cit_2022'
save "$data/input/Jamaica/cit_2022.dta", replace

/* ---------------------- */
/* Import Schedule 1 data */
/* ---------------------- */

/* Load data */
import excel using "$data/input/Jamaica/CIT_Sch_1_2018_2022.xlsx", clear first

/* Generate year variable */
gen year=year(ReturnFilingPeriod)
order year, a(ReturnFilingPeriod)
destring year, replace

/* Check duplicates */
duplicates report ANON_ID year

/* Rename variables */
ren * *_sch1
ren ANON_ID_sch1 ANON_ID
ren year_sch1 year

/* Save full temp file */
tempfile sch1_ally
save `sch1_ally'
save "$data/input/Jamaica/sch1_ally.dta", replace

/* ------------------------------- */
/* Merge IDs to verify consistency */
/* ------------------------------- */

use "$data/input/Jamaica/cit_2018_2019.dta", clear

append using "$data/input/Jamaica/cit_2020_2021.dta"
append using "$data/input/Jamaica/cit_2022.dta" 

merge 1:1 ANON_ID year using "$data/input/Jamaica/sch1_ally.dta"

drop if _merge==2
drop _merge

/* --------------------------- */
/* SELECT AND CREATE VARIABLES */
/* --------------------------- */

/* STR */
gen STR = .25

/* GROUP 0 */
gen tax_ID=ANON_ID
gen country = "JAM"

generate entity = ""
replace entity = "Legal"

gen total_assets = .

/* ---------------- */
/* GROUP 1: INCOMES */
/* ---------------- */

* Turnover and other income 
gen turnover = GrossReceipts

egen other_income = rowtotal(SharofPartnershipInc GrossRental TotalIncomeFromOther DividendsReceived), missing 

* Exempt income
egen exempt_income = rowtotal(Exemptions FrankedIncome), missing

egen dividend_income_18_19 = 	rowtotal(GrossPreferenceDivid FrankedIncome UnFrankedIncome Dividends) if year<2020, missing
egen dividend_income_20_21_22 = rowtotal(GrossPreferenceDivid FrankedIncome DividendsReceived Dividends) if year>2019, missing

gen unfranked_dividends=UnFrankedIncome
replace unfranked_dividends=DividendsReceived if year>2019

gen dividend_income = dividend_income_18_19
replace dividend_income = dividend_income_20_21_22 if year>2019

gen dividend_exempt = FrankedIncome

* Total income (all income): items 1+8+9+24+26
egen total_income = rowtotal(GrossReceipts SharofPartnershipInc GrossRental TotalIncomeFromOther DividendsReceived), missing

* Taxable income (-exempt income)
gen taxable_income = total_income - cond(missing(exempt_income), 0, exempt_income)

/* ------------------- */
/* GROUP 2: COST ITEMS */
/* ------------------- */

* Cost of good solds
gen cogs = CostOfGoodsSold

replace SalariesWages_sch1=0 if SalariesWages_sch1==.
egen labor_inp = rowmax(TotalGrossWages SalariesWages_sch1)

*Inventory
gen material_inp = CostOfGoodsSold

* Selling, admin and other operating costs
gen operating_inp = BusAdminExpenses

* Capital Inputs
gen capital_inp = RentalExpenses

* Financial Inputs
gen financial_inp = .

* Depreciation 
gen depreciation = TotalCapitalAllowanc if year<2020
replace depreciation = CapitalAllowances if year>2019

gen acc_depreciation = .

* Other Inputs
egen other_inp = rowtotal(CovenantedDonations OtherDonations), missing

* Non deductible Inputs
gen non_deduc_inp = NetAdjustments

* Total cost (all costs): items 2+4+10+28
egen tot_cost = rowtotal(CostOfGoodsSold BusAdminExpenses RentalExpenses TotalGrossWages), missing

* Deductible Costs: total costs - non-deductible inputs 
gen deductible_cost = tot_cost - cond(missing(non_deduc_inp), 0, non_deduc_inp)   

/* ---------------- */
/* GROUP 3: PROFITS */
/* ---------------- */

* Gross profit
gen gross_profit = total_income - cond(missing(cogs), 0, cogs)

* Net profit
gen net_profit=total_income-tot_cost

gen net_profit_built = .

* Taxable profit
gen taxable_profit = TotalIncomeUnfranked+unfranked_dividends if year>2019
replace taxable_profit = TotalIncomeFromAllSo+unfranked_dividends if year<2020

/* ----------------------------- */
/* GROUP 4: GROSS & NET TAX BASE */
/* ----------------------------- */

	* Investment Incentives  (From tax base)
gen investment_taxbase = .
	
	* Capital allowances  (From tax base)
gen capital_allowance = .
	
	* Losses (always from tax base)
gen loss_carryforward = AllowableLossDeducti
replace loss_carryforward = AllowableLoss if year>2019
	
	* Other Deductions (always from tax base)
gen other_ded_taxbase = .
	
	* Add up credits & deductions from tax base: 
egen tot_deduc_taxbase = rowtotal(investment_taxbase capital_allowance other_ded_taxbase), missing 

	* Gross tax base (taxable_profit - tot_deduc_taxbase)
gen gross_tax_base = taxable_profit - cond(missing(tot_deduc_taxbase), 0, tot_deduc_taxbase)
	
	* Net tax base
gen net_tax_base = 		TaxOnDividends+TaxOnChargeableIncom if year<2020
replace net_tax_base =  GrossDividendUnfranked+ChargeableIncomeUnfranked if year>2019

/* -------------------------------------------------------------- */
/* GROUP 5: GROSS TAX LIABILITY (GTL) AND NET TAX LIABILITY (NTL) */
/* -------------------------------------------------------------- */

* Gross tax liability
gen 	gross_tax_liability= TotalTaxPayableOnChargeab if year>2019
replace gross_tax_liability= TaxPayableOnChargeab if year<2020

* Credits for foreign taxes paid
gen cred_foreign_tax = DoubleTaxationRelief

* Investment credits from tax liability
egen investment_taxliab = rowtotal(CorporateTaxCredit), missing

* Special firms credits from tax liability
gen special_taxliab = .

* International Trade credits 
gen trade_taxliab = .

* Other credit and allowances from tax liability
egen other_cred_taxliab = rowtotal(ContractorsLevy EmploymentTaxCredit TaxReliefRespectOfOt TaxDeductedDividend OtherNonRefundableTa), missing

* Add up credits & deductions from tax liability 
egen tot_deduc_taxliab = rowtotal(cred_foreign_tax special_taxliab trade_taxliab investment_taxliab other_cred_taxliab), missing

* Add up credits & deductions that are not necessarily real credits from tax liability 
egen tot_noelse_taxliab = rowtotal(cred_foreign_tax  other_cred_taxliab), missing

* Net tax liability
gen net_tax_liability = gross_tax_liability-TotalNonRefundableCr

* Net tax liability without foreign and other credits  
gen ntl_noelse = .

/* ------------------------------------------------------------------------------- */
/* GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS */
/* ------------------------------------------------------------------------------- */

* Add up partial/advance payments
egen partial_advanced_pay = rowtotal(TaxDeductedFromDistr TaxDueOnDividends ThreePercentTaxWithh OtherRefundableTaxCr), missing

* Add withholding 
gen withholding = AmountAvailableAsTax

* Other creditable tax payments
egen other_cred_tax_pay = rowtotal(MBTPaid EstimatedTaxPaid), missing 

* Tax to remit
gen tax_to_remit = TaxBalancePayable

**** Treatment of missings and 0
foreach var of varlist gross_tax_base net_tax_base gross_tax_liability net_tax_liability tax_to_remit {
    replace `var' = 0 if missing(`var') & !missing(total_income)
}

/* Total refundable and non-refundable tax credits */
gen total_refundable_credits=TotalRefundableCredi
gen total_non_refundable_credits=TotalNonRefundableCr

/* ----------------------------- */
/* GROUP 7: FIRM CHARACTERISTICS */
/* ----------------------------- */

gen city = .
gen capital_city = .
gen incorporation = .
gen first_year = .
gen firm_age = .

/* --------------- */
/* Label variables */
/* --------------- */

label variable tax_ID "Tax ID"
label variable year "Fiscal Year"
label variable turnover "Turnover"
label variable total_income "Total income"
label variable taxable_income "Taxable income"
label variable tot_cost "Total Costs"
label variable deductible_cost "Deductible Costs"
label variable net_profit "Net profit"
label variable taxable_income "Taxable profit"
label variable gross_tax_base "Gross Tax Base"
label variable tot_deduc_taxbase "Total Credits & Deductions - Tax Base"
label variable net_tax_base "Net Tax Base"
label variable gross_tax_liability "Gross Tax Liability"
label variable net_tax_liability "Net Tax Liability"
label variable tot_deduc_taxliab "Total Credits & Deductions - Tax Liability"
label variable tax_to_remit "Tax to Remit"
label variable country "Country"

/* ------------------------------- */
/* Create locals to keep variables */
/* ------------------------------- */

local group0 year country tax_ID entity /*section  descr_section*/
local group1 turnover exempt_income other_income total_income taxable_income dividend_income dividend_exempt
local group2 tot_cost *_inp deductible_cost depreciation acc_depreciation cogs
local group3 taxable_profit net_profit gross_profit
local group4 investment_taxbase capital_allowance loss_carryforward other_ded_taxbase net_tax_base gross_tax_base tot_deduc_taxbase
local group5 gross_tax_liability net_tax_liability tot_deduc_taxliab cred_foreign_tax investment_taxliab other_cred_taxliab total_refundable_credits total_non_refundable_credits
local group6 withholding partial_advanced_pay other_cred_tax_pay tax_to_remit ntl_noelse tot_noelse_taxliab special_taxliab trade_taxliab
local group7 capital_city incorporation firm_age city total_assets first_year STR

* Keep selected variables
keep  `group0' `group1' `group2' `group3' `group4' `group5' `group6' `group7'

/* --------------------- */
/* ADD ORBIS INFORMATION */
/* --------------------- */
preserve
import excel "$data/input/Jamaica/WB_OECD_ORBIS_Match.xlsx", clear first case(preserve)
drop if ANON_ID==""
duplicates report ANON_ID
bys ANON_ID: gen N=_N
duplicates drop ANON_ID, force
drop source_list0WB1OECD2both N
ren ANON_ID tax_ID
tempfile temp
save `temp', replace
restore

merge m:1 tax_ID using `temp'
drop if _merge==2
drop _merge

gen group=GUO_ANON_ID
gen orbis_match=(GUO_ANON_ID!=.)

drop GUO_ANON_ID

/* Sector data */
split NACE_section, p(-) generate(sec_)
ren sec_1 section
drop sec_2 sec_3
replace section="S" if section=="Other service activities (includes real estate activities)"
replace section=subinstr(section, " ", "", .)

/* -------------------------------------------- */
/* ADDITIONAL VARIABLES FOR THE GMT COMPUTATION */
/* -------------------------------------------- */
gen nb_employee=.
gen tangible_assets=.
gen foreign_ownership=.

/* ------------ */
/* SAVE DATASET */
/* ------------ */

sort tax_ID year, stable
save "$data/temp/Jamaica/JAM_withvars.dta", replace

/* ----------------------------- */
/* RUN SEZ DATA CLEANING DO-FILE */
/* ----------------------------- */

include "$code/cleaning/CIT_JAM_SEZ.do"

/* --------------- */
/* APPEND SEZ DATA */
/* --------------- */
use "$data/temp/Jamaica/JAM_withvars.dta", clear

/* Append SEZ data */
append using "$data/input/Jamaica/JAM_SEZ.dta"

gen orbis_match_plus=orbis_match
replace orbis_match_plus=1 if sez==1
replace sez=0 if sez==.

/* SAVE DATASET */
sort tax_ID year, stable
save "$data/temp/Jamaica/JAM_withvars.dta", replace

/* --------------------------------- */
/* RUN PAYROLL DATA CLEANING DO-FILE */
/* --------------------------------- */

include "$code/cleaning/SO2_JAM.do"

/* ------------------------------- */
/* RUN ASSET DATA CLEANING DO-FILE */
/* ------------------------------- */

include "$code/cleaning/AT01_AT02_JAM.do"

/* ------------------ */
/* MERGE PAYROLL DATA */
/* ------------------ */
use "$data/temp/Jamaica/JAM_withvars.dta", clear

/* Merge payroll data */
merge 1:1 year tax_ID using "$data/input/Jamaica/SO2.dta"
drop if _merge==2
drop _merge

replace total_payroll_s02=0 if total_payroll_s02==.

summ labor_inp total_payroll_s02

/* Compare to current labor_inp variable */
count if labor_inp>total_payroll_s02 
count if labor_inp==total_payroll_s02 
count if labor_inp<total_payroll_s02 

replace labor_inp=total_payroll_s02 if labor_inp<total_payroll_s02

/* ----------------- */
/* MERGE ASSETS DATA */
/* ----------------- */

/* Keep old asset variable for now */
cap drop tangible_assets
cap drop OverseasCompany
cap drop tangible_assets_at
cap drop form 
cap drop sh_fixed

gen tangible_assets=.

merge m:1 tax_ID using "$data/input/Jamaica/AT01_AT02_Assets_16_18.dta"
drop if _merge==2
drop _merge

/* Mean share of fixed assets by income */
egen deciles_inc = xtile(total_income) if orbis_match==1, nq(10)

preserve
keep if orbis_match==1
keep if sh_fixed!=.
keep if form=="AT01"
collapse (mean) sh_fixed, by(deciles_inc)
ren sh_fixed m_sh_fixed
tempfile temp
save `temp', replace
restore

merge m:1 deciles_inc using `temp'
drop if _merge==2
drop _merge

replace tangible_assets=tangible_assets_at
replace tangible_assets=tangible_assets*m_sh_fixed if form=="AT01 16/17" & orbis_match==1 

replace foreign_ownership=1 if OverseasCompany==1
replace foreign_ownership=1 if orbis_match==1
replace foreign_ownership=0 if foreign_ownership==.

label var sh_fixed "Share of fixed assets out of total assets"
label var m_sh_fixed "Mean share of fixed assets by income decile"
label var form "Assets data form available"

drop deciles_inc

bys year: egen deciles_inc = xtile(total_income), nq(10)

preserve
keep if year==2018
keep if tangible_assets_at!=.
gen sh_asset_inc=tangible_assets_at/total_income
keep if total_income>0
collapse (mean) sh_asset_inc, by(deciles_inc)
tempfile temp 
save `temp', replace
restore

merge m:1 deciles_inc using `temp'
keep if _merge==3
drop _merge

gen assets_imputation=sh_asset_inc*total_income
replace tangible_assets=assets_imputation if tangible_assets==.

/* SAVE DATASET */
sort tax_ID year, stable
export delimited using "$data/output/Jamaica/JAM_withvars.csv", replace