*===============================================================================
* File name: 		CIT_JAM_SEZ.do
* 
* Description:		This do-file creates the dataset SO2.dta. 
*
* Input:  					
*					$data/input/Jamaica/IT15_2018-2022.xlsx
*					$data/input/Jamaica/sch1_ally.dta
*					$data/input/Jamaica/WB_OECD_ORBIS_Match.xlsx
*
* Output:
*					$data/input/Jamaica/JAM_SEZ.dta
*===============================================================================

cls
capture restore
set more off
cap log close
clear all

/* ----------------------------------- */
/* Import 2018-2022 Annual Return data */
/* ----------------------------------- */

/* Load data */
import excel using "$data/input/Jamaica/IT15_2018-2022.xlsx", clear first

/* Generate year variable */
gen year=year(ReturnFilingPeriod)
duplicates report ANON_ID year

/* SELECT AND CREATE VARIABLES */

/* STR */
gen STR = .25

/* GROUP 0 */
gen tax_ID=ANON_ID
gen country = "JAM"

generate entity = ""
replace entity = "Legal"

gen total_assets = .

/* Tangible assets variable */
gen tangible_assets= .

/* ---------------- */
/* GROUP 1: INCOMES */
/* ---------------- */

* Turnover and other income 
gen turnover = GrossReceipts
egen other_income = rowtotal(GrossRentalIncome GrossRentalIncomeConnected GrossInterestRecv Annuity OtherInvestIncome OtherDistributions TotalIncomeOffIsland OtherIncomeUnstated), missing 

* Exempt income
egen exempt_income = rowtotal(OtherExemptions GrossDividendsInvest), missing
egen dividend_income = 	rowtotal(GrossPrefDividend GrossDividendsInvest) if year<2020, missing
gen unfranked_dividends=GrossPrefDividend+GrossDividendsUnfranked
gen dividend_exempt = GrossDividendsInvest

* Total income (all income):
egen total_income = rowtotal(turnover other_income), missing

* Taxable income (-exempt income)
gen taxable_income = total_income - cond(missing(exempt_income), 0, exempt_income)

/* ------------------- */
/* GROUP 2: COST ITEMS */
/* ------------------- */

* Cost of good solds
gen cogs = CostOfGoodsSold

gen labor_inp = .

/* Merge Schedule 1 data */
preserve
use "$data/input/Jamaica/sch1_ally.dta", clear
collapse (mean) SalariesWages_sch1, by(ANON_ID)
keep SalariesWages_sch1 ANON_ID
ren SalariesWages_sch1 sch1wages
tempfile temp
save `temp', replace
restore

merge m:1 ANON_ID using `temp'
drop if _merge==2
drop _merge

replace labor_inp=sch1wages if labor_inp==.

*Inventory
gen material_inp = CostOfGoodsSold

* Selling, admin and other operating costs
gen operating_inp = BusAdminExpense

* Capital Inputs
gen capital_inp = RentalExpenses+RentalExpensesConnected

* Financial Inputs
gen financial_inp = .

* Depreciation 
gen depreciation = CapitalAllowances

gen acc_depreciation = .

* Other Inputs
egen other_inp = rowtotal(CovenantedDonations), missing

* Non deductible Inputs
gen non_deduc_inp = NetAdjustment

* Total cost (all costs): items 2+4+10+28
egen tot_cost = rowtotal(CostOfGoodsSold BusAdminExpense RentalExpenses RentalExpensesConnected), missing

* Deductible Costs: total costs - non-deductible inputs 
gen deductible_cost = tot_cost - cond(missing(non_deduc_inp), 0, non_deduc_inp)   

/* ---------------- */
/* GROUP 3: PROFITS */
/* ---------------- */

* Gross profit
gen gross_profit = total_income - cond(missing(cogs), 0, cogs)

* Net profit
gen net_profit=total_income-tot_cost

gen net_profit_built = .

* Taxable profit
gen taxable_profit = ChargeableIncome

/* ----------------------------- */
/* GROUP 4: GROSS & NET TAX BASE */
/* ----------------------------- */

	* Investment Incentives  (From tax base)
gen investment_taxbase = .
	
	* Capital allowances  (From tax base)
gen capital_allowance = .
	
	* Losses (always from tax base)
gen loss_carryforward = AllowableLoss

	* Other Deductions (always from tax base)
gen other_ded_taxbase = .
	
	* Add up credits & deductions from tax base: 
egen tot_deduc_taxbase = rowtotal(investment_taxbase capital_allowance other_ded_taxbase), missing 

	* Gross tax base (taxable_profit - tot_deduc_taxbase)
gen gross_tax_base = taxable_profit - cond(missing(tot_deduc_taxbase), 0, tot_deduc_taxbase)
	
	* Net tax base
gen net_tax_base = ChargeableIncome

/* -------------------------------------------------------------- */
/* GROUP 5: GROSS TAX LIABILITY (GTL) AND NET TAX LIABILITY (NTL) */
/* -------------------------------------------------------------- */

* Gross tax liability
gen 	gross_tax_liability=TotalTaxPayable

* Credits for foreign taxes paid
gen cred_foreign_tax = .

* Investment credits from tax liability
egen investment_taxliab = rowtotal(PromotionalTaxCredit), missing

* Special firms credits from tax liability
gen special_taxliab = .

* International Trade credits 
gen trade_taxliab = .

* Other credit and allowances from tax liability
egen other_cred_taxliab = rowtotal(EmployeeTaxCredit), missing

* Add up credits & deductions from tax liability 
gen tot_deduc_taxliab = TotalNonRefundableCredit

* Add up credits & deductions that are not necessarily real credits from tax liability 
egen tot_noelse_taxliab = rowtotal(cred_foreign_tax  other_cred_taxliab), missing

* Net tax liability
gen net_tax_liability = gross_tax_liability-tot_deduc_taxliab

* Net tax liability without foreign and other credits  
gen ntl_noelse = .

/* ------------------------------------------------------------------------------- */
/* GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS */
/* ------------------------------------------------------------------------------- */

* Add up partial/advance payments
gen partial_advanced_pay = .

* Add withholding 
gen withholding = .

* Other creditable tax payments
gen other_cred_tax_pay = .

* Tax to remit
gen tax_to_remit = NetTax

**** Treatment of missings and 0
foreach var of varlist gross_tax_base net_tax_base gross_tax_liability net_tax_liability tax_to_remit {
    replace `var' = 0 if missing(`var') & !missing(total_income)
}

/* Total refundable and non-refundable tax credits */
gen total_refundable_credits=TotalRefundableCredit
gen total_non_refundable_credits=TotalNonRefundableCredit

/* ----------------------------- */
/* GROUP 7: FIRM CHARACTERISTICS */
/* ----------------------------- */
gen city = .
gen capital_city = .
gen incorporation = .
gen first_year = .
gen firm_age = .

/* --------------- */
/* Label variables */
/* --------------- */
label variable tax_ID "Tax ID"
label variable year "Fiscal Year"
label variable turnover "Turnover"
label variable total_income "Total income"
label variable taxable_income "Taxable income"
label variable tot_cost "Total Costs"
label variable deductible_cost "Deductible Costs"
label variable net_profit "Net profit"
label variable taxable_income "Taxable profit"
label variable gross_tax_base "Gross Tax Base"
label variable tot_deduc_taxbase "Total Credits & Deductions - Tax Base"
label variable net_tax_base "Net Tax Base"
label variable gross_tax_liability "Gross Tax Liability"
label variable net_tax_liability "Net Tax Liability"
label variable tot_deduc_taxliab "Total Credits & Deductions - Tax Liability"
label variable tax_to_remit "Tax to Remit"
label variable country "Country"

/* ------------------------------- */
/* Create locals to keep variables */
/* ------------------------------- */

local group0 year country tax_ID entity
local group1 turnover exempt_income other_income total_income taxable_income dividend_income dividend_exempt
local group2 tot_cost *_inp deductible_cost depreciation acc_depreciation cogs
local group3 taxable_profit net_profit gross_profit
local group4 investment_taxbase capital_allowance loss_carryforward other_ded_taxbase net_tax_base gross_tax_base tot_deduc_taxbase
local group5 gross_tax_liability net_tax_liability tot_deduc_taxliab cred_foreign_tax investment_taxliab other_cred_taxliab total_refundable_credits total_non_refundable_credits
local group6 withholding partial_advanced_pay other_cred_tax_pay tax_to_remit ntl_noelse tot_noelse_taxliab special_taxliab trade_taxliab
local group7 capital_city incorporation firm_age city total_assets first_year
local group8 STR tangible_assets

* Keep selected variables
keep  `group0' `group1' `group2' `group3' `group4' `group5' `group6' `group7'  `group8'

/* --------------------- */
/* ADD ORBIS INFORMATION */
/* --------------------- */
preserve
import excel "$data/input/Jamaica/WB_OECD_ORBIS_Match.xlsx", clear first case(preserve)
drop if ANON_ID==""
duplicates report ANON_ID
bys ANON_ID: gen N=_N
duplicates drop ANON_ID, force
drop source_list0WB1OECD2both N
ren ANON_ID tax_ID
tempfile temp
save `temp', replace
restore

merge m:1 tax_ID using `temp'
drop if _merge==2
drop _merge

gen group=GUO_ANON_ID
gen orbis_match=(GUO_ANON_ID!=.)

drop GUO_ANON_ID

/* Sector data */
split NACE_section, p(-) generate(sec_)
ren sec_1 section
drop sec_2
replace section="S" if section=="Other service activities (includes real estate activities)"
replace section=subinstr(section, " ", "", .)

/* -------------------------------------------- */
/* ADDITIONAL VARIABLES FOR THE GMT COMPUTATION */
/* -------------------------------------------- */
gen nb_employee=.
gen foreign_ownership=.

replace foreign_ownership=0
replace foreign_ownership=1 if orbis_match==1

/* SEZ indicator */
gen sez=1
gen sez_not_orbis=(orbis_match!=1)

/* ------------ */
/* SAVE DATASET */
/* ------------ */

sort tax_ID year, stable
save "$data/input/Jamaica/JAM_SEZ.dta", replace