*===============================================================================
* File name: 		CIT_RWA.do
* 
* Description:		This do-file creates the dataset RWA_withvars.csv. 
*
* Input:  					
*					$data/input/Rwanda/CIT `i'.csv 
*					$data/input/Rwanda/CIT 2020.xlsx
*
* Output:
*					$data/output/Rwanda/RWA_withvars.csv
*===============================================================================

cls
capture restore
set more off
cap log close
clear all

*****************************************************************************
**************************** LEGAL ENTITIES *********************************
*****************************************************************************

*	1. IMPORT DATA
forvalues  i=2010/2017 {
	
	 di in red "YEAR: `i'"

	insheet using "$data/input/Rwanda/CIT `i'.csv", clear
	cap gen str submissiondate_str = string(submissiondate , "%tcnn/dd/ccYY_hh:MM")	
	cap rename submissiondate submissiondate_str
	cap tostring taxperiodduedate, replace

foreach v of varlist businessincome-creditclaimed {
	 
	cap replace `v' = "." if `v'==""
	cap replace `v' = subinstr(`v', ",", "", .) 
	cap destring `v', replace
}

*	2. ADJUSTING VARIABLES
	generate country = "RWA"
	generate entity = "Legal"	
    cap rename tin tax_ID
	cap rename anonymisedtin tax_ID
	cap rename anonymizedtin tax_ID
	cap rename anonymized_tin tax_ID
    rename taxperiodyear year
    cap gen assessmentnumber = .
	duplicates report year tax_ID assessmentnumber 
	duplicates tag year tax_ID, gen(flag)
	gsort year tax_ID -assessmentnumber
	
tempfile cit`i'
save `cit`i''

}

foreach v of varlist businessincome-creditclaimed { 
	cap replace `v' = 0 if `v'==.
	
}	

	* Append datasets
	use `cit2010', clear 
	append using `cit2011'
	append using `cit2012' 
	append using `cit2013' 
	append using `cit2014' 
	append using `cit2015' 
	append using `cit2016' 
	append using `cit2017'   

	drop if taxperiodmonth != "Annual"  & year == 2017
	sort tax_ID year businessincome
	egen non_miss=rownonmiss(businessincome-annualflatamountoftaxdue)
	drop if non_miss == 0
	replace businessincome = 0 if businessincome == .
	
	/* For duplicated firm-year pairs, keep the latest observation number */ 
	bys tax_ID year: egen max_assessmentnumber=max(assessmentnumber)
	keep if max_assessmentnumber==assessmentnumber
	
	drop max_assessmentnumber
	
	/* Check duplicates */
	duplicates report year tax_ID
	// no duplicates
	
	* Check taxpayer type:
	tab enttypedesc
	keep if enttypedesc == "Company" | enttypedesc == "PRIVATE CORPORATION" | enttypedesc == "PUBLIC CORPORATION" | enttypedesc == "TRUST"
	tab taxtypedesc
	
	gen CIT_normal_regime = 0
	replace CIT_normal_regime = 1 if taxtypedesc == "CIT-CORP. INCOME TAX"

* GROUP 1: INCOMES

	* Turnover and other income 
gen turnover = abs(businessincome)

foreach var of varlist rentalincome nonoperatingextraordinaryincome investimentincome{
	replace `var' = abs(`var')
}

egen other_income = rowtotal(rentalincome nonoperatingextraordinaryincome investimentincome), missing

	* Exempt income
gen exempt_income = abs(nontaxabledividsendsreceived)

gen dividend_income = .
gen dividend_exempt = abs(nontaxabledividsendsreceived)

	* Total income (all income)
egen total_income = rowtotal(turnover other_income), missing	

	* Taxable income (-exempt income)
gen taxable_income = total_income - cond(missing(exempt_income), 0, exempt_income)

* GROUP 2: COST ITEMS
	* cost of good sold
gen cogs = 	costofgoodssold
	* Labor Inputs
gen labor_inp = .

	* Material Inputs
gen material_inp = abs(costofgoodssold)

	* Selling, admin and other operating costs
gen operating_inp = abs(operatingexpenses)

	* Capital Inputs
egen capital_inp = rowtotal(investimentexpensesline35ofannex rentalexpensesonly10ofrentalinco ), missing

	* Financial Inputs
gen financial_inp = baddebts
	
	* Other Inputs
egen other_inp = rowtotal(nonoperationalextraordinaryexpen ), missing  
 	* Non deductible Inputs
if year == 2020{	
gen depreciation_adj_plus =  bh 
gen depreciation_adj_minus = bi
replace depreciationadjustments = depreciation_adj_plus -  depreciation_adj_minus
}

if year == 2018{	
gen depreciation_adj_plus =  v61 
gen depreciation_adj_minus = v62
replace depreciationadjustments = depreciation_adj_plus -  depreciation_adj_minus
}
gen non_deduc_inp = abs(reintegrationofnondeductibleexpe) + cond(missing(depreciationadjustments), 0, depreciationadjustments)

 	* Total costs: add up all costs & expenditure
egen tot_cost =  rowtotal(material_inp labor_inp operating_inp capital_inp financial_inp depreciation other_inp), missing

	* Deductible Costs: total costs - non-deductible inputs 
gen deductible_cost = tot_cost - cond(missing(non_deduc_inp), 0, non_deduc_inp)   

* GROUP 3: PROFITS
	* Gross profit (Gross income - CoGS)
gen gross_profit_temp = grossprofitline5line10 
gen gross_profit_built = abs(total_income) - abs(costofgoodssold)
gen gross_profit = gross_profit_built

	* Net profit
replace investimmentallowances = abs(investimmentallowances) // 1 outlier

gen net_profit = netincomeline90line55  + cond(missing(investimmentallowances), 0, investimmentallowances) ///
									    + cond(missing(trainingresearchexpenses), 0, trainingresearchexpenses)
gen net_profit_built = total_income - cond(missing(tot_cost), 0, tot_cost)
replace net_profit = net_profit_built if net_profit==.
	* Taxable profit
gen taxable_profit = taxable_income - cond(missing(deductible_cost), 0, deductible_cost)

/* Flag systematic missing values in most relevant variables */
egen profit_missings=rownonmiss(investimentincome nonoperatingextraordinaryincome nonoperatingextraordinaryi rentalincome purchases costofgoodssold operatingexpenses investimentexpensesline35ofannex investimentexpensesline35of rentalexpensesonly10ofrentalinco rentalexpensesonly10ofrent nonoperationalextraordinaryexpen nonoperationalextraordinary baddebts)

order profit_missings, a(year)
label var profit_missings "N. of non missing values in relevant income & cost variables"

* GROUP 4: GROSS & NET TAX BASE

	* Investment Incentives  (From tax base)
egen investment_taxbase = rowtotal(investimmentallowances trainingresearchexpenses), missing

	* Capital allowances  (From tax base)
gen capital_allowance = .

	* Losses (always from tax base)
gen loss_carryforward = abs(fiscallosscarriedforward)

	* Other Deductions (always from tax base)
gen other_ded_taxbase = .

	* Add up credits & deductions from tax base: 
egen tot_deduc_taxbase = rowtotal(investment_taxbase capital_allowance other_ded_taxbase), missing

	* Gross tax base (taxable_profit - tot_deduc_taxbase)
gen gross_tax_base = taxable_income
gen gross_tax_base_built = taxable_profit- cond(missing(tot_deduc_taxbase), 0, tot_deduc_taxbase)

	* Net tax base (gross_tax_base - loss_carryforward)
gen net_tax_base = taxableincomeorloss
replace net_tax_base =  -abs(lossdeclaredforthisperiod) if net_tax_base==.
gen net_tax_base_built = taxable_profit - cond(missing(loss_carryforward), 0, loss_carryforward)

* GROUP 5: GROSS & NET TAX LIABILITY
gen taxdisc_inv = .
gen taxdisc_else = .

if year == 2020{
replace taxdisc_inv = taxdiscountforcorporateincom + bl
replace taxdisc_else = taxdiscountforpreferentialco + bn
}

if year == 2018{
replace taxdisc_inv = taxdiscountforcorporateincom + v65
replace taxdisc_else = taxdiscountforpreferentialco + v67
}
	* Gross tax liability

	* Credits for foreign taxes paid
egen cred_foreign_tax = rowtotal(  foreigntaxcreditline65ofa foreigntaxcreditline65ofannexb), missing	

	* Investment credits from tax liability
egen investment_taxliab = rowtotal(taxdiscountforventurecapitalcomp collectiveinvestmentschemesandem taxdiscountonagriculturallivesto taxdiscountfromemployment taxdiscountformicrofinances), missing 

	* Small/young firms credits from tax liability
egen special_taxliab = rowtotal(taxdiscountfornewlylistedcompani ), missing 

	* International Trade credits 
egen trade_taxliab = rowtotal(taxdiscountfromexports taxdiscountforfreetradezone), missing 

	* Other credit and allowances from tax liability
gen other_cred_taxliab = auditadjustment

	* Add up credits & deductions from tax liability 
egen tot_deduc_taxliab = rowtotal(cred_foreign_tax investment_taxliab special_taxliab trade_taxliab other_cred_taxliab), missing 

	* Add up credits & deductions that are not necessarily real credits from tax liability 
egen tot_noelse_taxliab = rowtotal(cred_foreign_tax other_cred_taxliab), missing 

	* Gross tax liability (net tax base*CIT rate)
gen gross_tax_liability = corporateincometaxpayable +  cond(missing(tot_deduc_taxliab), 0, tot_deduc_taxliab) - cond(missing(auditadjustment), 0, auditadjustment)
gen gross_tax_liability_built = net_tax_base*0.3
sum gross_tax_liability gross_tax_liability_built

	* Net tax liability (gross_tax_liability - tot_deduc_taxliab)
gen net_tax_liability = corporateincometaxpayable // Normal regime
replace net_tax_liability = annualflatamountoftaxdue if net_tax_liability == . // Flat rate
gen net_tax_liability_built = gross_tax_liability - abs(tot_deduc_taxliab)

	* Net tax liability without foreign and other credits  
gen ntl_noelse	= net_tax_liability + tot_noelse_taxliab

* GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS
	* Add up partial/advance payments
gen partial_advanced_pay = quarterlyprepayments

	* Add withholding 
egen withholding = rowtotal(withholdingonimports withholdingsonpublictender withholdingonotherpaymentsinvest), missing

	* Other creditable tax payments
gen other_cred_tax_pay = overpaymentfrompreviousperiods

	* Tax to remit
gen tax_to_remit = nettaxduecreditline20line40 


**** Treatment of missings and 0
foreach var of varlist gross_tax_base net_tax_base gross_tax_liability net_tax_liability ntl_noelse tax_to_remit {
    replace `var' = 0 if missing(`var') & !missing(total_income)
}

gen FEZ = 0 
replace FEZ =1 if taxdiscountforfreetradezone !=0 & taxdiscountforfreetradezone!=.

gen exporter = 0
replace exporter = 1 if taxdiscountfromexports !=0 & taxdiscountfromexports!=.

********* Add labels and drop some variables ********
label variable tax_ID "Tax ID"
label variable year "Fiscal Year"
label variable turnover "Turnover"
label variable total_income "Total income"
label variable taxable_income "Taxable income"
label variable tot_cost "Total Costs"
label variable deductible_cost "Deductible Costs"
label variable net_profit "Net profit"
label variable taxable_income "Taxable profit"
label variable gross_tax_base "Gross Tax Base"
label variable tot_deduc_taxbase "Total Credits & Deductions - Tax Base"
label variable net_tax_base "Net Tax Base"
label variable gross_tax_liability "Gross Tax Liability"
label variable net_tax_liability "Net Tax Liability"
label variable tot_deduc_taxliab "Total Credits & Deductions - Tax Liability"
label variable tax_to_remit "Tax to Remit"
label variable country "Country"

* 4. ADD FIRM CHARACTERISTICS
	
	* CAPITAL CITY	
gen capital_city = 0
replace capital_city = . if taxcenterdesc == "Missing Tax center" 
replace capital_city = 1 if taxcenterdesc == "GASABO TC" | 		 ///
						taxcenterdesc == "KICUKIRO TC" | 	 ///
						taxcenterdesc == "KIGALI LTO" | 	 ///
						taxcenterdesc == "KIGALI MEDIUM" | 	 ///
						taxcenterdesc == "KIGALI SMALL" | 	 ///
						taxcenterdesc == "KIGALI-MICRO" | 	 ///
						taxcenterdesc == "NYARUGENGE TC" | 	 ///
						taxcenterdesc == "RRA- RSSB TC"
						
gen tax_center = taxcenterdesc						

* Standardize businessactivitydescs. we are using CIIU 4
gen section = ""
replace section = "B" if businessactivitydesc == "MINES" | businessactivitydesc == "PETROLEUM"
replace section = "C" if businessactivitydesc == "INDUSTRIES"
replace section = "D" if businessactivitydesc == "ELECTRONIC SERVICE" | businessactivitydesc == "ENERGY INDUSTRY"
replace section = "F" if businessactivitydesc == "PUBLIC WORKS & CONSTRUCTION"
replace section = "G" if businessactivitydesc == "BRALIRWA DISTRIBUTOR"
replace section = "G" if businessactivitydesc == "CIMERWA DISTRIBUTOR" |  businessactivitydesc ==  "CLEARING AGENCY" 
replace section = "G" if businessactivitydesc == "GENERAL COMMERCE" | businessactivitydesc == "PRINTARY, STATIONARY & BOOK SHOP"
replace section = "H" if businessactivitydesc == "GARAGE" | businessactivitydesc == "TRANSPORT"
replace section = "I" if businessactivitydesc == "HOTEL & SNACK BAR"
replace section =  "J" if businessactivitydesc == "POST & TELECOMMUNICATION" | businessactivitydesc == "RADIO COMMUNICATION"
replace section = "K" if businessactivitydesc == "CONSULTANCY & ADVOCATE" | businessactivitydesc == "FINANCIAL INSTITUTION"
replace section = "Q" if businessactivitydesc == "PHARMACY"
replace section =  "R" if businessactivitydesc == "PREMISES TRAINING"
replace section = "S" if businessactivitydesc == "OTHER SERVICES"

rename businessactivitydesc descr_section

	* PRIVATE/PUBLIC
gen private = 0
replace private = 1 if enttypegroup == "PRIVATE"

* GROUP 8: Statutory Tax Rate

gen STR = . 
replace STR = 0.3 


*	5. KEEP VARIABLES WE NEED 
local group0 year country tax_ID entity section descr_section  CIT_normal_regime
local group1 turnover exempt_income other_income total_income taxable_income dividend_income dividend_exempt
local group2 tot_cost *_inp deductible_cost depreciation cogs
local group3 gross_profit taxable_profit net_profit
local group4 investment_taxbase capital_allowance loss_carryforward other_ded_taxbase net_tax_base gross_tax_base tot_deduc_taxbase
local group5 gross_tax_liability net_tax_liability tot_deduc_taxliab cred_foreign_tax investment_taxliab other_cred_taxliab 
local group6 withholding partial_advanced_pay other_cred_tax_pay tax_to_remit net_profit_built net_tax_base_built gross_tax_liability_built taxtypedesc
local group7 ntl_noelse tot_noelse_taxliab special_taxliab trade_taxliab
local group8 FEZ exporter tax_center capital_city private STR profit_missings

	* Keep selected variables
keep  `group0' `group1' `group2' `group3' `group4' `group5' `group6' `group7' `group8'
gen cit_data = 1


/* Remove flat and 3% tax firms */
gen turnover_millions=turnover/1000000
gen etr_check=net_tax_liability/turnover*100

drop if turnover_millions<=20 & etr_check<=3
drop if turnover_millions<=20 & profit_missings==0
drop if etr_check<=3.1 & profit_missings==0

keep if CIT_normal_regime==1

/* Save data */
sort tax_ID year, stable
export delimited "$data/output/Rwanda/RWA_withvars.csv", replace