*===============================================================================
* File name: 		CIT_SEN.do
* 
* Description:		This do-file creates the dataset SEN_withvars.csv. 
*
* Input:  					
*					$data/input/Senegal/IS_appended.dta 
*					$data/input/Senegal/Afristat_convertion.dta 
*					$data/input/Senegal/Liste_activite.xlsx 
*					$data/input/Senegal/TVA_appended.dta 
*					$data/input/Senegal/RAS_IRPP_appended.dta
*
* Output:
*					$data/output/Senegal/SEN_withvars.csv
*===============================================================================

cls
capture restore
set more off
cap log close
clear all

*****************************************************************************
**************************** LEGAL ENTITIES *********************************
*****************************************************************************

use "$data/input/Senegal/IS_appended", clear


*** SELECT AND CREATE VARIABLES

* GROUP 0

	* Indentification variables
rename annee year 
rename ninea tax_ID
destring tax_ID, replace 
generate country = "SEN"
generate entity = "Legal"	

	* Check for duplicates and drop
duplicates report year tax_ID

* GROUP 1: INCOMES

	* Create one var for net profit (join loss and benefits)
gen net_profit = IS_L10_c
replace net_profit = -1*abs(IS_L200_c) if IS_L10_c==0 |  IS_L10_c==.

	* Turnover and other income
gen turnover = abs(IS_L5_c)
gen other_income = .

	* Exempt income
replace IS_L220_c = abs(IS_L220_c)
replace IS_L230_c = abs(IS_L230_c)
egen exempt_income =  rowtotal(IS_L220_c IS_L230_c), missing
egen dividend_exempt = rowtotal(IS_L250_c IS_L260_c), missing //

* Compute based on quote part:
gen IS_produit_brut_L250 = IS_L250_c/0.05
gen IS_produit_brut_L260 = IS_L260_c/0.4
egen dividend_income = rowtotal(IS_produit_brut_L250 IS_produit_brut_L260), missing // 


	* Total income (all income)
egen total_income = rowtotal(turnover other_income), missing
	
	* Taxable income (-exempt income)
gen taxable_income = total_income - cond(missing(exempt_income), 0, exempt_income)
replace taxable_income = . if taxable_income<0

* GROUP 2: COST ITEMS

gen cogs = .
	* Operating inp 
gen  operating_inp = .
	* Capital Inputs
gen capital_inp = .
	* Financial Inputs
gen financial_inp = .
	* Depreciation 
gen depreciation = . 	
	* Other Inputs
gen other_inp = .
 	* Non deductible Inputs

	foreach var of varlist IS_L20_c IS_L30_c IS_L50_c IS_L40_c IS_L60_c IS_L90_c IS_L70_c IS_L80_c IS_L160_c IS_L100_c IS_L130_c IS_L140_c IS_L150_c IS_L110_c IS_L210_c IS_L240_c IS_L250_c 						   IS_L260_c IS_L270_c IS_L360_c IS_L370_c{
	replace `var' = abs(`var')
} 

gen non_deduc_inp = IS_L160_c 

 	* Total costs: add up all costs & expenditure
gen tot_cost = turnover - cond(missing(net_profit), 0, net_profit) 
replace tot_cost = . if turnover == . | turnover == 0
replace tot_cost = . if tot_cost < 0 

	* Deductible Costs: total costs - non-deductible inputs 
gen deductible_cost = tot_cost - cond(missing(non_deduc_inp), 0, non_deduc_inp)   

* GROUP 3: PROFITS

gen gross_profit = .
	* Net profit
gen net_profit_built =  total_income - cond(missing(tot_cost), 0, tot_cost)
replace net_profit = net_profit_built if missing(net_profit)
	* Taxable profit
gen taxable_profit_built = taxable_income - cond(missing(deductible_cost), 0, deductible_cost)

gen taxable_profit = taxable_profit_built

* GROUP 4: GROSS & NET TAX BASE

	* Investment Incentives  (From tax base)
egen investment_taxbase = rowtotal( IS_L360_c IS_L370_c), missing
	* Capital allowances  (From tax base)
gen capital_allowance = abs(IS_L321_c)
	* Losses (always from tax base)
gen loss_carryforward = abs(IS_L330_c)
	* Other Deductions (always from tax base)
egen other_ded_taxbase = rowtotal(IS_L210_c  IS_L270_c IS_L380_c), missing
	* Add up credits & deductions from tax base: 
egen tot_deduc_taxbase = rowtotal(investment_taxbase capital_allowance other_ded_taxbase), missing 
	* Gross tax base (taxable_profit - capital_allowance - investment_incentive)
gen gross_tax_base = taxable_profit - cond(missing(tot_deduc_taxbase), 0, tot_deduc_taxbase) 
	* Net tax base (gross_tax_base - loss_carryforward)
gen net_tax_base_built = gross_tax_base - cond(missing(loss_carryforward), 0, loss_carryforward)
gen net_tax_base = IS_L400_c
replace IS_L405_c = IS_L405_c*-1 if IS_L405_c > 0
replace net_tax_base = IS_L405_c if IS_L400_c == 0

* GROUP 5: GROSS & NET TAX LIABILITY

	* Gross tax liability (net tax base*CIT rate)
gen gross_tax_liability = IS_L470_c
	* Credits for foreign taxes paid
gen cred_foreign_tax = .	
	* Investment credits from tax liability
gen investment_taxliab = .
	* Special firms credits from tax liability
gen special_taxliab = .
	* International Trade credits 
gen trade_taxliab = .
	* Other credit and allowances from tax liability
gen other_cred_taxliab = .
	* Add up credits & deductions from tax liability 
egen tot_deduc_taxliab = rowtotal(cred_foreign_tax special_taxliab trade_taxliab investment_taxliab other_cred_taxliab), missing
	* Add up credits & deductions that are not necessarily real credits from tax liability 
egen tot_noelse_taxliab = rowtotal(cred_foreign_tax  other_cred_taxliab), missing

	* Net tax liability (gross_tax_liability - tot_deduc_taxliab)
gen net_tax_liability = gross_tax_liability - cond(missing(tot_deduc_taxliab), 0, tot_deduc_taxliab)

	* Net tax liability without foreign and other credits  
gen ntl_noelse = net_tax_liability + cond(missing(tot_noelse_taxliab), 0, tot_noelse_taxliab)

* GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS

foreach var of varlist IS_L480_c  IS_L440_c IS_L435_c IS_L425_c IS_L423_c IS_L430_c IS_L422_c{
    replace `var' = abs(`var')
}
	* Add up partial/advance payments
egen partial_advanced_pay = rowtotal(IS_L480_c  IS_L440_c), missing
	* Add withholding 
egen withholding = rowtotal(IS_L435_c IS_L425_c IS_L423_c  IS_L422_c), missing
	* Other creditable tax payments
egen other_cred_tax_pay = rowtotal(IS_L430_c IS_L485_c), missing

	* Tax to remit
gen tax_to_remit = IS_L490_c
replace tax_to_remit = IS_L490b_c if year == 2020

replace tax_to_remit = IS_L500_c*-1 if tax_to_remit == 0

**** Treatment of missings and 0
foreach var of varlist gross_tax_base net_tax_base gross_tax_liability net_tax_liability tax_to_remit {
    replace `var' = 0 if missing(`var') & !missing(total_income)
}

*IS_L415_c // zone franche d'exportation, at least 80% of production is exported, get 15% discount. 
*IS_L420_c // point franc, ZFI ou exonere  
gen FEZ = 0
replace FEZ = 1 if IS_L420_c == 1 | IS_L415_c == 1  
gen first_year = IS_L410_c


********* Add labels and drop some variables ********
label variable tax_ID "Tax ID"
label variable year "Fiscal Year"
label variable turnover "Turnover"
label variable total_income "Total income"
label variable taxable_income "Taxable income"
label variable tot_cost "Total Costs"
label variable deductible_cost "Deductible Costs"
label variable net_profit "Net profit"
label variable taxable_income "Taxable profit"
label variable gross_tax_base "Gross Tax Base"
label variable tot_deduc_taxbase "Total Credits & Deductions - Tax Base"
label variable net_tax_base "Net Tax Base"
label variable gross_tax_liability "Gross Tax Liability"
label variable net_tax_liability "Net Tax Liability"
label variable tot_deduc_taxliab "Total Credits & Deductions - Tax Liability"
label variable tax_to_remit "Tax to Remit"
label variable country "Country"
	
	* Add firm characteristic variables
merge m:1 tax_ID using "$data/input/Senegal/Afristat_convertion"
drop if _merge == 2
drop _merge


**************************
* Capital Dummy
gen capital_city = 0 
replace capital_city = 1 if CENTRE == "DAKAR LIBERTE" | ///
					  CENTRE == "DAKAR PLATEAU" | ///
					  CENTRE == "GRAND DAKAR" | ///
					  CENTRE == "NGOR ALMADIES" | ///
					  CENTRE == "PIKINE GUEDIAWAYE" | ///
					  CENTRE == "RUFISQUE"
					  
tempfile CIT
save `CIT'
 					  
import excel "$data/input/Senegal/Liste_activite.xlsx", sheet("Select enterprise") firstrow clear
gen tax_ID = NINEA
replace tax_ID = "005116927" if tax_ID =="005116927X"
destring tax_ID, replace
gen adresse = subinstr(ADRESSE_CLEAN, char(10), "", .) 
split adresse, p("Sénégal")
gen reversed = reverse(adresse1)
split(reversed), p(",") limit(2)
gen city = reverse(reversed1)
replace city = subinstr(city, " ", "", .)

keep city tax_ID CENTRE ACTIVITE SECTEUR_ACTIVITE
duplicates drop tax_ID, force
merge 1:m tax_ID using `CIT'
drop if _merge ==1
***
replace capital_city = 1 if city == "DAKAR" 
replace capital_city = 0 if city == "THIES" | city == "SAINT-LOUIS" | ////
					   city == "FATICK" | city == "KAOLACK" | ///
					   city =="TAMBACOUNDA" | city == "ZIGUINCHOR" | ///
					   city == "DIOURBEL"

gen activity = ACTIVITE 
replace activity = SECTEUR_ACTIVITE if ACTIVITE == "" 
replace activity = upper(activity) 

rename CENTRE tax_center

****************************************************
*4 Economic activity
****************************************************

foreach a in "É" "Ê" "È" {
replace activity = subinstr(activity, "`a'", "a", .)
}
replace activity  = upper(activity)

local group1 `""TRANSPORT" "FERROVIAIRE" "ROUTIE" "AEROPOR" "MARITIME" "CARRIERES" "TRANSIT" "LOGISTIQUE" "AERIENNE" "AUTOROUTE" "PEAGE" "'
local group2 `""HOTEL" "HÔTEL" "BRASSERIE" "RECREATIVES" "CULTUREL" "FOIRES" "SALONS" "MUSICAL" "PLAGE" "SPORTIVE" "PATRIMOINE" "RACRAATIVE" "RECREATI" "SOUTIEN À LA CULTURE" "CINEMA" "THEATRE"  "RESTAURANT" "ARTIST" "HEBERGE" "HABERGEMENT" "TOURIS" "RESTAURATION""'	
local group3 `""BTP" "BATIMENT"  "TRAVAUX" "PRAPARATION DES SITES" "CIMENT" "BETON" "TRUCTION" "GENIE CIVIL" "GENIERIE""'	
local group4 `""ALIMENT" "AGRICUL" "PECHE" "VOLAILLES" "CEREAL" "BISCUITS" "BOULANGER" "PAIN" "DENRAE" "SEMENCE" "AVICULTURE" "POISSON" "PACHE ARTISANALE" "PISCICULTURE" "GRAINS" "VIANDE" "SYLVICULTURE" "AGICULTUR" "PÊCHE" "LAIT" "ALAVAGE" "ELEVAGE" "FRUIT" "DENRAES" "TOMATE" "DENREE" "RIZ" "FARINE""'
local group5 `""INDUSTRIE" "INDUTRIE" "INDUSTRIIE" "TEXTIL" "IND" "MANUFAC" "FABICA" "METAUX" "EMBALLAGE" "CHIMI" "EXTRACT" "MINIER" "ACIERIE" "MINNIERE" "FABRICATION" "FABRIQUE" "MINES" "TALLURGI" "TRANSFORMATION" "PLASTIQ" "TANNERI" "'
local group6 `""SANTE" "HOPITAL" "LABORATOIRE" "THERAP" "ORTHO" "ORL" "CHIRURGI" "VATARINAIRE" "GASTRO" "PEDIATRE" "GENERALISTE" "OLOGUE"  "PHARMAC" "HOSPITAL" "CARDIO" "SANITAIRE" "SANTA" "MEDICA" "UROLOGIE" "CLINIQUE" "ANESTHE" "DENTISTE" "OPHTALM" "CANCER" "MEDECIN" "VETERIN""'
local group7 `""AVOCAT" "JURIDIQUE" "ECONOMIQUE" "CONSULT" "EXPERT" "HUISSIER" "HUSSIER" "RESSOURCES HUMAINES" "CONSULTANT" "FISCAL" "IMMO" "NOTAIRE" "COMPTAB" "SOUTIEN AUX ENTREPRISES" "CONSEIL" "ARCHITE" "AGENCE" "'
local group8 `""BANQUE" "FINANC" "MICROCRED" "ASSURANCE" "CREDIT" "FONDS" "ASSURRA" "MONATAIRE" "INVESTISS""'
local group9 `""ENERGIE" "CARBUR" "PETROLE" "PETROLIER" "HYDROCARB" "ELECTR" "BUTANE" "GAZ""'
local group10 `""TELECOM" "COMMUNICATION" "RADIO" "MEDIAS" "TALAVISION" "PUBLICITA" "TELE" "INFORMATIQUE" "INFORM" "'
local group11 `""SERVICE" "SEVICES"  "SURVEILL" "MAINTEN" "MANUTENTI" "'
local group12 `""COMMERC" "DETAIL" "DISTRIBUTION""'
local group13 `""ENSEIGN" "EDUCA" "ECOLE" "SCIENTIF" "RECHERCHE""'
local group14 `""AUTOM" "VOITU" "CONCESS""'
 
gen activity_group = 0 
label define n 0 "Autres" 1 "Transport" 2 "Tourisme & Restauration" 3 "BTP" 4 "Alimentation" 5 "Industrie et mines" 6 "Santé" 7 "Libéraux" 8 "Finance" 9 "Energie" 10 "Telecommunications, inform. et medias" 11 "Autres services" 12 "Commerce et distribution" 13 "Enseignement et recherche" 14 "Automobile"
label values activity_group n 

forvalues i = 1/14 {
	foreach act2 in `group`i'' {
		replace activity_group = `i' if strpos(activity, "`act2'") > 0  & activity_group == 0 
	}
}
 drop _merge
save "$data/temp/Senegal/temp_CIT", replace

/******************************************************/
* Append TVA for material_inp
use "$data/input/Senegal/TVA_appended", clear 
rename annee year
rename ninea tax_ID
collapse (sum) TVA_L100_s-TVA_mont_paye_sur_period, by(year tax_ID)

merge 1:1 tax_ID year using "$data/temp/Senegal/temp_CIT"

	*Material input
	*Compute implicit VAT tax rate for each sector 
	bys section: egen totalsales = total(TVA_L5_c)
	bys section: egen totalexports = total(TVA_L10_c)
	bys section: egen totalVAT = total(TVA_L60_c)
	gen VATrate = totalVAT / (totalsales - totalexports)
	gen material_inp = TVA_L80_c + (TVA_L90_c/VATrate)
	replace material_inp = 0 if material_inp<0
	drop if _merge ==1 
	drop _merge


tempfile CIT_VAT
save `CIT_VAT'

/******************************************************/

* Append RSA for labor inp
use "$data/input/Senegal/RAS_IRPP_appended", clear 
rename annee year
rename ninea tax_ID
collapse (sum) RAS_IRPP_Localite-RAS_IRPP_mont_paye_sur_period, by(year tax_ID)

gen labor_inp = 	RAS_IRPP_L60_c
gen nb_employee = RAS_IRPP_L30_c
keep year labor_inp nb_employee tax_ID
merge 1:1 tax_ID year using `CIT_VAT'
drop if _merge == 1
 drop _merge

* GROUP 8:STATUTORY TAX RATE

gen statutory_rate = IS_L421_c
replace statutory_rate = 0.25 if statutory_rate == 299000 | statutory_rate == 962000 
replace statutory_rate = 0.25 if statutory_rate == 25 
replace statutory_rate = 0.15 if statutory_rate == 15 
replace statutory_rate = 0.3 if statutory_rate == 30 

gen IMF = 0.005*turnover
gen test = 0
replace test = 1 if IMF == net_tax_liability

gen tax_applicable = "IS"
replace tax_applicable = "IMF" if net_tax_liability <= 5000000

gen STR = statutory_rate
replace STR = .3 if STR == .15
replace STR = .3 if STR == 0
replace STR = .3 if STR == .

gen special_regime = 0
replace special_regime = 1 if  tax_applicable=="IS"
                                     

************* KEEP VARIABLES WE NEED *************
    
	* Create locals to keep variables
    local group0 year country tax_ID entity   
    local group1 turnover exempt_income other_income total_income taxable_income  dividend_income dividend_exempt statutory_rate 
    local group2 tot_cost *_inp deductible_cost depreciation cogs
    local group3 taxable_profit net_profit gross_profit
    local group4 investment_taxbase capital_allowance loss_carryforward other_ded_taxbase net_tax_base gross_tax_base tot_deduc_taxbase
    local group5 gross_tax_liability net_tax_liability tot_deduc_taxliab cred_foreign_tax investment_taxliab other_cred_taxliab 
    local group6 withholding partial_advanced_pay other_cred_tax_pay tax_to_remit activity activity_group tax_applicable section descr_section 
	local group7 ntl_noelse tot_noelse_taxliab special_taxliab trade_taxliab
	local group8 FEZ  capital_city first_year nb_employee tax_center city STR statutory_rate // incorporation  private exporter


	* Keep selected variables
	keep  `group0' `group1' `group2' `group3' `group4' `group5' `group6' `group7' `group8' 

* Final adjustments
sort tax_ID year, stable

* Data is not usable for some years:
drop if year <= 2009 & year >= 2018 

*** Outlier management:
replace net_tax_liability = . if tax_ID==6285614 & year == 2019

drop if tax_ID==2386317
drop if year == 2016 & tax_ID==4135762
drop if year == 2019 & tax_ID==6285614

sort tax_ID year, stable
export delimited using "$data/output/Senegal/SEN_withvars.csv", replace 