*===============================================================================
* File name: 		CIT_SWZ.do
* 
* Description:		This do-file creates the dataset ESW_withvars.csv. 
*
* Input:  					
*					$data/input/Eswatini/Jul2019_CIT_2013_2018_Clean.dta 
*					$data/input/Eswatini/Registry_Location.dta
*
* Output:
*					$data/output/Eswatini/ESW_withvars.csv
*===============================================================================


cls
capture restore
set more off
cap log close
clear all

*****************************************************************************
**************************** LEGAL ENTITIES *********************************
*****************************************************************************

**	IMPORT DATA
	use "$data/input/Eswatini/Jul2019_CIT_2013_2018_Clean.dta"


** 	MERGE WITH REGISTRY LOCATION INFORMATION
	merge m:1 ID using "$data/input/Eswatini/Registry_Location.dta"
	drop if _merge==2
	drop if TIN==. 
	drop _merge
            
	gen capital=.
	replace capital = 0 if Town_reg!=""
	replace capital = 1 if Town_reg=="Mbabane" | Town_reg=="Manzini"

**	RENAME VARIABLES
	lab var CIT "CIT indicator"
	generate country = "ESW"
	generate entity = "Legal"	
	rename Year_decl year
	rename ID tax_ID
	
	* Check for duplicates and drop
duplicates drop  
duplicates report year tax_ID 
duplicates tag year tax_ID, gen(flag)
sort year tax_ID  

	* Check taxpayer type:
tab OrganizationType	
tab Sector

* GROUP 1: INCOMES

	* Turnover and other income 
gen turnover = Turnover
gen other_income = IncomeotherthanTurnover
	* Exempt income
gen exempt_income = total_exempt_income
gen dividend_income = .						
gen dividend_exempt = .
	
	* Total income (all income)
egen total_income_built = rowtotal(turnover other_income), missing	
sum total_income total_income_built

sum total_income total_income_built
	* Taxable income (-exempt income)
rename taxable_income taxable_income_raw
gen taxable_income = total_income - cond(missing(exempt_income), 0, exempt_income)

	* Gross profit (Gross income - CoGS)
cap replace Gross_profit_loss = "" if Gross_profit_loss=="NULL"
destring Gross_profit_loss, replace
gen gross_profit = Gross_profit_loss
gen gross_profit_built = abs(total_income) - abs(Cost_of_Sales)
sum gross_profit gross_profit_built

* GROUP 2: COST ITEMS

	* Labor Inputs
gen cogs = Cost_of_Sales
	* Labor Inputs
gen labor_inp = labor_input
	* Material Inputs
gen material_inp = Cost_of_Sales
	* Selling, admin and other operating costs
gen operating_inp = .
	* Capital Inputs
gen capital_inp = .
	* Financial Inputs
gen financial_inp = .
	* Depreciation 
gen depreciation = .	
	* Other Inputs
gen other_inp = .
 	* Non deductible Inputs
gen non_deduc_inp = total_adjustments
 	* Total costs: add up all costs & expenditure
gen tot_cost = total_expenses
	* Deductible Costs: total costs - non-deductible inputs 
gen deductible_cost = tot_cost - cond(missing(non_deduc_inp), 0, non_deduc_inp)   

* GROUP 3: PROFITS

	* Net profit
gen net_profit = accounting_profit_loss  
gen net_profit_built = total_income - cond(missing(tot_cost), 0, tot_cost)
sum net_profit net_profit_built
	* Taxable profit
gen taxable_profit = taxable_income - cond(missing(deductible_cost), 0, deductible_cost)

* GROUP 4: GROSS & NET TAX BASE

	* Investment Incentives  (From tax base)
gen investment_taxbase = .
	* Capital allowances  (From tax base)
gen capital_allowance = .
	* Losses (always from tax base)
gen loss_carryforward = loss_broght_forward
	* Other Deductions (always from tax base)
gen other_ded_taxbase = .
	* Add up credits & deductions from tax base: 
gen tot_deduc_taxbase = total_allowance 

	* Gross tax base (taxable_profit - tot_deduc_taxbase)
gen gross_tax_base = taxable_income
gen gross_tax_base_built = taxable_profit- cond(missing(tot_deduc_taxbase), 0, tot_deduc_taxbase)
sum gross_tax_base gross_tax_base_built
	* Net tax base (gross_tax_base - loss_carryforward)
gen net_tax_base = net_taxable_income 
gen net_tax_base_built = taxable_profit - cond(missing(loss_carryforward), 0, loss_carryforward)
sum net_tax_base net_tax_base_built 

* GROUP 5: GROSS & NET TAX LIABILITY

	* Gross tax liability (net tax base*CIT rate)
gen gross_tax_liability = tax_assessed  
gen gross_tax_liability_built = net_tax_base*0.3
sum gross_tax_liability gross_tax_liability_built
	* Credits for foreign taxes paid
gen cred_foreign_tax = Foreigntaxcredits	
	* Investment credits from tax liability
gen investment_taxliab = .
	* Special firms credits from tax liability
gen special_taxliab = .
	* International Trade credits 
gen trade_taxliab = .
	* Other credit and allowances from tax liability
gen other_cred_taxliab = .
	* Add up credits & deductions from tax liability 
egen tot_deduc_taxliab = rowtotal(cred_foreign_tax special_taxliab trade_taxliab investment_taxliab other_cred_taxliab), missing
	* Add up credits & deductions that are not necessarily real credits from tax liability 
egen tot_noelse_taxliab = rowtotal(cred_foreign_tax  other_cred_taxliab), missing
	* Net tax liability (gross_tax_liability - tot_deduc_taxliab)
gen net_tax_liability = gross_tax_liability - cond(missing(tot_deduc_taxliab), 0, tot_deduc_taxliab)
gen net_tax_liability_built = gross_tax_liability - abs(tot_deduc_taxliab)
	* Net tax liability without foreign and other credits  
gen ntl_noelse = net_tax_liability + cond(missing(tot_noelse_taxliab), 0, tot_noelse_taxliab)

* GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS

	* Add up partial/advance payments
gen partial_advanced_pay = provisional_tax_paid
	* Add withholding 
gen withholding = .
	* Other creditable tax payments
gen other_cred_tax_pay = .
	* Tax to remit
gen tax_to_remit = tax_payable_refund 

* Treatment of missings and 0
foreach var of varlist gross_tax_base net_tax_base gross_tax_liability net_tax_liability tax_to_remit {
    replace `var' = 0 if missing(`var') & !missing(total_income)
}

* GROUP 7: FIRM CHARACTERISTICS
gen STR = .
replace  STR = 0.275 if year >= 2014
replace  STR = 0.3 if year <= 2013
  
********* Add labels and drop some variables ********
label variable tax_ID "Tax ID"
label variable year "Fiscal Year"
label variable turnover "Turnover"
label variable total_income "Total income"
label variable taxable_income "Taxable income"
label variable tot_cost "Total Costs"
label variable deductible_cost "Deductible Costs"
label variable net_profit "Net profit"
label variable taxable_income "Taxable profit"
label variable gross_tax_base "Gross Tax Base"
label variable tot_deduc_taxbase "Total Credits & Deductions - Tax Base"
label variable net_tax_base "Net Tax Base"
label variable gross_tax_liability "Gross Tax Liability"
label variable net_tax_liability "Net Tax Liability"
label variable tot_deduc_taxliab "Total Credits & Deductions - Tax Liability"
label variable tax_to_remit "Tax to Remit"
label variable country "Country"

*	Final adjustments
	rename ISICCode isic_d4
	drop d2 d3 d2_desc d3_desc
	label var d4_desc "4-digit ISIC code description"
	label var isic_d4 "4-digit ISIC code"
	label var section_desc "Sector description"
	
*	EXPORT
	export delimited using "$data/output/Eswatini/ESW_withvars.csv", replace