*===============================================================================
* File name: 		CIT_UGA.do
* 
* Description:		This do-file creates the dataset UGA_withvars.csv. 
*
* Input:  					
*					$data/input/Uganda/CITanalysis_Raw_Extravars2.dta 
*
* Output:
*					$data/output/Uganda/UGA_withvars.csv
*===============================================================================

cls
capture restore
set more off
cap log close
clear all

*****************************************************************************
**************************** LEGAL ENTITIES *********************************
*****************************************************************************

* Load data 
use "$data/input/Uganda/CITanalysis_Raw_Extravars2.dta", replace

* Remove natural entities/individuals
drop if firm_id==.
tab taxpayertype
drop if taxpayertype=="INDIVIDUAL"

/* Identify and handle duplicates */
duplicates report firm_id fy 
duplicates tag firm_id fy, generate(duple)
sort fy firm_id  

bys firm_id: egen hasduplicates = sum(duple)
drop if hasduplicates!=0
drop duple hasduplicates

foreach var of varlist costofsales totoperationexpense tototherexpense totadminexpense incometaxturnover shortinsamt incomemcapitalgain ///
 totfinancialexpense totrentincmexpns totalamounttobeaddedbacktotalato totfactoryovh ///
 openstocksales totalpurchaseimport closestocksales directexpint directwages totempcompensation admndepreciation  factorydepreciation ///
  exemptincomemexpense  totalallowabledeductionstotalite {
			replace `var' = -1 * `var' if `var' < 0 
			replace `var' = 0 if missing(`var')
}                                       
                                 
   
******** SELECT AND CREATE VARIABLES ********

* GROUP 0

	* Indentification variables
rename fy year
rename firm_id tax_ID
generate country = "UGA"
generate entity = "Legal"	

* GROUP 1: INCOMES

	* Turnover and other income 
gen turnover = incometaxturnover

egen tot_oth_inc = rowtotal(interestinsideuganda interestoutsideuganda /// 
dividend commission ///
 annuity  naturalresourcepay ///
 royalties  gift ///
 otherreceipt ///
 disposaldepreciableasset /// 
 provisionforbaddebts ///
 rentalincome ///
 realizedexchange /// 
 othrunrealizedgain), missing

egen other_income = rowtotal(shortinsamt tot_oth_inc), missing   

	* Exempt income
gen exempt_income = exemptincomemexpense
gen dividend_income = dividend						
gen dividend_exempt = .

	* Total income (all income)
egen total_income = rowtotal(turnover other_income), missing
sum total_income turnover other_income
list total_income turnover other_income in 1/20
	
	* Taxable income (-exempt income)
gen taxable_income = total_income - cond(missing(exempt_income), 0, exempt_income)

gen gross_profit = grossprofit
gen gross_profit_built = incometaxturnover - costofsales
 sum gross_profit gross_profit_built
list gross_profit gross_profit_built in 1/20

* GROUP 2: COST ITEMS

	* Cost of good sold
gen cogs = costofsales
	* Labor Inputs
egen labor_inp = rowtotal(directwages totempcompensation), missing
	* Material Inputs
gen inventory = openstocksales - closestocksales
egen material_inp = rowtotal(inventory totfactoryovh totalpurchaseimport), missing
replace material_inp = material_inp - factorydepreciation
	* Selling, admin and other operating costs
gen adminexpenses_adjusted = totadminexpense - totempcompensation
egen operating_inp = rowtotal(totoperationexpense adminexpenses_adjusted directexpint), missing
replace operating_inp = operating_inp - admndepreciation
	* Capital Inputs
gen capital_inp = .
	* Financial Inputs  
gen F10f = profitbeforetax - incometaxturnover - costofsales-totoperationexpense - tototherexpense - totadminexpense - totfinancialexpense - totrentincmexpns
egen financial_inp = rowtotal(totfinancialexpense F10f), missing
	* Depreciation 
rename depreciation depreciation_dta
egen depreciation = rowtotal(factorydepreciation admndepreciation), missing
sum depreciation depreciation_dta
list depreciation depreciation_dta in 1/20
	* Other Inputs
egen other_inp = rowtotal(tototherexpense totrentincmexpns), missing
	* Non deductible Inputs
gen non_deduc_inp = totalamounttobeaddedbacktotalato  

 	* Total costs: add up all costs & expenditure
egen tot_cost_built = rowtotal(capital_inp material_inp operating_inp labor_inp financial_inp depreciation other_inp), missing
egen tot_cost = rowtotal(costofsales totoperationexpense tototherexpense totadminexpense totfinancialexpense totrentincmexpns F10f), missing

sum tot_cost tot_cost_built capital_inp material_inp operating_inp labor_inp financial_inp depreciation other_inp
list tot_cost tot_cost_built in 1/20

	* Deductible Costs: total costs - non-deductible inputs 
gen deductible_cost = tot_cost - cond(missing(non_deduc_inp), 0, non_deduc_inp)   

* GROUP 3: PROFITS

	* Net profit
gen net_profit = profitbeforetax
gen net_profit_built = total_income - cond(missing(tot_cost), 0, tot_cost)
sum net_profit net_profit_built
list net_profit net_profit_built in 1/20

	* Taxable profit
gen taxable_profit_built = taxable_income - cond(missing(deductible_cost), 0, deductible_cost)
gen taxable_profit = profitbeforetax  - cond(missing(totalamounttobeaddedbacktotalato), 0, totalamounttobeaddedbacktotalato)
sum taxable_profit taxable_profit_built
list taxable_profit taxable_profit_built in 1/20


* GROUP 4: GROSS & NET TAX BASE

	* Investment Incentives  (From tax base)
egen investment_taxbase = rowtotal(initialallowanceplantmachinery initialbuildingdeduction), missing
replace investment_taxbase = . if year != 2018
    * Capital allowances  (From tax base)
gen capital_allowance = capitallosses
	* Losses (always from tax base)
gen loss_carryforward = losspreviousyear
	* Other Deductions (always from tax base)
gen other_ded_taxbase = totalallowabledeductionstotalite - exemptincomemexpense
	* Add up credits & deductions from tax base: 
egen tot_deduc_taxbase = rowtotal(investment_taxbase capital_allowance other_ded_taxbase), missing 

	* Gross tax base (taxable_profit - tot_deduc_taxbase)
gen gross_tax_base = chargeincomeprofitbusiness
gen gross_tax_base_built = taxable_profit - cond(missing(tot_deduc_taxbase), 0, tot_deduc_taxbase)
sum gross_tax_base gross_tax_base_built 
list gross_tax_base gross_tax_base_built in 1/20

	* Net tax base (gross_tax_base - loss_carryforward)
gen net_tax_base = incomembusinessactvty
gen net_tax_base_built = gross_tax_base - cond(missing(loss_carryforward), 0, loss_carryforward)
sum net_tax_base net_tax_base_built 
list net_tax_base net_tax_base_built in 1/20

* GROUP 5: GROSS & NET TAX LIABILITY

	* Gross tax liability (net tax base*CIT rate)
gen gross_tax_liability = totincometaxamt
gen gross_tax_liability_built = net_tax_base*0.3
sum gross_tax_liability gross_tax_liability_built
list gross_tax_liability gross_tax_liability_built in 1/20
	* Credits for foreign taxes paid
gen cred_foreign_tax = .	
	* Investment credits from tax liability
gen investment_taxliab = .
	* Special firms credits from tax liability
gen special_taxliab = .
	* International Trade credits 
gen trade_taxliab = .
	* Other credit and allowances from tax liability
gen other_cred_taxliab = .
	* Add up credits & deductions from tax liability 
egen tot_deduc_taxliab = rowtotal(cred_foreign_tax special_taxliab trade_taxliab investment_taxliab other_cred_taxliab), missing
	* Add up credits & deductions that are not necessarily real credits from tax liability 
egen tot_noelse_taxliab = rowtotal(cred_foreign_tax  other_cred_taxliab), missing
	* Net tax liability (gross_tax_liability - tot_deduc_taxliab)
gen net_tax_liability = totincometaxamt
gen net_tax_liability_built = gross_tax_liability - cond(missing(tot_deduc_taxliab), 0, tot_deduc_taxliab)

	* Net tax liability without foreign and other credits  
gen ntl_noelse = net_tax_liability + cond(missing(tot_noelse_taxliab), 0, tot_noelse_taxliab)

* GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS

	* Add up partial/advance payments
gen partial_advanced_pay = .
	* Add withholding 
gen withholding = .
	* Other creditable tax payments
gen other_cred_tax_pay = .

	* Tax to remit
gen tax_to_remit = totincometaxamt

**** Treatment of missings and 0
foreach var of varlist gross_tax_base net_tax_base gross_tax_liability net_tax_liability tax_to_remit {
    replace `var' = 0 if missing(`var') & !missing(total_income)
}

********* Add labels and drop some variables ********
label variable tax_ID "Tax ID"
label variable year "Fiscal Year"
label variable turnover "Turnover"
label variable total_income "Total income"
label variable taxable_income "Taxable income"
label variable tot_cost "Total Costs"
label variable deductible_cost "Deductible Costs"
label variable net_profit "Net profit"
label variable taxable_income "Taxable profit"
label variable gross_tax_base "Gross Tax Base"
label variable tot_deduc_taxbase "Total Credits & Deductions - Tax Base"
label variable net_tax_base "Net Tax Base"
label variable gross_tax_liability "Gross Tax Liability"
label variable net_tax_liability "Net Tax Liability"
label variable tot_deduc_taxliab "Total Credits & Deductions - Tax Liability"
label variable tax_to_remit "Tax to Remit"
label variable country "Country"
**********************************************************************

* GROUP 7: FIRM CHARACTERISTICS

*** Capital city
tab businessdistrict
gen capital_city = .
replace capital_city = 0 if !missing(businessdistrict)
replace capital_city = 1 if businessdistrict == "KAMPALA"

gen total_assets = totalfixedassets    

gen region = businessdistrict

*** SECTORS 
* Extract sector at the division level of NACE Rev. 2
replace currentsectormainactivity = "" if currentsectormainactivity == "NULL"
gen section = substr(currentsectormainactivity, 1, 1)

gen descr_section_NACErev2 = ""
replace descr_section_NACErev2 = "AGRICULTURE, FORESTRY AND FISHING" if section == "A"
replace descr_section_NACErev2 = "MINING AND QUARRYING" if section == "B"
replace descr_section_NACErev2 = "MANUFACTURING" if section == "C"
replace descr_section_NACErev2 = "ELECTRICITY, GAS, STEAM AND AIR CONDITIONING SUPPLY" if section == "D"
replace descr_section_NACErev2 = "WATER SUPPLY; SEWERAGE, WASTE MANAGEMENT AND REMEDIATION ACTIVITIES" if section == "E"
replace descr_section_NACErev2 = "CONSTRUCTION" if section == "F"
replace descr_section_NACErev2 = "WHOLESALE AND RETAIL TRADE; REPAIR OF MOTOR VEHICLES AND MOTORCYCLES" if section == "G"
replace descr_section_NACErev2 = "TRANSPORTATION AND STORAGE" if section == "H"
replace descr_section_NACErev2 = "ACCOMODATION AND FOOD SERVICE ACTIVITIES" if section == "I"
replace descr_section_NACErev2 = "INFORMATION AND COMMUNICATION" if section == "J"
replace descr_section_NACErev2 = "FINANCIAL AND INSURANCE ACTIVITIES" if section == "K"
replace descr_section_NACErev2 = "REAL ESTATE ACTIVITIES" if section == "L"
replace descr_section_NACErev2 = "PROFESSIONAL, SCIENTIFIC AND TECHNICAL ACTIVITIES" if section == "M"
replace descr_section_NACErev2 = "ADMNINISTRATIVE AND SUPPORT SERVICE ACTIVITIES" if section == "N"
replace descr_section_NACErev2 = "PUBLIC ADMINISTRATION AND DEFENCE; COMPULSORY SOCIAL SECURITY" if section == "O"
replace descr_section_NACErev2 = "EDUCATION" if section == "P"
replace descr_section_NACErev2 = "HUMAN HEALTH AND SOCIAL WORK ACTIVITIES" if section == "Q"
replace descr_section_NACErev2 = "ARTS, ENTERTAINMENT AND RECREATION" if section == "R"
replace descr_section_NACErev2 = "OTHER SERVICE ACTIVITIES" if section == "S"
replace descr_section_NACErev2 = "ACTIVITY OF HOUSEHOLDS AS EMPLOYERS; ACTIVITIES OF HOUSEHOLDS FOR OWN USE" if section == "T"
replace descr_section_NACErev2 = "ACTIVITY OF EXTRATERRITORIAL ORGANISATIONS AND BODIES" if section == "U"

gen descr_section = descr_section_NACErev2

gen STR = 0.3

************* KEEP VARIABLES WE NEED *************
	* Create locals to keep variables
local group0 year country tax_ID entity  section descr_section 
local group1 turnover exempt_income other_income total_income taxable_income 
local group2 tot_cost *_inp deductible_cost depreciation cogs
local group3 taxable_profit net_profit
local group4 investment_taxbase capital_allowance loss_carryforward other_ded_taxbase net_tax_base gross_tax_base tot_deduc_taxbase
local group5 gross_tax_liability net_tax_liability tot_deduc_taxliab cred_foreign_tax investment_taxliab other_cred_taxliab 
local group6 withholding partial_advanced_pay other_cred_tax_pay tax_to_remit ntl_noelse tot_noelse_taxliab special_taxliab trade_taxliab gross_profit
local group7 capital_city region total_assets dividend* STR // incorporation firm_age nb_employee city total_assets  private foreign_ownership

	* Keep selected variables
keep  `group0' `group1' `group2' `group3' `group4' `group5' `group6' `group7' 

	* Final adjustments
sort tax_ID year, stable

export delimited using "$data/output/Uganda/UGA_withvars.csv", replace 