*===============================================================================
* File name: 		CIT_ZAF.do
* 
* Description:		This do-file creates the dataset ZAF_withvars.csv. 
*
* Input:  					
*					$data/input/South Africa/citfp_2008_2022_e5_v1.dta 
*					$data/input/South Africa/CIT-IRP5_employee.dta 
*					$data/input/South Africa/mne_ind_cbc.dta 
*					$data/input/South Africa/EUR_USD_exchange_rate.dta
*
* Output:
*					$data/output/South Africa/ZAF_withvars.csv
*===============================================================================

cls
capture restore
set more off
cap log close
clear all

*****************************************************************************
**************************** LEGAL ENTITIES *********************************
*****************************************************************************


* Load data and append together
use "$data/input/South Africa/citfp_2008_2022_e5_v1.dta", clear

* 1. YEAR:
gen finan_year_end = year(FYE)
gen finan_month_end = month(FYE)
count if finan_year_end != taxyear

* 2. TAX ID:
drop if FID == . // 13 observations

******** SELECT AND CREATE VARIABLES ********

* GROUP 0
rename  taxable_income taxable_income_SARS

	* Identification variables
gen year = taxyear 
gen tax_ID = FID 

generate country = "ZAF"
generate entity = "Legal"	

	* Check for duplicates and drop
duplicates report year tax_ID // No duplicates


	* Dormant firms 
gen dormant = .
replace dormant = 1 if ITR14_c_CompDormant == 1
replace dormant = 1 if c_type_imp == 1
replace dormant = 0 if ITR14_c_CompDormant == 0
replace dormant = 0 if c_type_imp != 1 & ITR14_c_CompDormant != 1 & c_type_imp != .
drop if dormant == 1

	* Rename types
rename c_type_imp type_firm
label define type_label  1 "Dormant" ///
			 2 "Share block company or body corporate" 	///
			 3 "Micro" ///
			 4 "Small" ///
			 5 "Med-Large" 
label values type_firm type_label 			 
			 
*****************************************************************************
/* Depending on the type of firms, they file different sections of the CIT form

i) Balance Sheet information & Income Statement
Type 2 and 3: p6-8
Type 4 : p8-10
Type 5 : p10-15

ii) Tax Computation
All Types: p15-21

*****************************************************************************/

* GROUP A: BALANCE SHEET INFORMATION

** TYPE 2/3: Micro and Share block companies
*........................................................
	*current
gen total_current = ITR14_k_totca
gen c_inventory_net = k_inventory 													// Inventory and work in progress
gen c_trade_net = k_trade 															// Trade and other receivables (net)
gen c_cash = k_cash 																// current assets, cash and cash equivalent
egen total_current_built = rowtotal(c_inventory_net c_trade_net c_cash), missing 

	* non-current
gen total_nocurrent = ITR14_k_totnca 												// hardly any non-0 or missing
gen nc_property = k_ppe 															// Property, plant and equipment
gen nc_vehicles = ITR14_k_vehicles 													// Vehicles
gen nc_loan = k_ltloan 																// Long term loans
egen total_nocurrent_built = rowtotal(nc_property nc_loan), missing 

	*total
gen total_assets = ITR14_k_totassets
egen total_assets_build = rowtotal(c_inventory_net c_trade_net c_cash nc_property nc_loan), missing 
egen tangible_assets = rowtotal(nc_property nc_vehicles), missing
gen intangible_assets = .

** TYPE 4: Small companies
*........................................................

	* non-current
gen nc_invesment = k_investsub 														// Investment in associates and joint ventures
gen nc_other = k_othernca 															// other non current assets
egen total_nocurrent_built_4 = rowtotal(nc_property nc_loan nc_invesment nc_other), missing 
replace total_nocurrent_built = total_nocurrent_built_4 if type_firm == 4

	*current
gen c_debtor = ITR14_k_debtors 														// Debtors exlcuding trade debtors 
gen c_investment = k_stinvest 														// short term invesment 
gen c_other = k_otherca 															// Other current assets 
egen total_current_built_4 = rowtotal(c_inventory_net c_trade_net c_debtor c_cash c_investment c_other), missing 
replace total_current_built = total_current_built_4 if type_firm == 4

	* Capital and reserves
gen total_capital_reserves = ITR14_e_totcapres 
egen total_assets_build_4 = rowtotal(total_nocurrent_built total_current_built), missing 
replace total_assets_build = total_assets_build_4 if type_firm == 4
egen tangible_assets_4 = rowtotal(nc_property), missing 							// long term investment might by intangible
replace tangible_assets = tangible_assets_4 if type_firm == 4
replace intangible_assets = nc_other if type_firm == 4 


** TYPE 5: Med- and Large companies
*........................................................
gen nc_fixedasset = k_faother 														// Other fixed assed
gen nc_intangible = k_goodwill 														// Goodwill and intellectual property
gen nc_deferred  = k_deftax 														// deferred tax assets
 
egen total_nocurrent_built_5 = rowtotal(nc_property nc_fixedasset k_goodwill nc_loan nc_invesment nc_other nc_deferred), missing 
replace total_nocurrent_built = total_nocurrent_built_5 if type_firm == 5

	*total (does not include capital and reserves)
egen total_assets_build_5 = rowtotal(total_nocurrent total_current), missing 
replace total_assets_build = total_assets_build_5 if type_firm == 5

egen tangible_assets_5 = rowtotal(nc_property nc_fixedasset), missing				// long term investment might by intangible
replace tangible_assets = tangible_assets_5 if type_firm == 5
egen intangible_assets_5 = rowtotal(nc_other nc_intangible), missing 
replace intangible_assets = intangible_assets_5 if type_firm == 5

replace total_assets = total_assets_build if total_assets == .

replace total_assets = total_assets_build if total_assets < 0 & (type_firm == 2 | type_firm == 3) 


*****************************************************************************
* GROUP B:  INCOME STATEMENT

* GROUP 1: INCOMES
	* Turnover and other income 
gen turnover = g_sales
replace turnover = abs(g_sales) if g_sales < 0 

	* Other 
egen other_income = rowtotal(y_int y_admin ITR14_y_insproceeds ITR14_y_reitdiv y_accp y_bdebtrec y_div ITR14_y_levy y_other y_royal ITR14_y_idemnopaym ITR14_y_lossrev y_feg), missing
replace other_income = ITR14_y_incntrl if other_income == 0 & ITR14_y_incntrl > 0 & ITR14_y_incntrl!= .
replace other_income = abs(other_income) if other_income < 0

	* Exempt income
gen dividend_income = .
gen dividend_exempt = . 

	* Total income (turnover + other_income)
egen total_income = rowtotal(turnover other_income), missing

*****************************************************************************

* GROUP 2: COST ITEMS
	* Cost of Goods Sold
gen cogs = g_cos
	* Labor Inputs
gen labor_inp = x_labcost
	* Material Inputs
gen material_inp = g_cos 
	*Selling, admin and other operating costs
egen operating_inp = rowtotal(ITR14_x_muncharges x_maint IT14_x_travel ///
							x_admin x_cprof x_officel ///
							x_ins ITR14_x_managemnt ITR14_x_oplease), missing
	* Capital Inputs
egen capital_inp = rowtotal(x_acl ///
				ITR14_x_cre ///
				ITR14_x_capimp ITR14_x_tools ITR14_x_leaseother), missing 
				
	* Financial Inputs
egen financial_inp = rowtotal(x_bdebtrec x_provdd x_dntn x_int ///
							ITR14_x_com ///
							ITR14_x_imploss x_fel x_royalt x_rd ITR14_x_partnloss), missing
	* Depreciation 
egen depreciation = rowtotal(x_deprec	///
								x_alt), missing
gen acc_depreciation = .

	* Other Inputs
egen other_inp = rowtotal(x_other ///
				ITR14_x_bee ITR14_x_cre x_rot), missing 
				
 	* Total costs: add up all costs & expenditure
egen tot_cost_built = rowtotal(capital_inp material_inp operating_inp labor_inp financial_inp depreciation other_inp), missing
gen tot_cost_dataset = x_control
gen tot_cost = tot_cost_dataset + cond(missing(g_cos), 0, g_cos)

*****************************************************************************

* GROUP 3: OPERATING PROFITS
	* Gross profit
gen gross_profit = abs(g_grossprofit)
replace gross_profit = -1*abs(g_grossloss) if g_grossprofit == . 
gen gross_profit_built = turnover - cond(missing(cogs), 0, cogs)  

	* Net profit
gen net_profit = abs(y_np)
replace net_profit = -1*abs(y_nl) if y_np == .

	* replace net_profit = -1 * net_loss if net_profit == 0
gen net_profit_built = total_income - cond(missing(tot_cost), 0, tot_cost)   
sum net_profit_built net_profit

*****************************************************************************
* GROUP 3.bis: ADJUSTEMENTS
*-----------

/*TAX COMPUTATION:
- Debit adjustments: allowables (exempt income, incentives)*/
	*- non-taxable amounts credited to the income statement
	*- Special allowances not claimed in the income statement
	
egen sum_allowable_debit_t = rowtotal(t_deb_aip t_deb_apa t_deb_ifrsa t_deb_exfgn t_deb_extxefgndiv t_deb_cra t_deb_rop t_deb_othnontax t_deb_lcdv t_deb_rot t_deb_wnt t_deb_lpa t_deb_ilp t_deb_dda t_deb_amlmp t_deb_bbe t_deb_dprcal t_deb_fdd t_deb_rnds11 t_deb_mpda t_deb_lrna t_deb_bfp t_deb_udzbe t_deb_udzimp t_deb_prex t_deb_cada t_deb_affe t_deb_fla t_deb_intincs24j t_deb_lpcl t_deb_ospa t_deb_iaa), m

egen sum_allowable_debit_ITR14 = rowtotal(ITR14_t_deb_aptadv ITR14_t_deb_filmsex ITR14_t_deb_gvngrnts ITR14_t_deb_exship ITR14_t_deb_exdta1 ITR14_t_deb_exdta2   ITR14_t_deb_cere2 ITR14_t_deb_ebt ITR14_t_deb_rnds11b ITR14_t_deb_rnds11d ITR14_t_deb_mhda ITR14_t_deb_prtd ITR14_t_deb_rst ITR14_t_deb_pmsbc ITR14_t_deb_apaa ITR14_t_deb_lrncmp ITR14_t_deb_lrnadis ITR14_t_deb_lrncmpdis ITR14_t_deb_gfp ITR14_t_deb_vccs ITR14_t_deb_cere1 ITR14_t_deb_eesd ITR14_t_deb_medlsp ITR14_t_deb_impnoc ITR14_t_deb_impgvnuse ITR14_t_deb_sezbld ITR14_t_deb_buim ITR14_t_deb_hotelbld ITR14_t_deb_redbd ITR14_t_deb_cbd ITR14_t_deb_resud ITR14_t_deb_lcru ITR14_t_deb_revwip ITR14_t_deb_revstckprts ITR14_t_deb_mtmfinass ITR14_t_deb_incintprdinc ITR14_t_deb_reits25bb ITR14_t_deb_cda ITR14_t_deb_eadtra ITR14_t_deb_eadwdd ITR14_t_deb_ecmd ITR14_t_deb_levy ITR14_t_deb_oexmp ITR14_t_deb_ocramnt ITR14_t_deb_lcas37d  ITR14_t_deb_dprcal  ITR14_t_deb_ospa  ITR14_t_deb_dda), m

egen control_total_debit = rowtotal( ITR14_t_deb_aca ITR14_t_deb_sanc  ITR14_t_deb_othrnntxctnrlttl), m 

gen control_total_debit_built = sum_allowable_debit_t
replace control_total_debit_built = sum_allowable_debit_ITR14 if (sum_allowable_debit_t == . | sum_allowable_debit_t == 0)
replace control_total_debit_built = sum_allowable_debit_ITR14 if sum_allowable_debit_ITR14 == control_total_debit
replace control_total_debit_built = sum_allowable_debit_ITR14 if (sum_allowable_debit_ITR14 > sum_allowable_debit_t) & ///
																!missing(sum_allowable_debit_t) &  ///
																!missing(sum_allowable_debit_ITR14) & ///
																(sum_allowable_debit_ITR14 != control_total_debit)
																
gen control_total_debit_label = "t"
replace control_total_debit_label = "ITR14" if (sum_allowable_debit_t == . | sum_allowable_debit_t == 0)
replace control_total_debit_label = "ITR14" if sum_allowable_debit_ITR14 == control_total_debit
replace control_total_debit_label = "ITR14" if (sum_allowable_debit_ITR14 > sum_allowable_debit_t) & ///
																!missing(sum_allowable_debit_t) &  ///
																!missing(sum_allowable_debit_ITR14) & ///
																(sum_allowable_debit_ITR14 != control_total_debit)
*-----------

** CASE 1: sum_allowable_debit_t
	* Exempt income  (From tax base)
egen exempt_income_t = rowtotal(t_deb_exfgn t_deb_extxefgndiv t_deb_cra t_deb_lcdv  t_deb_fdd), m
	* Investment Incentives  (From tax base)
egen investment_taxbase_t = rowtotal(t_deb_bfp t_deb_udzbe t_deb_udzimp t_deb_iaa t_deb_rnds11 ), m
	* Capital allowances  (From tax base)
egen capital_allowance_t = rowtotal(t_deb_wnt t_deb_lpa t_deb_ilp t_deb_dprcal t_deb_mpda t_deb_lpcl t_deb_iaa), missing
	* Other Deductions (always from tax base)
egen other_ded_taxbase_t = rowtotal(t_deb_othnontax t_deb_ospa ///
							t_deb_aip t_deb_apa t_deb_ifrsa t_deb_rop t_deb_prex t_deb_affe t_deb_cada t_deb_intincs24j ///  
							t_deb_dda t_deb_amlmp t_deb_rot ///
							t_deb_bbe	t_deb_lrna t_deb_fla), m
							
	* Add up credits & deductions from tax base: 
egen tot_deduc_taxbase_t = rowtotal(investment_taxbase_t capital_allowance_t other_ded_taxbase_t), missing 


** CASE 2: sum_allowable_debit_ITR14
	* Exempt income  (From tax base)
egen exempt_income_ITR14 = rowtotal(ITR14_t_deb_gvngrnts ITR14_t_deb_exship ITR14_t_deb_exdta1 ITR14_t_deb_exdta2 ITR14_t_deb_oexmp ITR14_t_deb_levy ), m
	* Investment Incentives  (From tax base)
egen investment_taxbase_ITR14 = rowtotal(ITR14_t_deb_lcas37d ITR14_t_deb_ecmd ITR14_t_deb_eadwdd ITR14_t_deb_eadtra ITR14_t_deb_gfp ITR14_t_deb_eesd ITR14_t_deb_rnds11d ITR14_t_deb_rnds11b ITR14_t_deb_cere1 ITR14_t_deb_cere2), m
	* Capital allowances  (From tax base)
egen capital_allowance_ITR14 = rowtotal(ITR14_t_deb_dprcal  ITR14_t_deb_prtd ITR14_t_deb_pmsbc ITR14_t_deb_apaa ITR14_t_deb_sezbld ITR14_t_deb_buim ITR14_t_deb_hotelbld ITR14_t_deb_redbd ITR14_t_deb_cbd ITR14_t_deb_resud ITR14_t_deb_lcru), missing
	* Other Deductions (always from tax base)
egen other_ded_taxbase_ITR14 = rowtotal(ITR14_t_deb_aptadv ITR14_t_deb_filmsex ITR14_t_deb_ebt ITR14_t_deb_mhda ITR14_t_deb_rst ITR14_t_deb_lrncmp ITR14_t_deb_lrnadis ITR14_t_deb_lrncmpdis ITR14_t_deb_vccs ITR14_t_deb_medlsp ITR14_t_deb_impnoc ITR14_t_deb_impgvnuse ITR14_t_deb_revwip ITR14_t_deb_revstckprts ITR14_t_deb_mtmfinass ITR14_t_deb_incintprdinc ITR14_t_deb_reits25bb ITR14_t_deb_cda ITR14_t_deb_ocramnt ITR14_t_deb_ospa ITR14_t_deb_dda), m // epmloyee
							
	* Add up credits & deductions from tax base: 
egen tot_deduc_taxbase_ITR14 = rowtotal(investment_taxbase_ITR14 capital_allowance_ITR14 other_ded_taxbase_ITR14), missing 

* BRING TOGETHER
	* Exempt income
gen exempt_income = exempt_income_t if control_total_debit_label == "t"
replace exempt_income = exempt_income_ITR14 if control_total_debit_label == "ITR14"

	* Investment Incentives  (From tax base)
gen investment_taxbase = investment_taxbase_t if control_total_debit_label == "t"
replace investment_taxbase = tot_deduc_taxbase_ITR14 if control_total_debit_label == "ITR14"

	* Capital allowances  (From tax base)
gen capital_allowance = capital_allowance_t if control_total_debit_label == "t"
replace capital_allowance = capital_allowance_ITR14 if control_total_debit_label == "ITR14"

	* Other Deductions (always from tax base)
gen other_ded_taxbase = other_ded_taxbase_t if control_total_debit_label == "t"
replace other_ded_taxbase = other_ded_taxbase_ITR14 if control_total_debit_label == "ITR14"

	* Add up credits & deductions from tax base: 
gen tot_deduc_taxbase = tot_deduc_taxbase_t if control_total_debit_label == "t"
replace tot_deduc_taxbase = tot_deduc_taxbase_ITR14 if control_total_debit_label == "ITR14"


/*	
- Credit adjustments (to be added back): goes into non-deductible costs
	- non-deductible amounts debited to the income statement */
	
		* Non deductible Inputs
egen non_deduc_inp_t = rowtotal(t_cred_aip t_cred_alfs t_cred_alda t_cred_ifrs t_cred_alpi t_cred_cel t_cred_eex t_cred_lscpp t_cred_exnp t_cred_dono t_cred_prex t_cred_faa t_cred_nddtpa t_cred_onddebit t_cred_rvcrdada t_cred_rvfutexp t_cred_rvoadjrev t_cred_ancaar t_cred_ancaan t_cred_anclcs t_cred_anclnfi t_cred_anconci t_cred_clai), missing

egen non_deduc_inp_ITR14 = rowtotal(ITR14_t_cred_ifrsa ITR14_t_cred_ifrsfv ITR14_t_cred_dfs ITR14_t_cred_pdvdd ITR14_t_cred_pndcy ITR14_t_cred_ndp ITR14_t_cred_dda ITR14_t_cred_dons18 ITR14_t_cred_ndint ITR14_t_cred_stipna ITR14_t_cred_inadbts ITR14_t_cred_lointd ITR14_t_cred_cifrm ITR14_t_cred_rvpyall ITR14_t_cred_tandecl  ITR14_t_cred_clostck ITR14_t_cred_ancintac ITR14_t_cred_ancmtmasslia ITR14_t_cred_anctppa ITR14_t_cred_rapgbd ITR14_t_cred_rapgwt ITR14_t_cred_rapglsc ITR14_t_cred_rapgvcc ITR14_t_cred_rapgdebt ITR14_t_cred_rapgother   ITR14_t_cred_othercreditadj ITR14_t_cred_inpes23d  ), missing

		* Total control
gen addback_control_built = ITR14_t_cred_adjaddtotal
replace addback_control_built = ITR14_t_cred_ndadtotal if (missing(ITR14_t_cred_adjaddtotal) | ITR14_t_cred_adjaddtotal == 0)

gen non_deduc_inp = non_deduc_inp_t
replace non_deduc_inp = non_deduc_inp_ITR14 if (non_deduc_inp_t == . | non_deduc_inp_t == 0)
replace non_deduc_inp = non_deduc_inp_ITR14 if non_deduc_inp_ITR14 == addback_control_built
replace non_deduc_inp = non_deduc_inp_ITR14 if (non_deduc_inp_ITR14 > non_deduc_inp_t) & ///
																!missing(non_deduc_inp_t) &  ///
																!missing(non_deduc_inp_ITR14) & ///
																(non_deduc_inp_ITR14 != addback_control_built)

		* Label how the different credits are constructed:
gen control_total_credit_label = "t"
replace control_total_credit_label = "ITR14" if (non_deduc_inp_t == . | non_deduc_inp_t == 0)
replace control_total_credit_label = "ITR14" if non_deduc_inp_ITR14 == addback_control_built
replace control_total_credit_label = "ITR14" if (non_deduc_inp_ITR14 > non_deduc_inp_t) & ///
																!missing(non_deduc_inp_t) &  ///
																!missing(non_deduc_inp_ITR14) & ///
																(non_deduc_inp_ITR14 != addback_control_built)
*-----------

	    * Deductible Costs: total costs - non-deductible inputs 
gen deductible_cost = tot_cost - cond(missing(non_deduc_inp), 0, non_deduc_inp) 

* GROUP 4: GROSS & NET TAX BASE

	* Taxable income (-exempt income)
gen taxable_income = total_income - cond(missing(exempt_income), 0, exempt_income)

	* Taxable profit
gen taxable_profit = taxable_income - cond(missing(deductible_cost), 0, deductible_cost)

	* Gross tax base (taxable_profit - tot_deduc_taxbase)
gen gross_tax_base = taxable_profit - cond(missing(tot_deduc_taxbase), 0, tot_deduc_taxbase)


****************************************************************************

	* Gross tax base 
replace gross_tax_base = 0 if gross_tax_base == .  

gen double rcpp_losses_mk = taxable_income_SARS
replace rcpp_losses_mk = gross_tax_base  if gross_tax_base >=0 & gross_tax_base< .  & (rcpp_losses_mk > 0 & rcpp_losses_mk< .) & tax_ID ==tax_ID[_n-1] 
replace rcpp_losses_mk = gross_tax_base+ rcpp_losses_mk[_n-1] if ((gross_tax_base>0  & gross_tax_base<. & rcpp_losses_mk[_n-1]<0 )  | ///
															     (gross_tax_base<0   & rcpp_losses_mk[_n-1]<0 ) |    ///
																 (gross_tax_base<0   & rcpp_losses_mk[_n-1]>0 )) & tax_ID ==tax_ID[_n-1]

	* Loss carryforward
gen diff_assed_losses = gross_tax_base - taxable_income_SARS
gen loss_carryforward = diff_assed_losses
replace loss_carryforward = 0 if diff_assed_losses<0 

	* Net tax base (gross_tax_base - loss_carryforward)
gen net_tax_base =  taxable_income_SARS

	* replace net_tax_base = -1 * tax_loss if net_tax_base == 0
gen net_tax_base_built = gross_tax_base - cond(missing(loss_carryforward), 0, loss_carryforward)


* GROUP 5: GROSS & NET TAX LIABILITY

	* Gross tax liability (net tax base*CIT rate)
gen gross_tax_liability = total_tax_payable 
gen rate =  gross_tax_liability / net_tax_base 

	* Credits for foreign taxes paid
gen cred_foreign_tax = .	
	* Investment credits from tax liability
gen investment_taxliab = .
	* Special firms credits from tax liability
gen special_taxliab = .
	* International Trade credits 
gen trade_taxliab = .
	* Other credit and allowances from tax liability
gen other_cred_taxliab = .

	* Add up credits & deductions from tax liability 
egen tot_deduc_taxliab = rowtotal(cred_foreign_tax special_taxliab trade_taxliab investment_taxliab other_cred_taxliab), missing
	* Add up credits & deductions that are not necessarily real credits from tax liability 
egen tot_noelse_taxliab = rowtotal(cred_foreign_tax  other_cred_taxliab), missing

	* Net tax liability (gross_tax_liability - tot_deduc_taxliab)
gen net_tax_liability = total_tax_payable
gen net_tax_liability_built = gross_tax_liability - cond(missing(tot_deduc_taxliab), 0, tot_deduc_taxliab)

	* Net tax liability without foreign and other credits  
gen ntl_noelse = net_tax_liability + cond(missing(tot_noelse_taxliab), 0, tot_noelse_taxliab)


* GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS

	* Add up partial/advance payments
gen partial_advanced_pay = .
	* Add withholding 
gen withholding = .
	* Other creditable tax payments
gen other_cred_tax_pay = .

	* Tax to remit
gen tax_to_remit = .

**** Treatment of missings and 0
foreach var of varlist gross_tax_base net_tax_base gross_tax_liability net_tax_liability tax_to_remit {
    replace `var' = 0 if missing(`var') & !missing(total_income)
}

*********** ABSOLUTE TAX BASE & TAX LIABILITY  **********************

replace rate = 0 if net_tax_base == 0 
 
* Move tax liability deductions up before gross tax base level
gen abs_deduc_taxbase = tot_deduc_taxliab*(1/rate)
replace abs_deduc_taxbase = 0 if missing(abs_deduc_taxbase)
gen abs_gross_tax_base = gross_tax_base - abs_deduc_taxbase
gen abs_net_tax_base = net_tax_base - abs_deduc_taxbase
gen abs_tax_liability = abs_net_tax_base*rate

*********** NET OF LOSSES (NOL) TAX BASE & TAX LIABILITY  **********************
gen nol_tax_base = abs_net_tax_base + cond(missing(loss_carryforward), 0, loss_carryforward)
gen losses_tax_liab = loss_carryforward*rate
gen nol_tax_liability = abs_tax_liability + cond(missing(losses_tax_liab), 0, losses_tax_liab)

********* Add labels and drop some variables ********
label variable tax_ID "Tax ID"
label variable year "Fiscal Year"
label variable turnover "Turnover"
label variable total_income "Total income"
label variable taxable_income "Taxable income"
label variable tot_cost "Total Costs"
label variable deductible_cost "Deductible Costs"
label variable net_profit "Net profit"
label variable taxable_income "Taxable profit"
label variable gross_tax_base "Gross Tax Base"
label variable abs_gross_tax_base "Gross Tax Base after all Deductions (Tax base + Reintegrated Tax Liab)"
label variable tot_deduc_taxbase "Total Credits & Deductions - Tax Base"
label variable abs_deduc_taxbase "Total Credits & Deductions Reintegrated from Tax Liability"
label variable net_tax_base "Net Tax Base"
label variable abs_net_tax_base "Net Tax Base net of all deductions"
label variable nol_tax_base "Tax Base Net of Losses Carryfoward + all Reintegrated Deductions"
label variable nol_tax_liability "Tax Liability Net of Losses Carryfoward"
label variable gross_tax_liability "Gross Tax Liability"
label variable net_tax_liability "Net Tax Liability"
label variable tot_deduc_taxliab "Total Credits & Deductions - Tax Liability"
label variable tax_to_remit "Tax to Remit"
label variable country "Country"

**********************************************************************

* Add sectors
	
* Standardized NACE rev 2 code
gen section = ""
replace section = "A" if imp_mic_sic7_1d == -1
replace section = "B" if imp_mic_sic7_1d == -2 
replace section = "C" if imp_mic_sic7_1d == -3 
replace section = "D" if imp_mic_sic7_1d == -4
replace section = "E" if imp_mic_sic7_1d == -5
replace section = "F" if imp_mic_sic7_1d == -6
replace section = "G" if imp_mic_sic7_1d == -7
replace section = "H" if imp_mic_sic7_1d == -8
replace section = "I" if imp_mic_sic7_1d == -9
replace section = "J" if imp_mic_sic7_1d == -10
replace section = "K" if imp_mic_sic7_1d == -11
replace section = "L" if imp_mic_sic7_1d == -12
replace section = "M" if imp_mic_sic7_1d == -13 
replace section = "N" if imp_mic_sic7_1d == -14
replace section = "O" if imp_mic_sic7_1d == -15
replace section = "P" if imp_mic_sic7_1d == -16
replace section = "Q" if imp_mic_sic7_1d == -17
replace section = "R" if imp_mic_sic7_1d == -18
replace section = "S" if imp_mic_sic7_1d == -19
replace section = "T" if imp_mic_sic7_1d == -20
replace section = "U" if imp_mic_sic7_1d == -21

gen descr_section = section
replace descr_section = "AGRICULTURE, FORESTRY AND FISHING" if section == "A"
replace descr_section = "MINING AND QUARRYING" if section == "B"
replace descr_section = "MANUFACTURING" if section == "C"
replace descr_section = "ELECTRICITY, GAS, STEAM AND AIR CONDITIONING SUPPLY" if section == "D"
replace descr_section = "WATER SUPPLY; SEWERAGE, WASTE MANAGEMENT AND REMEDIATION ACTIVITIES" if section == "E"
replace descr_section = "CONSTRUCTION" if section == "F"
replace descr_section = "WHOLESALE AND RETAIL TRADE; REPAIR OF MOTOR VEHICLES AND MOTORCYCLES" if section == "G"
replace descr_section = "TRANSPORTATION AND STORAGE" if section == "H"
replace descr_section = "ACCOMODATION AND FOOD SERVICE ACTIVITIES" if section == "I"
replace descr_section = "INFORMATION AND COMMUNICATION" if section == "J"
replace descr_section = "FINANCIAL AND INSURANCE ACTIVITIES" if section == "K"
replace descr_section = "REAL ESTATE ACTIVITIES" if section == "L"
replace descr_section = "PROFESSIONAL, SCIENTIFIC AND TECHNICAL ACTIVITIES" if section == "M"
replace descr_section = "ADMNINISTRATIVE AND SUPPORT SERVICE ACTIVITIES" if section == "N"
replace descr_section = "PUBLIC ADMINISTRATION AND DEFENCE; COMPULSORY SOCIAL SECURITY" if section == "O"
replace descr_section = "EDUCATION" if section == "P"
replace descr_section = "HUMAN HEALTH AND SOCIAL WORK ACTIVITIES" if section == "Q"
replace descr_section = "ARTS, ENTERTAINMENT AND RECREATION" if section == "R"
replace descr_section = "OTHER SERVICE ACTIVITIES" if section == "S"
replace descr_section = "ACTIVITY OF HOUSEHOLDS AS EMPLOYERS; ACTIVITIES OF HOUSEHOLDS FOR OWN USE" if section == "T"
replace descr_section = "ACTIVITY OF EXTRATERRITORIAL ORGANISATIONS AND BODIES" if section == "U"

**********************************************************************

* GROUP 7: FIRM CHARACTERISTICS

	* REGIONAL: 
	*---------------------
gen capital_city = inlist(c_province, 1, 7) 
replace capital_city = . if c_province == . | c_province == 0

gen region = c_province
replace region = . if c_province == 0
tab region

gen city = .
gen tax_center = .

		* FIRM DYNAMIC:
		*---------------------
gen incorporation = .
gen firm_age = .

merge 1:1 year tax_ID using "$data/input/South Africa/CIT-IRP5_employee.dta"
gen nb_employee = irp5_kerr_weight_b
bys year: tab _merge
tab _merge type_firm
drop if _merge == 2

		* SPECIAL ECONOMIC ZONE:
		*---------------------
gen private = . 
gen FEZ = inlist(ITR14_c_sezqualcomp, 1)
replace FEZ = 1 if ITR14_c_udzqual == 1

		* MNE:
		*---------------------
* 1. HQ: 
gen country_HQ = ITR14_c_forhold
replace country_HQ = "" if (country_HQ == "0" | ///
						   country_HQ == "359" | ///
						   country_HQ == "ZZZ" | ///
						   country_HQ == "C" | ///
						   country_HQ == " ")

replace country_HQ = "ZAF" if (country_HQ == "za" | ///
						   country_HQ == "ZA")
replace country_HQ = "SAU" if (country_HQ == "SA")
replace country_HQ = "FRA" if (country_HQ == "fr")
replace country_HQ = "NZL" if (country_HQ == "NZ")
replace country_HQ = "MUS" if (country_HQ == "MU")
replace country_HQ = "JPN" if (country_HQ == "JP")
replace country_HQ = "GIB" if (country_HQ == "GI")
replace country_HQ = "ESP" if (country_HQ == "ES")
replace country_HQ = "CHN" if (country_HQ == "CN")
replace country_HQ = "BLZ" if (country_HQ == "BZ")
tab country_HQ

* Construct
gen foreign_HQ_built = inlist(ITR14_c_fgnhold, 1) /
replace foreign_HQ_built = 0 if country_HQ == "ZAF"	
replace foreign_HQ_built = 0 if ITR14_c_mne_type == 1
replace foreign_HQ_built = . if country_HQ == ""

* Standing var in data:
gen foreign_HQ = .
replace foreign_HQ = 0 if ITR14_c_mne_type == 1
replace foreign_HQ = 1 if ITR14_c_mne_type == 2
replace foreign_HQ = 0 if country_HQ == "ZAF" 
replace country_HQ = "ZAF" if ITR14_c_mne_type == 1

gen MNE = inlist(ITR14_c_mne, 1) 
replace MNE = . if ITR14_c_mne == .
replace MNE = 1 if foreign_HQ != .

gen MNE_nm = MNE
replace MNE_nm = 0 if MNE == .

* 3.  MNE with foreign parent:
gen foreign_ownership = 0
replace foreign_ownership = 1 if MNE == 1 & foreign_HQ == 1

* Consolidated turnover (Available from 2017 onwards)
gen cons_group_turnover = abs(c_grpturnover)

* 4. CbCr reporting:
drop _merge

merge 1:1 taxyear taxrefno using  "$data/input/South Africa/mne_ind_cbc.dta"
drop if _merge == 2
drop _merge

gen cbcr = .
replace cbcr = 0 if mne_group_cbc == "N"
replace cbcr = 1 if mne_group_cbc == "Y"
replace cbcr = . if year<2019

gen MNE_wide = MNE_nm
replace MNE_wide = 1 if cbcr == 1 

gen foreign_ownership_wide = foreign_ownership
replace foreign_ownership_wide = 1 if MNE_wide == 1 & country_HQ == "" & ITR14_c_mne_type != 1
	 
* 5. Group Identifier
egen group_mne_id = group(cons_group_turnover country_HQ year)
egen group_mne_id_noHQ = group(cons_group_turnover year)  if country_HQ == ""
tostring group_mne_id_noHQ, replace 
replace group_mne_id_noHQ= group_mne_id_noHQ + "noHQ"
tostring group_mne_id, replace 
replace group_mne_id= group_mne_id + "HQ"
replace group_mne_id = group_mne_id_noHQ if country_HQ == "" 
replace group_mne_id = "" if cons_group_turnover == . 
bys year group_mne_id: gen subsidiary_count = _N
replace subsidiary_count = . if group_mne_id == ""	 

gen consolidated_revenue = cons_group_turnover 
sort year country_HQ consolidated_revenue

gen aux=0
gen lower_bound = (1 - 0.005) * consolidated_revenue
gen upper_bound = (1 + 0.005) * consolidated_revenue

replace aux = 1 if year!=year[_n-1] | country_HQ!=country_HQ[_n-1] | lower_bound>upper_bound[_n-1]

sort year country_HQ consolidated_revenue
gen group_mne_id_1 = sum(aux)
replace group_mne_id_1 = . if consolidated_revenue == .
bys year group_mne_id_1: gen subsidiary_count_1 = _N
replace subsidiary_count_1 = . if group_mne_id_1 == .	 

* Cross check CBCR with consolidated revenue:

* EUR_USD exchange rates: 
merge m:1 year using "$data/input/South Africa/EUR_USD_exchange_rate.dta" 
drop if _merge == 2
drop _merge 

* Exchange_rate_RAND_USD: (from WDI)
gen xchange_rate = .
replace xchange_rate = 14.7 if year == 2016
replace xchange_rate = 13.3 if year == 2017
replace xchange_rate = 13.2 if year == 2018
replace xchange_rate = 14.4 if year == 2019
replace xchange_rate = 16.5 if year == 2020
replace xchange_rate = 14.8 if year == 2021
replace xchange_rate = 16.4 if year == 2022

* Create consolidated turnover in USD
gen cons_turnover_USD = cons_group_turnover*xchange_rate
gen limit_USD750m = 750000000/EUR_USD_exchange_rate

gen above_750m = 0
replace above_750m = 1 if cons_turnover_USD >= limit_USD750m 
replace above_750m = . if cons_turnover_USD == .	 
	 
************* KEEP VARIABLES WE NEED *************

	* Create locals to keep variables
local group0 year country tax_ID entity   section descr_section taxrefno
local group1 turnover exempt_income other_income total_income taxable_income dividend_exempt dividend_income
local group2 tot_cost *_inp deductible_cost depreciation acc_depreciation cogs
local group3 taxable_profit net_profit gross_profit
local group4 investment_taxbase capital_allowance loss_carryforward net_tax_base gross_tax_base tot_deduc_taxbase
local group5 gross_tax_liability net_tax_liability tot_deduc_taxliab cred_foreign_tax investment_taxliab other_cred_taxliab 
local group6 withholding partial_advanced_pay other_cred_tax_pay tax_to_remit ntl_noelse tot_noelse_taxliab special_taxliab trade_taxliab
local group7 capital_city region incorporation firm_age nb_employee city total_assets   foreign_ownership
local group8 dormant total_current total_current_built total_nocurrent total_nocurrent_built total_assets total_assets_build tangible_assets intangible_assets sum_allowable_debit_t sum_allowable_debit_ITR14 control_total_debit_built control_total_debit_label control_total_debit addback_control_built control_total_credit_label diff_assed_losses rcpp_losses_mk rate
local group9  cons_group_turnover foreign_ownership* MNE* foreign_HQ foreign_HQ_built MNE FEZ irp5_kerr_weight_b cbcr group_mne_id group_mne_id subsidiary_count* above_750m limit_USD750m EUR_USD_exchange_rate cons_turnover_USD   group_mne_id_1 country_HQ type_firm

	* Keep selected variables
keep  `group0' `group1' `group2' `group3' `group4' `group5' `group6' `group7' `group8'  `group9' 

	* Keep only legal entities and save
keep if entity == "Legal"
keep if year >= 2014
	
	* Final adjustments
sort tax_ID year, stable

	* Export data
export delimited using ".\data\clean\ZAF_withvars.csv", replace 