*===============================================================================
* File name: 		CRI_Lasso_Estimates.do
* 
* Description:		This do-file creates the dataset CRI_Lasso_Estimates.dta. 
*
* Input:  					
*					$data/input/Costa Rica/D152_`i'.xlsx 
*					$data/input/Costa Rica/RENTA_TD_2017_2018.xlsx
*					$data/input/Costa Rica/Diccionario de tablas.xlsx
*					$data/input/Costa Rica/2021-08-13 Datos identificativos_Final.xlsx
*					$data/input/Costa Rica/CRI_withvars_temp.dta
*
* Output:
*					$data/input/Costa Rica/CRI_Lasso_Estimates.dta
*===============================================================================

cls
capture restore
set more off
cap log close
clear all

/* -------------- */
/* Load D152 data */
/* -------------- */

clear 
set more off

/* Load each D152 file */
foreach i in 0 1 2 3 4 5 6 7 8 9 {
	import excel using "$data/input/Costa Rica/D152_`i'.xlsx", firstrow case(lower) clear
	tempfile D152_`i'
	save `D152_`i'', replace
}

use `D152_0', clear

foreach i in 1 2 3 4 5 6 7 8 9 {
	append using `D152_`i''
}

replace c_concepto=subinstr(c_concepto, " ", "", .)
keep if c_concepto=="SL"

format %16.0g nro_declarac

sort nro_internoid_reportador nro_internoid_retenido d_periodo

drop if nro_internoid_reportador==.

gen year=year(d_periodo)

order nro_internoid_reportador nro_internoid_retenido year c_concepto

/* Check duplicates */
duplicates report nro_internoid_reportador nro_internoid_retenido year 

bys nro_internoid_reportador nro_internoid_retenido year: gen N=_N
sort N nro_internoid_reportador nro_internoid_retenido d_periodo
duplicates report
drop N

/* Collapse data at the firm level (IDU reportador) */
gen N=1
gen exchange_rate=545 if year==2016
replace exchange_rate=568 if year==2017
replace exchange_rate=577 if year==2018
replace exchange_rate=587 if year==2019
replace exchange_rate=584 if year==2020
replace exchange_rate=620 if year==2021
replace exchange_rate=647 if year==2022
replace exchange_rate=542 if year==2023

collapse (sum) p_base_rete p_impto_rete N (mean) exchange_rate, by(nro_internoid_reportador year)

ren p_base_rete 	wages
ren p_impto_rete	tax_wages

gen wages_usd=wages/exchange_rate
gen tax_wages_usd=tax_wages/exchange_rate

ren nro_internoid_reportador tax_ID

sort tax_ID year
distinct tax_ID

/*
Dataset info

58,593 observations, distributed in 8 different years (2016-2023)
14,301 firms

*/

/* Save data */
save "$data/temp/Costa Rica/D152_2016_2023.dta", replace

/* ------------- */
/* Load SAP data */
/* ------------- */

clear 
set more off
	
/* Append files */
import excel using "$data/input/Costa Rica/RENTA_TD_2017_2018.xlsx", firstrow case(lower) sh(2017) clear
tempfile temp
save `temp', replace

import excel using "$data/input/Costa Rica/RENTA_TD_2017_2018.xlsx", firstrow case(lower) sh(2018) clear
append using `temp'

/* Rename variables */
rename id_interno tax_ID
rename a_02_periodo_fiscal year	
rename a_98_fecha_recepcion d_periodo

gen sap=1
label var sap "Observation comes from SAP data (1=Yes)"

/* Compute wage related variables */
egen a_34_35_b=rowtotal(a_34_gasto_gene_y_admi a_35_gasto_vent_y_dist), missing
egen a_128_138_b=rowtotal(a_128_totales a_138_totales), missing

egen total_wages=rowtotal(a_120_sueldos_y_salari a_130_sueldos_y_salari), missing

gen sh_wages_admin_costs=total_wages/a_128_138_b*100

egen turnover=rowtotal(a_20_ingres_venta_bien a_21_ingres_venta_serv a_22_servi_profes_hono), missing
gen turnover_millions=turnover/1000000

/* ASSETS */
egen tang_assets=rowtotal(a_150_efecti_y_equi_ef a_151_inversiones a_152_cuenta_p_cobr_cl a_153_cuenta_p_cobr_so a_154_cuenta_p_cobr_ot a_155_accion_y_apor_so a_156_inventarios a_157_activos_fijos a_158_deprecia_acti_fi), missing

egen tot_assets=rowtotal(a_150_efecti_y_equi_ef a_151_inversiones a_152_cuenta_p_cobr_cl a_153_cuenta_p_cobr_so a_154_cuenta_p_cobr_ot a_155_accion_y_apor_so a_156_inventarios a_157_activos_fijos a_158_deprecia_acti_fi a_163_otros_activos), missing

gen sh_other_assets=a_163_otros_activos/tot_assets

gen sh_assets_tang_tot=tang_assets/tot_assets*100
gen sh_assets_tot_tang=tot_assets/tang_assets
summ sh_assets_tot_tang
winsor sh_assets_tot_tang, gen(sh_assets_tot_tang_w) p(0.01) highonly
			
xtile quantile=turnover_millions if turnover>1, n(10)
bys quantile: egen mean_q_sh_assets=mean(sh_assets_tot_tang_w)
bys quantile: egen mean_turnover=mean(turnover_millions)
tab mean_q_sh_assets
tab mean_q_sh_assets mean_turnover

/* Save SAP data */
save "$data/temp/Costa Rica/SAP_raw_all_new.dta", replace

/* ------------ */
/* SECTORS DATA */
/* ------------ */

* 1) Sectors Dictionary: gives the 5-6 digits code with their description. Follows a special standadization
	import excel "$data/input/Costa Rica/Diccionario de tablas.xlsx", sheet("Código Act Económicas") firstrow clear
	duplicates drop
	drop if missing(CódigoActividad)
	tempfile sectors
	save `sectors' // ready to be merged at the 5 or 6 digit codes

	// Create a less granulated sections: some 5-6 d sectors will not match, so we still extract the 
	// division to match the first 2 numbers and get the section categories for the firms
	tostring CódigoActividad, gen(code)
	gen division = substr(code, 1, 2) 
	replace division = substr(code, 1, 1) if strlen(code) == 5
	drop if SectorEconómico == "Z" | SectorEconómico == "W" // those are discontinued firms or without categories
	replace SectorEconómico = "K"	 if division == "71"
	replace SectorEconómico = "L"	 if division == "75" 
	replace SectorEconómico = "O"	 if division == "91" 
	replace SectorEconómico = "O"	 if division == "92" 
	collapse (count) CódigoActividad , by(division SectorEconómico)
	sort SectorEconómico
	drop if division == "90"
	destring division, replace
	tempfile sectors_2d
	save `sectors_2d' 

* 2) Prepare the Final Batch to match with the sectors, based on tax_ID
	import excel "$data/input/Costa Rica/2021-08-13 Datos identificativos_Final.xlsx", sheet("Datos") firstrow clear
	rename nro_InternoID tax_ID
	duplicates drop
	
	replace Codigo_AEP_Activa = "." if  Codigo_AEP_Activa=="NULL"
	gen division = substr(Codigo_AEP_Activa, 1, 2) 
	replace division = substr(Codigo_AEP_Activa, 1, 1) if strlen(Codigo_AEP_Activa) == 5
	destring division, replace
	destring Codigo_AEP_Activa, gen(CódigoActividad)
	drop if CódigoActividad == .

	* Merge with the file 1)i. sectors
	merge m:1 CódigoActividad using `sectors'
	drop _merge
	
	* Merge with the file 1)ii. sectors_2d
	merge m:1 division using `sectors_2d'
	replace SectorEconómico = "W" if division == 96
	drop _merge
	drop if missing(tax_ID)
	
* 3) Adapt to CIIU4. Standardization
	gen section = SectorEconómico
	replace section = "C" if SectorEconómico == "D"
	replace section = "I" if SectorEconómico == "H"
	replace section = "L" if SectorEconómico == "K"
	replace section = "D" if SectorEconómico == "E"
	replace section = "H" if SectorEconómico == "I"
	replace section = "K" if SectorEconómico == "J"
	replace section = "S" if SectorEconómico == "O"
	replace section = "O" if SectorEconómico == "L"
	replace section = "P" if SectorEconómico == "M"
	replace section = "B" if SectorEconómico == "C"
	replace section = "T" if SectorEconómico == "P"
	replace section = "U" if SectorEconómico == "Q"
	replace section = "Q" if SectorEconómico == "N"
	replace section = "A" if SectorEconómico == "B"
	replace section = "" if SectorEconómico == "Z" // No categories

	* CIIU4. Standardization. 
	gen descr_section = section 
	replace descr_section = "Agricultura, ganaderia, silvicultura y pesca" if section == "A"
	replace descr_section = "Explotacion de minas y canteras" if section == "B"
	replace descr_section = "Industrias manufactureras" if section == "C"
	replace descr_section = "Suministro de electricidad, gas, vapor y aire acondicionado" if section == "D"
	replace descr_section = "Suministro de agua, evacuacion de aguas residuales, gestion de desechos y descontaminacion" if section == "E"
	replace descr_section = "Construccion" if section == "F"
	replace descr_section = "Comercio al por mayor y al por menor; reparacion de vehiculos automotores y motocicletas" if section == "G"
	replace descr_section = "Transporte y almacenamiento" if section == "H"
	replace descr_section = "Actividades de alojamiento y servicio de comidas" if section == "I"
	replace descr_section = "Informacion y comunicaciones" if section == "J"
	replace descr_section = "Actividades financieras y de seguros" if section == "K"
	replace descr_section = "Actividades inmobiliarias" if section == "L"
	replace descr_section = "Actividades profesionales, cientificas y tecnicas" if section == "M"
	replace descr_section = "Actividades de servicios administrativos y de apoyo" if section == "N"
	replace descr_section = "Administracion publica y defensa; planes de seguridad social de afiliacion obligatoria" if section == "O"
	replace descr_section = "Ensenanza" if section == "P"
	replace descr_section = "Actividades de atencion de la salud humana y de asistencia social" if section == "Q"
	replace descr_section = "Actividades artisticas, de entretenimiento y recreativas" if section == "R"
	replace descr_section = "Otras actividades de servicio" if section == "S"
	replace descr_section = "Actividades de los hogares como empleadores; actividades no diferenciadas de los hogares como productores de bienes y servicios para uso propio" if section == "T"
	replace descr_section = "Actividades de organizaciones y organos extraterritoriales" if section == "U"

	drop NombreActividad SectorEconómico SectorEconómicoDescripción
	gen country = "CRI"
	rename Codigo_AEP_Activa ACT
	
* Save temp sectors data
	tempfile sectors_full
	save `sectors_full'

/* --------------------- */
/* MERGE D152 & SAP DATA */
/* --------------------- */

/* Load SAP data */
use "$data/temp/Costa Rica/SAP_raw_all_new.dta", clear

sort tax_ID year
 
merge 1:1 tax_ID year using "$data/temp/Costa Rica/D152_2016_2023.dta"
keep if _merge==3
drop _merge

/* Organize and compare */
ren wages wages_d152
ren wages_usd wages_usd_d152
ren total_wages wages_sap

gen wages_sap_usd=wages_sap/exchange_rate
order tax_ID year wages_sap_usd wages_usd_d152 wages_sap wages_d152

/* Drop cases we can't compare */
drop if wages_sap==. // 1,462 cases dropped
drop if wages_d152==. // 0 cases dropped

replace wages_sap_usd=wages_sap_usd/1000
replace wages_usd_d152=wages_usd_d152/1000

replace wages_sap_usd=round(wages_sap_usd)
replace wages_usd_d152=round(wages_usd_d152)

gen sap_higher=(wages_sap_usd>=wages_usd_d152)
gen sap_lower=(wages_sap_usd<wages_usd_d152)

gen wage_gap=abs(wages_sap_usd-wages_usd_d152)
gen wage_gap_sh=wage_gap/wages_sap_usd*100

order tax_ID year wages_sap_usd wages_usd_d152 sap_higher sap_lower wage_gap wage_gap_sh wages_sap wages_d152

gen sap_higher_adj=sap_higher
gen sap_lower_adj=sap_lower
replace sap_higher_adj=1 if wage_gap_sh<=15
replace sap_lower_adj=0 if wage_gap_sh<=15

tab sap_higher_adj // 85% with the adjusted measure

sort wage_gap_sh tax_ID year

/* CREATE STANDARD VARIABLES TO USE AS EXPLANATORY COMPONENTS */
drop turnover
egen turnover =rowtotal(a_20_ingres_venta_bien a_21_ingres_venta_serv a_22_servi_profes_hono), missing
replace turnover = . if a_20_ingres_venta_bien==. & a_21_ingres_venta_serv==. & a_22_servi_profes_hono==.

egen other_income = rowtotal(a_23_comisiones a_24_alquileres a_25_interes_y_rend_fin a_26_dividen_y_partici a_27_otros_ingresos a_28_devoluc_y_descuen), missing
	* Exempt income
gen exempt_income = a_29_ingresos_no_grava

* Dividend income
gen dividend_income=a_26_dividen_y_partici
gen dividend_exempt=a_101_dividen_y_partic 

	* Total income (turnover + other_income)
egen total_income =  rowtotal(turnover other_income exempt_income), missing	
	* Taxable income (-exempt income)
gen taxable_income = a_30_total_ingres_brut

* GROUP 2: COST ITEMS
	* Cost of goods sold
gen cogs = a_31_costo_de_ventas
	* Labor Inputs
egen labor_inp = rowtotal(a_120_sueldos_y_salari  a_130_sueldos_y_salari ), missing
	* Material Inputs
gen material_inp =a_31_costo_de_ventas
	* Selling, admin and other operating costs
egen operating_inp = rowtotal(a_35_gasto_vent_y_dist a_34_gasto_gene_y_admi a_32_costo_ventas_industriales ), missing
	* Capital Inputs
gen capital_inp =.
	* Financial Inputs
egen financial_inp = rowtotal(a_37_otros_gast_financ a_36_intereses), missing 
	* Depreciation 
egen depreciation = rowtotal(a_126_gasto_p_deprecia a_136_gastos_por_depre), missing 
gen acc_depreciation = .
	* Other Inputs
gen other_inp = . 
	* Non deductible Inputs
gen non_deduc_inp = a_41_gast_no_ded_inc_a
 	* Total costs: add up all costs & expenditure
egen tot_cost_built = rowtotal(capital_inp material_inp operating_inp labor_inp financial_inp depreciation other_inp), missing
gen tot_cost_dataset = a_33_total_costos
gen tot_cost = tot_cost_dataset
	* Deductible Costs: total costs - non-deductible inputs 
gen deductible_cost = a_42_tot_gast_y_otr_de 
gen deductible_cost_built = tot_cost - cond(missing(non_deduc_inp), 0, non_deduc_inp) 

* GROUP 3: PROFITS
	* Gross profit
gen gross_profit = total_income - cond(missing(cogs), 0, cogs) 
	* Net profit
gen net_profit = total_income - cond(missing(tot_cost), 0, tot_cost)

	* Taxable profit
gen taxable_profit = . // after all adjustment
gen taxable_profit_built = taxable_income - cond(missing(deductible_cost), 0, deductible_cost) // after all adjustment

* GROUP 4: GROSS & NET TAX BASE
	* Investment Incentives  (From tax base)
gen investment_taxbase = .
	* Capital allowances  (From tax base)
gen capital_allowance = .
	* Losses (always from tax base)
gen loss_carryforward = . 
	* Other Deductions (always from tax base)
egen other_ded_taxbase = rowtotal(a_40_otras_deducciones a_39_apor_reg_vol_pens a_38_deduc_perdid_dife), missing 
	* Add up credits & deductions from tax base: 
egen tot_deduc_taxbase = rowtotal(investment_taxbase capital_allowance other_ded_taxbase), missing 

	* Gross tax base (taxable_profit - tot_deduc_taxbase)
gen gross_tax_base_built = taxable_profit - cond(missing(tot_deduc_taxbase), 0, tot_deduc_taxbase)
gen gross_tax_base = a_43_renta_neta
replace gross_tax_base = a_44_perdida_neta*-1 if gross_tax_base==0

	* Net tax base (gross_tax_base - loss_carryforward)
gen net_tax_base_built = gross_tax_base - cond(missing(loss_carryforward), 0, loss_carryforward)
gen net_tax_base = gross_tax_base


* GROUP 5: GROSS & NET TAX LIABILITY
	* Gross tax liability (net tax base*CIT rate)
gen gross_tax_liability = a_45_impuesto_de_renta 

	* Credits for foreign taxes paid
gen cred_foreign_tax = .	
	* Investment credits from tax liability
egen investment_taxliab = rowtotal(a_47_otr_exone_per_ley), missing
	* Special firms credits from tax liability
gen special_taxliab = .
	* International Trade credits 
gen trade_taxliab = a_46_exoner_zona_franc
	* Other credit and allowances from tax liability
egen other_cred_taxliab = rowtotal (a_50_otr_cred_fis_perm), missing
	* Add up credits & deductions from tax liability 
egen tot_deduc_taxliab = rowtotal(cred_foreign_tax special_taxliab trade_taxliab investment_taxliab other_cred_taxliab), missing
	* Add up credits & deductions that are not necessarily real credits from tax liability 
egen tot_noelse_taxliab = rowtotal(cred_foreign_tax  other_cred_taxliab), missing
	* Net tax liability (gross_tax_liability - tot_deduc_taxliab)
gen net_tax_liability = a_51_impto_del_periodo+a_49_creditos_familiar
gen net_tax_liability_built = gross_tax_liability - cond(missing(tot_deduc_taxliab), 0, tot_deduc_taxliab)
	* Net tax liability without foreign and other credits  
gen ntl_noelse = net_tax_liability + cond(missing(tot_noelse_taxliab), 0, tot_noelse_taxliab)


* GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS
	* Add up partial/advance payments
egen partial_advanced_pay = rowtotal( a_55_pago_a_cta_de_imp a_54_pagos_parcs_renta), missing
	* Add withholding 
egen withholding = rowtotal(a_52_retenc_2_por_cien a_53_retenc_3_por_cien), missing
	* Other creditable tax payments
gen other_cred_tax_pay = .

	* Tax to remit
gen tax_to_remit = a_56_impto_neto_period
replace tax_to_remit = a_57_saldo_a_fav_perio*-1 if tax_to_remit == 0

**** Treatment of missings and 0
foreach var of varlist gross_tax_base net_tax_base gross_tax_liability net_tax_liability tax_to_remit {
    replace `var' = 0 if missing(`var') & !missing(total_income)
}

egen admin_sales_costs=rowtotal(a_34_gasto_gene_y_admi a_35_gasto_vent_y_dist), missing

gen total_assets = a_164_total_activo

gen FEZ = 0 
replace FEZ =1 if a_46_exoner_zona_franc !=0 & a_46_exoner_zona_franc!=.

********* Add labels and drop some variables ********
label variable tax_ID "Tax ID"
label variable year "Fiscal Year"
label variable turnover "Turnover"
label variable total_income "Total income"
label variable taxable_income "Taxable income"
label variable tot_cost "Total Costs"
label variable deductible_cost "Deductible Costs"
label variable net_profit "Net profit"
label variable taxable_income "Taxable profit"
label variable gross_tax_base "Gross Tax Base"
label variable tot_deduc_taxbase "Total Credits & Deductions - Tax Base"
label variable net_tax_base "Net Tax Base"
label variable gross_tax_liability "Gross Tax Liability"
label variable net_tax_liability "Net Tax Liability"
label variable tot_deduc_taxliab "Total Credits & Deductions - Tax Liability"
label variable tax_to_remit "Tax to Remit"

************* KEEP VARIABLES WE NEED *************
	* Create locals to keep variables
local group0 year tax_ID  
local group1 turnover exempt_income other_income total_income taxable_income dividend_income dividend_exempt
local group2 tot_cost *_inp deductible_cost depreciation acc_depreciation cogs
local group3 taxable_profit net_profit gross_profit
local group4 investment_taxbase capital_allowance loss_carryforward other_ded_taxbase net_tax_base gross_tax_base tot_deduc_taxbase
local group5 gross_tax_liability net_tax_liability tot_deduc_taxliab cred_foreign_tax investment_taxliab other_cred_taxliab 
local group6 withholding partial_advanced_pay other_cred_tax_pay tax_to_remit ntl_noelse tot_noelse_taxliab special_taxliab trade_taxliab
local group7 a_34_gasto_gene_y_admi a_35_gasto_vent_y_dist a_120_sueldos_y_salari a_130_sueldos_y_salari a_138_totales a_128_totales sap tang_assets admin_sales_costs a_49_creditos_familiar a_39_apor_reg_vol_pens

	* Keep selected variables
keep  `group0' `group1' `group2' `group3' `group4' `group5' `group6' `group7' FEZ total_assets wages_d152 wages_usd_d152 wages_sap wages_sap_usd

/* Merge sectors data */
merge m:1 tax_ID using `sectors_full'
keep if _merge==3
drop _merge

/* Compute sectors */
gen sector = "Other"
replace sector = "Manufacturing" if section == "C"
replace sector = "Retail" if section == "G"
replace sector = "Primary/Secondary" if inlist(section, "A", "B", "F", "D", "E")
replace sector = "Services" if inlist(section, "Q", "I", "H", "D", "R", "S", "O", "N")
replace sector = "Knowledge-Based" if inlist(section, "J", "M", "P")
replace sector = "Financial & Estate" if inlist(section, "K", "L")

sort sector
encode sector, gen(sector_num)

* Create a new variable "largesector" with the default value "Other"
gen largesector = "Other"
replace largesector = "Retail" if section == "G"
replace largesector = "Primary" if inlist(section, "A", "B")
replace largesector = "Secondary" if inlist(section, "C", "F", "D", "E")
replace largesector = "Services" if inlist(sector, "Services", "Other", "L", "K", "J", "M", "P")

sort largesector
encode largesector, gen(largesector_num)

tab largesector, gen(lsector_)

/* Predicting total payroll using a LASSO+OLS approach */
global indep 	wages_d152 lsector_*  other_income tang_assets exempt_income material_inp turnover  ///
				depreciation taxable_income tax_to_remit partial_advanced_pay net_tax_liability net_profit

corr wages_sap $indep

corr wages_sap wages_d152 lsector_1 other_income tang_assets exempt_income turnover depreciation taxable_income tax_to_remit partial_advanced_pay net_tax_liability net_profit

corr wages_sap wages_d152 lsector_1 depreciation taxable_income tax_to_remit partial_advanced_pay net_profit
// Best correlated variables that work with Lasso

/* Lasso */
global indep 	other_income tang_assets exempt_income material_inp turnover  ///
				taxable_income net_tax_liability lsector_2 lsector_3 lsector_4 lsector_5
				
cap drop yhat
lasso linear wages_sap (wages_d152 lsector_1 depreciation tax_to_remit partial_advanced_pay net_profit) $indep, noconstant
lassocoef
predict yhat

cap drop yhat
lasso linear wages_sap (wages_d152 lsector_1 depreciation tax_to_remit partial_advanced_pay net_profit) $indep
lassocoef
predict yhat

/* Select revelant variables only and save data */
keep tax_ID year wages_sap wages_d152 lsector_1 depreciation tax_to_remit partial_advanced_pay net_profit $indep
drop partial_advanced_pay
gen lasso=1

save "$data/temp/Costa Rica/CRI_Lasso_Sample.dta", replace

/* ------------------------- */
/* MERGE 2018-20 & D152 DATA */
/* ------------------------- */

/* Load D152 data */
use "$data/temp/Costa Rica/D152_2016_2023.dta", clear
keep if year==2018 | year==2019 | year==2020
count
tempfile temp
save `temp', replace

/* Load cleaned data */
use "$data/temp/Costa Rica/CRI_withvars_temp.dta", clear

keep if year>2017
tab year

merge 1:1 tax_ID year using `temp'
drop if _merge==2
gen matched_d152=(_merge==3)
drop _merge

ren wages wages_d152

keep if orbis_match==1

tab matched_d152 year

/* Compute sectors */
gen sector = "Other"
replace sector = "Manufacturing" if section == "C"
replace sector = "Retail" if section == "G"
replace sector = "Primary/Secondary" if inlist(section, "A", "B", "F", "D", "E")
replace sector = "Services" if inlist(section, "Q", "I", "H", "D", "R", "S", "O", "N")
replace sector = "Knowledge-Based" if inlist(section, "J", "M", "P")
replace sector = "Financial & Estate" if inlist(section, "K", "L")

sort sector
encode sector, gen(sector_num)

* Create a new variable "largesector" with the default value "Other"
gen largesector = "Other"
replace largesector = "Retail" if section == "G"
replace largesector = "Primary" if inlist(section, "A", "B")
replace largesector = "Secondary" if inlist(section, "C", "F", "D", "E")
replace largesector = "Services" if inlist(sector, "Services", "Other", "L", "K", "J", "M", "P")

sort largesector
encode largesector, gen(largesector_num)

tab largesector, gen(lsector_)

global indep 	other_income tang_assets exempt_income material_inp turnover  ///
				taxable_income net_tax_liability lsector_2 lsector_3 lsector_4 lsector_5

keep tax_ID year wages_d152 lsector_1 depreciation tax_to_remit net_profit $indep
desc, s

append using "$data/temp/Costa Rica/CRI_Lasso_Sample.dta"
desc, s

replace lasso=0 if lasso==.

/* Lasso */
sort tax_ID year
set seed 2024
lasso linear wages_sap (wages_d152 lsector_1 depreciation tax_to_remit net_profit) $indep if lasso==1, sel(cv, folds(20)) noconstant
lassocoef
predict yhat
ren yhat labor_inp_lasso

/* Save data to merge */
keep if lasso==0

keep tax_ID year labor_inp_lasso
drop if labor_inp_lasso==.

sort tax_ID year
save "$data/input/Costa Rica/CRI_Lasso_Estimates.dta", replace