*===============================================================================
* File name: 		GRC_Lasso.do
* 
* Description:		This do-file creates the dataset GRC_Lasso_Estimates.csv. 
*
* Input:  					
*					$data/input/Greece/GRC_withvars.csv 
*
* Output:
*					$data/input/Greece/GRC_Lasso_Estimates.csv
*===============================================================================
 
/* --------- */
/* Load data */
/* --------- */

clear 
set more off

import delimited using "$data/input/Greece/GRC_withvars.csv", case(preserve) clear

* Create a new variable "largesector" with the default value "Other"
gen largesector = "Other"
replace largesector = "Retail" if section == "G"
replace largesector = "Primary" if inlist(section, "A", "B")
replace largesector = "Secondary" if inlist(section, "C", "F", "D", "E")
replace largesector = "Services" if inlist(sector, "Services", "Other", "L", "K", "J", "M", "P")

sort largesector
encode largesector, gen(largesector_num)

tab largesector, gen(lsector_)

sort tax_ID year
distinct tax_ID

keep if year >= 2012

// Replace all "NA" with "."
foreach var of varlist _all {
   capture replace `var' = "." if `var' == "NA"
}

// Destring the variables if they are numeric
foreach var of varlist _all {
    capture destring `var', replace
}

drop if turnover <=0 | missing(turnover)
gen log_turnover = log(turnover)


gen labor_var = labor_data
replace labor_var = . if labor_data == 0

gen tang_var = tangible_assets_data
replace tang_var = 0 if tang_var <0
replace tang_var = . if tang_var == 0

gen empl_var = empl
replace empl_var = . if empl_var == 0

global indep  net_profit foreign_ownership lsector_2 lsector_3 lsector_4   
	
**** LABOR:

* Identify missing values in the target variable (assuming 'target' is the target variable)
gen missing_target = missing(labor_var)

* Initial imputation for missing values in predictors (mean imputation)
foreach var of varlist $indep      {
    egen imputed_`var' = mean(`var') 
    replace `var' = imputed_`var' if missing(`var')
    drop imputed_`var'
}

* Initial imputation for the target variable
egen target_median = mean(labor_var) 
replace labor_var = target_median if labor_var == .

* Train Lasso model
lasso linear labor_var (lsector_1 log_turnover)  $indep , rseed(1234) noconstant 

* Predict missing values
predict lasso_predicted_target if missing_target

* Replace missing target values with predictions 
replace labor_var = lasso_predicted_target if missing_target
replace labor_var = 0 if labor_var < 0 

* Create a variable to differentiate imputed from non-imputed values
gen imputation_status = .
replace imputation_status = 1 if missing_target  // 1 for imputed
replace imputation_status = 0 if !missing_target // 0 for non-imputed

* Generate histograms for imputed and non-imputed values
twoway (histogram labor_var if imputation_status == 0, bin(30) color(blue) percent) ///
 (histogram labor_var if imputation_status == 1, bin(30) color(red) percent) ///
       , legend(order(1 "Non-imputed" 2 "Imputed")) ///
       title("Histogram of Imputed and Non-imputed Target Values") ///
       xlabel(, grid)
drop missing_target target_median lasso_predicted_target imputation_status
 
* ASSETs:	
	
* Identify missing values in the target variable (assuming 'target' is the target variable)
gen missing_target = missing(tang_var)

* Initial imputation for missing values in predictors (mean imputation)
foreach var of varlist  lsector_1 log_turnover  $indep {
    egen imputed_`var' = mean(`var')
    replace `var' = imputed_`var' if missing(`var')
    drop imputed_`var'
}

* Initial imputation for the target variable
egen target_median = mean(tang_var) 
replace tang_var = target_median if tang_var == .

* Train Lasso model
lasso linear tang_var  (lsector_1 log_turnover)  $indep, rseed(1234) noconstant 

* Predict missing values
predict lasso_predicted_target if missing_target

* Replace missing target values with predictions
replace tang_var = lasso_predicted_target if missing_target
replace tang_var = 0 if tang_var < 0 

* Create a variable to differentiate imputed from non-imputed values
gen imputation_status = .
replace imputation_status = 1 if missing_target  // 1 for imputed
replace imputation_status = 0 if !missing_target // 0 for non-imputed
	   
drop missing_target target_med* lasso_predicted_target imputation_status

**** EMPLOYMENT:	
	
* Identify missing values in the target variable (assuming 'target' is the target variable)
gen missing_target = missing(empl_var)

* Initial imputation for missing values in predictors (mean imputation)
foreach var of varlist  lsector_1 log_turnover  $indep {
    egen imputed_`var' = mean(`var')
    replace `var' = imputed_`var' if missing(`var')
    drop imputed_`var'
}

* Initial imputation for the target variable
egen target_median = mean(empl_var) 
replace empl_var = target_median if empl_var == .

* Train Lasso model
lasso linear empl_var  (lsector_1 log_turnover)  $indep, rseed(1234) noconstant 

* Predict missing values 
predict lasso_predicted_target if missing_target

* Replace missing target values with predictions
replace empl_var = lasso_predicted_target if missing_target
replace empl_var = 0 if empl_var < 0 

* Create a variable to differentiate imputed from non-imputed values
gen imputation_status = .
replace imputation_status = 1 if missing_target  // 1 for imputed
replace imputation_status = 0 if !missing_target // 0 for non-imputed
	   
drop missing_target target_med* lasso_predicted_target imputation_status

* SAVE		
rename labor_var labor_lasso
rename tang_var tangible_asset_lasso 
rename empl_var empl_lasso 
		
keep year tax_ID labor_lasso tangible_asset_lasso empl_lasso
		
export delimited "$data/input/Greece/GRC_Lasso_Estimates.csv", replace